@@ -6,9 +6,11 @@ function usage()
 	echo
 	echo "Usage: jmg.sh [options]"
 	echo "Options:"
-	echo "  -g    Disable OpenGL displayer"
+	echo "  -g    Set ghhtp dir"
 	echo "  -h    Disable home install"
-	echo "  -o    Enable optimizations"
+	echo "  -o    Disable OpenGL"
+	echo "  -p    Enable optimizations"
+	echo "  -q    Disable lyrix queries"
 	echo "  -t    Omit test plugins"
 	echo "  -w    Normal warnings"
 	echo
@@ -22,34 +24,40 @@ function evl_echo()
 	fi
 }
 
-OPENGL=" --enable-opengl"
-HOMEINST=" --enable-install-home"
-OPTIMI=" --disable-optimizations"
-TESTDIS=" --enable-test-plugins"
-WARNS=" --enable-more-warnings"
+OPENGL="--enable-opengl"
+HOMEINST="--enable-install-home"
+OPTIMI="--disable-optimizations"
+TESTDIS="--enable-test-plugins"
+WARNS="--enable-more-warnings"
+GHTTP="--with-ghttp-prefix=/opt/gnome"
+QUERY=""
 
 # Parse command line options
-while getopts ghotw? opt ; do
+while getopts ghopqtw? opt ; do
 	case "$opt" in
-		g) OPENGL="" ;;
+		g) GHTTP="" ;;
 		h) HOMEINST="" ;;
-		o) OPTIMI="" ;;
+		o) OPENGL="" ;;
+		p) OPTIMI="" ;;
+		q) QUERY="--disable-lyrix-query" ;;
 		t) TESTDIS="" ;;
 		w) WARNS="" ;;
 		?) usage; exit ;;
 	esac
 done
 
-CONFIG="--enable-opengl ${TESTDIS} ${OPTIMI} ${WARNS} ${HOMEINST}"
+CONFIG="${OPENGL} ${TESTDIS} ${OPTIMI} ${WARNS} ${HOMEINST} ${GHTTP}"
 
 echo
 echo "This script runs configure with the following settings"
 echo " ./configure"
-evl_echo "$OPENGL"
-evl_echo "$TESTDIS"
-evl_echo "$OPTIMI"
-evl_echo "$WARNS"
-evl_echo "$HOMEINST"
+evl_echo "${OPENGL}"
+evl_echo "${TESTDIS}"
+evl_echo "${OPTIMI}"
+evl_echo "${WARNS}"
+evl_echo "${HOMEINST}"
+evl_echo "${GHTTP}"
+evl_echo "${QUERY}"
 echo
 echo "<CTRL + C> to abort - <Return> to continue"
 
@@ -59,15 +67,15 @@ read TMP
 
 echo
 echo "Press <Return> to compile"
-echo
 read TMP
+echo
 
 make
 
 echo
 echo "Press <Return> to install"
-echo
 read TMP
+echo
 
 make install
 
