@@ -22,7 +22,7 @@
 #include <gtk/gtk.h>
 
 #include "singit_debug.h"
-#include "singit_macros.h"
+#include "singit/macros.h"
 
 #include "dlg_input_time.h"
 
@@ -350,7 +350,7 @@ static void input_time_cancel_button_event(GtkButton *button, gpointer data)
 	g_return_if_fail(IS_INPUT_TIME_DIALOG(gtk_widget_get_toplevel(GTK_WIDGET(button))));
 
 	itd = INPUT_TIME_DIALOG(gtk_widget_get_toplevel(GTK_WIDGET(button)));
-	
+
 	input_time_dialog_hide(itd);
 }
 
@@ -397,7 +397,7 @@ static void input_time_dialog_destroy (GtkObject *object)
 		(* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
 
-void input_time_dialog_show (InputTimeDialog* dialog, GtkWindow *parent, 
+void input_time_dialog_show (InputTimeDialog* dialog, GtkWindow *parent,
 	gboolean at_cursor, gboolean modal)
 {
 #ifdef CODEDEBUG
@@ -410,7 +410,7 @@ void input_time_dialog_show (InputTimeDialog* dialog, GtkWindow *parent,
 	if (parent != NULL)
 		gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(parent));
 	gtk_window_set_modal(GTK_WINDOW(dialog), modal);
-	
+
 	gtk_widget_show(GTK_WIDGET(dialog));
 
 	if (at_cursor == FALSE)
@@ -432,7 +432,7 @@ void input_time_dialog_hide (InputTimeDialog* dialog)
 	g_return_if_fail(IS_INPUT_TIME_DIALOG(dialog));
 
 	gtk_widget_hide (GTK_WIDGET(dialog));
-	
+
 	if (GTK_WINDOW(dialog)->modal == TRUE)
 		gtk_main_quit();
 }
