@@ -21,11 +21,11 @@
 #include <string.h>
 #include <gtk/gtk.h>
 
-#include "singit_debug.h"
-#include "singit_macros.h"
-#include "singit_tools.h"
+#include "singit/macros.h"
+#include "singit/dlg_multiline.h"
 
-#include "dlg_multiline.h"
+#include "singit_debug.h"
+#include "singit_tools.h"
 
 enum {
 	NEW_TEXT,
