@@ -20,8 +20,8 @@
 
 #include <gtk/gtk.h>
 
+#include "singit/macros.h"
 #include "singit_debug.h"
-#include "singit_macros.h"
 
 #include "dlg_singit_about.h"
 
@@ -66,7 +66,7 @@ static void singit_about_create_about_page(GtkNotebook *notebook)
 	gtk_widget_show(info_about_table);
 
 	formatStr[0] = g_strdup_printf(_("Developed by %s"), "Jan-Marek Glogowski");
-	formatStr[1] = g_strdup_printf("%s: %s", _("Email"), JMG_EMAIL);
+	formatStr[1] = g_strdup_printf("%s: %s", _("Email"), PACKAGE_BUGREPORT);
 	formatStr[2] = NULL;
 	transStr = g_strconcat(SINGIT_VERSION_STRING, "\n\n\n",
 		formatStr[0], "\n", formatStr[1], "\n\n",
@@ -82,9 +82,7 @@ static void singit_about_create_about_page(GtkNotebook *notebook)
 	g_free(formatStr[0]);
 }
 
-/*
-	SingIt key 1  about  page
-*/
+// * SingIt key 1  about  page *
 static void singit_about_create_keybindings_one_page(GtkNotebook *notebook)
 {
 	gchar *transStr = '\0';
@@ -151,9 +149,7 @@ static void singit_about_create_keybindings_one_page(GtkNotebook *notebook)
 	g_free(transStr);
 }
 
-/*
-	SingIt key 2 about  page
-*/
+// * SingIt key 2 about  page *
 static void singit_about_create_keybindings_two_page(GtkNotebook *notebook)
 {
 	gchar *transStr = '\0';
@@ -242,7 +238,8 @@ void singit_about_show_page(gint page)
 	gtk_box_pack_start(GTK_BOX(about_vbox), button_hbox, FALSE, FALSE, 2);
 
 	ok_button = gtk_button_new_with_label( _("Ok") );
-	gtk_signal_connect_object(GTK_OBJECT(ok_button), "clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(singit_about_win));
+	gtk_signal_connect_object(GTK_OBJECT(ok_button), "clicked",
+		GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(singit_about_win));
 	GTK_WIDGET_SET_FLAGS(ok_button, GTK_CAN_DEFAULT);
 	gtk_box_pack_start(GTK_BOX(button_hbox), ok_button, TRUE, TRUE, 0);
 	gtk_widget_grab_default(ok_button);
