@@ -22,7 +22,7 @@
 #define __SINGIT_ABOUT_H__
 
 void singit_about_show(void);
-void singit_about_show_page(guint page);
+void singit_about_show_page(gint page);
 void singit_about_hide(void);
 
 #endif  // __SINGIT_ABOUT_H__
