@@ -21,10 +21,11 @@
 #ifndef __DLG_SINGIT_CONFIG_H__
 #define __DLG_SINGIT_CONFIG_H__
 
-void singit_config_show();
-void singit_config_hide();
+void singit_config_show(void);
+void singit_config_show_page(gint page);
+void singit_config_hide(void);
 
 /* rescans the plugin configuration if plugin state changed */
-void config_dis_plugins_rescan();
+void config_dis_plugins_rescan(void);
 
 #endif  // __DLG_SINGIT_CONFIG_H__
