@@ -32,13 +32,13 @@
 #include <gdk/gdkkeysyms.h>
 #include <stdio.h>
 
-#include "singit_macros.h"
-#include "singit_dialogs.h"
-#include "singit_config.h"
-#include "singit_displayer_plugin.h"
+#include "singit/macros.h"
+#include "singit/control.h"
+#include "singit/displayer_plugin.h"
+
+#include "displayer_clist.h"
 #include "displayer_clist_config.h"
 #include "displayer_clist_config_dlg.h"
-
 #include "displayer_clist_status.h"
 
 static GtkWidget *displayer_clist_win = NULL;
@@ -51,33 +51,29 @@ static GtkWidget
 static GtkTooltips
 		*displayer_clist_tooltips;
 
-extern SingitConfigGen *displayer_clist_config;
-
-void displayer_clist_init(void);
-void displayer_clist_show(SingitSong *cur_song);
-void displayer_clist_hide(SingitSong *cur_song);
-void displayer_clist_toggle(SingitSong *cur_song);
-void displayer_clist_finish(void);
-void displayer_clist_set_time(guint time, SingitSong *cur_song, GList *real_next);
-void displayer_clist_config_update(const SingitConfigData *singit_config);
-void displayer_clist_configure(void);
+static void displayer_clist_init(void);
+static void displayer_clist_finish(void);
+static void displayer_clist_set_song(SingitSong *new_song);
+static void displayer_clist_set_time(guint time, GList *real_next);
+static void displayer_clist_config_update(void);
+static void displayer_clist_configure(void);
 
 DisplayerPlugin clist_dp =
 {
 	NULL,
 	NULL,
 	0,
+	0,
+	NULL,
 
 	"Navigation displayer",
 
 	displayer_clist_init,
-	displayer_clist_show,
-	displayer_clist_hide,
-	displayer_clist_toggle,
 	displayer_clist_finish,
-	NULL,
+
 	displayer_clist_config_update,
 
+	displayer_clist_set_song,
 	displayer_clist_set_time,
 
 	NULL,
@@ -91,8 +87,6 @@ DisplayerPlugin clist_dp =
 
 DIPSPLAYER_SYMBOL(libdisplayer_clist, clist_dp)
 
-void displayer_clist_config_update_event(SingitConfigGen *scg, CListConfigData *cfg_data, gpointer user_data);
-
 static void displayer_clist_clst_jumpToTime(GtkWidget *clist, gint row, gint column, GdkEventButton *event, gpointer data)
 {
 	GList *item = NULL;
@@ -100,7 +94,10 @@ static void displayer_clist_clst_jumpToTime(GtkWidget *clist, gint row, gint col
 	SingitSong *cur_song = NULL;
 
 	if ((!event) || (!displayer_clist_win) ||
-		((cur_song = singit_song_attach(displayer_clist_status.song)) == NULL)) { return; }
+		((cur_song = singit_song_attach(STATUS->song)) == NULL))
+	{
+		return;
+	}
 
 // Prevent to show the focus row
 	if (GTK_CLIST(clist)->focus_row != -1) {
@@ -120,20 +117,20 @@ static void displayer_clist_clst_jumpToTime(GtkWidget *clist, gint row, gint col
 		}
 	}
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("dlg_singit_navigator.c [clst_jumpToTime] : "));
-#	endif
+#endif
 
-	if (displayer_clist_status.lastRow == row) {
+	if (STATUS->lastRow == row) {
 		item = cur_song->first_token;
 		while (item != cur_song->last_token) {
 			if ((gint) tLine(item) == row) {
 				if (!isPlaying) { xmms_remote_play(clist_dp.xmms_session); }
 				xmms_remote_jump_to_time(clist_dp.xmms_session, tTime(item));
 				singit_song_detach(&cur_song);
-#				ifdef CODEDEBUG
+#ifdef CODEDEBUG
 				DEBUG(("Ok\n"));
-#				endif
+#endif
 				return;
 			}
 			item = g_list_next(item);
@@ -144,14 +141,14 @@ static void displayer_clist_clst_jumpToTime(GtkWidget *clist, gint row, gint col
 		}
 	}
 	else {
-		displayer_clist_status.lastRow = row;
+		STATUS->lastRow = row;
 	}
 
 	singit_song_detach(&cur_song);
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
         DEBUG(("Ok\n"));
-#	endif
+#endif
 }
 
 static void set_statusbar_messages(gint time)
@@ -163,29 +160,29 @@ static void set_statusbar_messages(gint time)
 	if (new_message_count < 0) { new_message_count = 0; }
 	else
 		if (!(time % 1000 == 0)) { new_message_count++; }
-	if (displayer_clist_status.messageCounter == new_message_count) { return; }
+	if (STATUS->messageCounter == new_message_count) { return; }
 
 	timeStamp[9] = '\0';
-	if (displayer_clist_status.timestamp_context_id != 0) {
-		while (displayer_clist_status.messageCounter > new_message_count) {
+	if (STATUS->timestamp_context_id != 0) {
+		while (STATUS->messageCounter > new_message_count) {
 			gtk_statusbar_pop(GTK_STATUSBAR(displayer_clist_timestamp_status_bar),
-				displayer_clist_status.timestamp_context_id);
-			displayer_clist_status.messageCounter--;
+				STATUS->timestamp_context_id);
+			STATUS->messageCounter--;
 		}
 	}
 	else {
-		displayer_clist_status.timestamp_context_id =
+		STATUS->timestamp_context_id =
 			gtk_statusbar_get_context_id(
 				GTK_STATUSBAR(displayer_clist_timestamp_status_bar), "timestamps");
-		displayer_clist_status.messageCounter = 0;
+		STATUS->messageCounter = 0;
 	}
-	while (displayer_clist_status.messageCounter < new_message_count) {
-		displayer_clist_status.messageCounter++;
-		sprintf(timeStamp, " - %.2i:%.2i ", displayer_clist_status.messageCounter / 60,
-			displayer_clist_status.messageCounter % 60);
+	while (STATUS->messageCounter < new_message_count) {
+		STATUS->messageCounter++;
+		sprintf(timeStamp, " - %.2i:%.2i ", STATUS->messageCounter / 60,
+			STATUS->messageCounter % 60);
 		gtk_statusbar_push
 			(GTK_STATUSBAR(displayer_clist_timestamp_status_bar),
-			displayer_clist_status.timestamp_context_id, timeStamp);
+			STATUS->timestamp_context_id, timeStamp);
 	}
 }
 
@@ -194,23 +191,23 @@ static void lyrics_not_found(void)
 	gchar *fileNotFound, *nlbr[1][1];
 	gint width, height;
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("displayer_clist.c [lyrics_not_found]\n"));
-#	endif
+#endif
 
 	gtk_clist_freeze(GTK_CLIST(displayer_clist_clst));
 	gtk_clist_clear(GTK_CLIST(displayer_clist_clst));
 	fileNotFound = g_strconcat(_("Lyrics not found"), NULL);
 	nlbr[0][0] = fileNotFound;
 	gtk_clist_append(GTK_CLIST(displayer_clist_clst), nlbr[0]);
-	if (GET_CFG(displayer_clist_config,autoResize) == TRUE) {
+	if (GET_DCC->autoResize == TRUE) {
 		gdk_window_get_size (displayer_clist_win->window, &width, &height);
 		gtk_window_set_default_size(GTK_WINDOW(displayer_clist_win), 230, 80);
 	}
 	g_free(fileNotFound);
 	gtk_clist_thaw(GTK_CLIST(displayer_clist_clst));
 
-	if (displayer_clist_status.timestamp_context_id != 0)
+	if (STATUS->timestamp_context_id != 0)
 		{ set_statusbar_messages(0); }
 }
 
@@ -221,38 +218,46 @@ static void update_clist(SingitSong *new_song)
 	SingitSong *my_song = NULL;
 	gint clist_width;
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("displayer_clist.c [update_clist]\n"));
-#	endif
+#endif
 
 	gtk_clist_freeze(GTK_CLIST(displayer_clist_clst));
 	gtk_clist_clear(GTK_CLIST(displayer_clist_clst));
 
+	if (STATUS->timestamp_context_id != 0)
+		{ set_statusbar_messages(0); }
+
 	my_song = singit_song_attach(new_song);
-	if (my_song) {
-		if (displayer_clist_status.timestamp_context_id != 0)
-			{ set_statusbar_messages(0); }
-
-		// * Fill the clist *
-		lbr[1] = NULL;
-		i = 0;
-		while (my_song->lyrics[i]) {
-			lbr[0] = my_song->lyrics[i];
-			gtk_clist_append(GTK_CLIST(displayer_clist_clst), lbr);
-			i++;
-		}
-
-		// * Resize the clist *
-		if (GET_CFG(displayer_clist_config,autoResize) == TRUE) {
-			clist_width = gtk_clist_columns_autosize
-				(GTK_CLIST(displayer_clist_clst));
-			if (clist_width < 150) { clist_width = 150; }
-			gtk_window_set_default_size(GTK_WINDOW(displayer_clist_win),
-				clist_width + 45,
-				displayer_clist_status.win_size_y);
-		}
-		singit_song_detach(&my_song);
+	if (my_song != NULL) {
+		if (!singit_song_text_found(my_song))
+			{ goto detach_and_unfreeze; }
 	}
+	else { goto unfreeze; }
+
+	// * Fill the clist *
+	lbr[1] = NULL;
+	i = 0;
+	while (my_song->lyrics[i]) {
+		lbr[0] = my_song->lyrics[i];
+		gtk_clist_append
+			(GTK_CLIST(displayer_clist_clst), lbr);
+		i++;
+	}
+
+	// * Resize the clist *
+	if (GET_DCC->autoResize == TRUE) {
+		clist_width = gtk_clist_columns_autosize
+			(GTK_CLIST(displayer_clist_clst));
+		if (clist_width < 150) { clist_width = 150; }
+		gtk_window_set_default_size(GTK_WINDOW(displayer_clist_win),
+			clist_width + 45,
+			STATUS->win_size_y);
+	}
+
+detach_and_unfreeze:
+	singit_song_detach(&my_song);
+unfreeze:
 	gtk_clist_thaw(GTK_CLIST(displayer_clist_clst));
 }
 
@@ -260,117 +265,98 @@ static void set_status_filename(gchar *fileName)
 {
 	gchar *tmp;
 	if (!displayer_clist_win) { return; }
-	if (displayer_clist_status.song_context_id) {
+	if (STATUS->song_context_id) {
 		gtk_statusbar_pop(GTK_STATUSBAR
 			(displayer_clist_song_status_bar),
-			displayer_clist_status.song_context_id);
+			STATUS->song_context_id);
 	}
 	else {
-		displayer_clist_status.song_context_id =
+		STATUS->song_context_id =
 			gtk_statusbar_get_context_id(GTK_STATUSBAR
 				(displayer_clist_song_status_bar), "filename");
 	}
 	tmp = g_strconcat(" ", fileName, NULL);
 	gtk_statusbar_push(GTK_STATUSBAR(displayer_clist_song_status_bar),
-		displayer_clist_status.song_context_id, tmp);
+		STATUS->song_context_id, tmp);
 	gtk_tooltips_set_tip(displayer_clist_tooltips,
 		displayer_clist_song_gtk_event_box, fileName, NULL);
 	g_free(tmp);
 }
 
-static void select_item(gint new_item, gboolean show)
+static void select_item(gint new_line, gboolean show)
 {
-	if (displayer_clist_status.line > -1)
+	if (STATUS->line > -1)
 		gtk_clist_unselect_row(GTK_CLIST(displayer_clist_clst),
-			displayer_clist_status.line, 0);
+			STATUS->line, 0);
 
 	if (show) {
-		gtk_clist_select_row(GTK_CLIST(displayer_clist_clst), new_item, 0);
-		gtk_clist_moveto(GTK_CLIST(displayer_clist_clst), new_item, -1, 0.5, 0);
+		gtk_clist_select_row
+			(GTK_CLIST(displayer_clist_clst), new_line, 0);
 	}
-	displayer_clist_status.line = new_item;
+	gtk_clist_moveto(GTK_CLIST(displayer_clist_clst), new_line, -1, 0.5, 0);
 }
 
-void displayer_clist_set_time(guint time, SingitSong *cur_song, GList *real_next)
+void displayer_clist_set_time(guint time, GList *real_next)
 {
 	GList *item = NULL;
-	SingitSong* my_song = NULL, *tmp_song;
-	gboolean update_song = FALSE;
+	SingitSong* my_song = NULL;
 	gboolean update_selection = FALSE;
 	gboolean update_timer = FALSE;
 	gboolean show_item = FALSE;
-	gint new_item = -1;
+	gint new_line = -1, new_pos = -1;
 	gint timer;
 
 	if (displayer_clist_win && GTK_WIDGET_VISIBLE(displayer_clist_win) &&
 		(gdk_window_is_visible(displayer_clist_win->window)) &&
 		(gdk_window_is_viewable(displayer_clist_win->window)))
 	{
-		my_song = singit_song_attach(cur_song);
-		if (!my_song) { return; }
+		my_song = singit_song_attach(STATUS->song);
+		if (my_song == NULL)
+			{ return; }
 
-		if ((my_song != displayer_clist_status.song) ||
-			(strcmp(my_song->song_filename, displayer_clist_status.song->song_filename) != 0))
-		{
-			displayer_clist_status.line = -1;
-			tmp_song = displayer_clist_status.song;
-			displayer_clist_status.song = singit_song_attach(my_song);
-			singit_song_detach(&tmp_song);
-			update_song = TRUE;
-		}
-
-		if (singit_song_text_found(my_song)) {
-			// * Has the active token and ??? *
-			if (singit_song_lyrics_found(my_song)) {
-				if (my_song->active_token != NULL) {
-					new_item = tLine(my_song->active_token);
-					if (displayer_clist_status.line != new_item)
+		if (singit_song_lyrics_found(my_song)) {
+			if (my_song->active_token != NULL) {
+				new_line = tLine(my_song->active_token);
+				new_pos = tPos(my_song->active_token);
+				if ((STATUS->line != new_line) || (STATUS->pos != new_pos))
+				{
+					if (singit_song_is_empty_item(my_song, my_song->active_token, TRUE) &&
+						(real_next != NULL))
 					{
-						if (!singit_song_is_empty_item(my_song, my_song->active_token, FALSE)
-							|| (GET_CFG(displayer_clist_config,showEmpty) == TRUE))
-						{
-							show_item = TRUE;
-						}
-
-						update_selection = TRUE;
+						new_line = tLine(real_next);
+						new_pos = tPos(real_next);
 					}
+					else { show_item = TRUE; }
+					update_selection = TRUE;
 				}
+			}
 
-				// * Has the timer status changed ??? *
-				item = (real_next) ? real_next : my_song->last_token;
-				if (item != NULL) {
-					timer = (time / 1000);
-					if (timer < 0) { timer = 0; }
-					else
-						if (!(time % 1000 == 0)) { timer++; }
-					if (displayer_clist_status.messageCounter != timer)
-						{ update_timer = TRUE; }
-				}
+			// * Has the timer status changed ??? *
+			item = (real_next != NULL) ? real_next : my_song->last_token;
+			if (item != NULL) {
+				timer = (time / 1000);
+				if (timer < 0) { timer = 0; }
+				else
+					if (!(time % 1000 == 0)) { timer++; }
+				if (STATUS->messageCounter != timer)
+					{ update_timer = TRUE; }
 			}
 
 			// * Any updates needed ??? *
-			if (update_song || update_selection || update_timer) {
+			if (update_selection || update_timer) {
 
 				GDK_THREADS_ENTER();
-
-				// * Run any updates *
-				if (update_song) {
-					set_status_filename(my_song->song_filename);
-					update_clist(my_song);
+				if (update_selection) {
+					select_item(new_line, show_item);
+					STATUS->line = tLine(my_song->active_token);
+					STATUS->pos = tPos(my_song->active_token);
 				}
-				if (update_selection)
-					{ select_item(new_item, show_item); }
 				if (update_timer)
 					{ set_statusbar_messages(tTime(item) - time); }
-
 				GDK_THREADS_LEAVE();
 			}
 		}
-		else {
-			GDK_THREADS_ENTER();
-			lyrics_not_found();
-			GDK_THREADS_LEAVE();
-		}
+
 		singit_song_detach(&my_song);
 	}
 }
@@ -384,23 +370,28 @@ static gboolean displayer_clist_win_keypress(GtkWidget * w, GdkEventKey * event,
                         clist_dp.disable(&clist_dp);
                         break;
 		case GDK_a:
-			if (event->state & GDK_CONTROL_MASK) { singit_about_show(); }
+			if (event->state & GDK_CONTROL_MASK)
+				{ singit_remote_show_about_dlg(clist_dp.singit_session); }
 			break;
                 case GDK_b:
                         xmms_remote_playlist_next(clist_dp.xmms_session);
                         break;
                 case GDK_c:
-			if (event->state & GDK_CONTROL_MASK) { displayer_clist_config_show(); }
+			if (event->state & GDK_CONTROL_MASK)
+				{ displayer_clist_config_show(); }
 			else { xmms_remote_pause(clist_dp.xmms_session); }
                         break;
 		case GDK_e:
-			if (event->state & GDK_CONTROL_MASK) { singit_editor_show(); }
+			if (event->state & GDK_CONTROL_MASK)
+				{ singit_remote_show_editor_dlg(clist_dp.singit_session); }
 			break;
 		case GDK_i:
-			if (event->state & GDK_CONTROL_MASK) { singit_tag_manager_show(); }
+			if (event->state & GDK_CONTROL_MASK)
+				{ singit_remote_show_tag_manager_dlg(clist_dp.singit_session); }
 			break;
 		case GDK_p:
-			if (event->state & GDK_CONTROL_MASK) { singit_config_show(); }
+			if (event->state & GDK_CONTROL_MASK)
+				{ singit_remote_show_prefs_dlg(clist_dp.singit_session); }
 			break;
                 case GDK_v:
                         xmms_remote_stop(clist_dp.xmms_session);
@@ -409,11 +400,11 @@ static gboolean displayer_clist_win_keypress(GtkWidget * w, GdkEventKey * event,
                         xmms_remote_play(clist_dp.xmms_session);
                         break;
 		case GDK_y:
-			if (GET_DCC(displayer_clist_config)->gblToggleYZ)
+			if (GET_DCC->gblToggleYZ)
 				{ xmms_remote_playlist_prev(clist_dp.xmms_session); }
 			break;
                 case GDK_z:
-			if (!GET_DCC(displayer_clist_config)->gblToggleYZ)
+			if (!GET_DCC->gblToggleYZ)
 				{ xmms_remote_playlist_prev(clist_dp.xmms_session); }
                         break;
 		case GDK_KP_Add:
@@ -427,14 +418,14 @@ static gboolean displayer_clist_win_keypress(GtkWidget * w, GdkEventKey * event,
 			xmms_remote_set_main_volume(clist_dp.xmms_session, volume);
 			break;
 		case GDK_KP_Enter:
-			if (displayer_clist_status.jump_to_song == 0) { break; }
+			if (STATUS->jump_to_song == 0) { break; }
 			if (xmms_remote_get_playlist_pos(clist_dp.xmms_session) !=
-				(displayer_clist_status.jump_to_song - 1)) {
+				(STATUS->jump_to_song - 1)) {
 				xmms_remote_set_playlist_pos
-					(clist_dp.xmms_session, (displayer_clist_status.jump_to_song - 1));
+					(clist_dp.xmms_session, (STATUS->jump_to_song - 1));
 			}
 		case GDK_KP_Decimal:
-			displayer_clist_status.jump_to_song = 0;
+			STATUS->jump_to_song = 0;
 			break;
 		case GDK_KP_0:
 		case GDK_KP_1:
@@ -464,9 +455,9 @@ static gboolean displayer_clist_win_keypress(GtkWidget * w, GdkEventKey * event,
 				enable_plugin(((value + 9) % 10));
 			}
 			else {
-				displayer_clist_status.jump_to_song = (displayer_clist_status.jump_to_song * 10) + value;
-				if (displayer_clist_status.jump_to_song > xmms_remote_get_playlist_length
-					(clist_dp.xmms_session)) { displayer_clist_status.jump_to_song = value; }
+				STATUS->jump_to_song = (STATUS->jump_to_song * 10) + value;
+				if (STATUS->jump_to_song > xmms_remote_get_playlist_length
+					(clist_dp.xmms_session)) { STATUS->jump_to_song = value; }
 			}
 			break;
                 default:
@@ -481,13 +472,14 @@ static void displayer_clist_resize_event (GtkWidget *widget, gpointer user_data)
 	gint width, height;
 	SingitSong *cur_song = NULL;
 
-	if (!displayer_clist_win) { return; }
-	cur_song = singit_song_attach(displayer_clist_status.song);
-	if (!cur_song) { return; }
+	cur_song = singit_song_attach(STATUS->song);
+	if (cur_song == NULL)
+		{ return; }
+
 	if (singit_song_lyrics_found(cur_song) && displayer_clist_win->window)
-		if (GET_CFG(displayer_clist_config,autoResize) == TRUE) {
+		if (GET_DCC->autoResize == TRUE) {
 			gdk_window_get_size (displayer_clist_win->window, &width, &height);
-			displayer_clist_status.win_size_y = height;
+			STATUS->win_size_y = height;
 		}
 	if (displayer_clist_clst)
 		if (cur_song->active_token)
@@ -499,22 +491,21 @@ void displayer_clist_finish(void)
 {
 	CListConfigData *ccd;
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("displayer_clist.c [displayer_clist_finish]\n"));
-#	endif
+#endif
 
 	if (displayer_clist_win) {
-		ccd = GET_DCC(displayer_clist_config);
+		ccd = GET_DCC;
 		if (displayer_clist_win->window && (ccd != NULL)) {
-			gdk_window_get_root_origin(displayer_clist_win->window, &ccd->winPosX, &ccd->winPosY);
-			singit_config_gen_save(SINGIT_CONFIG_GEN(displayer_clist_config));
+			gdk_window_get_root_origin
+				(displayer_clist_win->window, &ccd->winPosX, &ccd->winPosY);
+			singit_config_gen_save(STATUS->config);
 		}
 		gtk_widget_destroy(displayer_clist_win);
 	}
 
-	singit_config_gen_detach(SINGIT_CONFIG_GEN(displayer_clist_config));
-
-	displayer_clist_status_finish();
+	clist_status_unref(NULL);
 }
 
 static gint displayer_clist_delete_event(GtkWidget *widget, GdkEvent  *event, gpointer data)
@@ -526,29 +517,13 @@ static gint displayer_clist_delete_event(GtkWidget *widget, GdkEvent  *event, gp
 void displayer_clist_init(void)
 {
 	gchar* title;
-	CListConfigData *ccd;
-
-#	ifdef CODEDEBUG
-	DEBUG(("dlg_singit_navigator.c [displayer_clist_init]\n"));
-#	endif
 
 	g_return_if_fail(displayer_clist_win == NULL);
+	g_return_if_fail(clist_status_ref() != NULL);
 
-	displayer_clist_status_init();
-
-	if (!singit_config_gen_attach(displayer_clist_config)) {
-		displayer_clist_config = displayer_clist_config_new();
-		singit_config_gen_load(SINGIT_CONFIG_GEN(displayer_clist_config));
-	}
-
-	ccd = GET_DCC(displayer_clist_config);
-	if (!ccd) {
-		singit_config_gen_detach(SINGIT_CONFIG_GEN(displayer_clist_config));
-		return;
-	}
-
-	gtk_signal_connect(GTK_OBJECT(displayer_clist_config), "update",
-		GTK_SIGNAL_FUNC(displayer_clist_config_update_event), NULL);
+#ifdef CODEDEBUG
+	DEBUG(("dlg_singit_navigator.c [displayer_clist_init]\n"));
+#endif
 
 	displayer_clist_tooltips = gtk_tooltips_new ();
 
@@ -612,112 +587,79 @@ void displayer_clist_init(void)
 // * we must explicit realize it to get a GDK_WINDOW *
 	gtk_widget_realize(displayer_clist_win);
 
-	displayer_clist_status.song_context_id =
+	STATUS->song_context_id =
 		gtk_statusbar_get_context_id(GTK_STATUSBAR(displayer_clist_song_status_bar), "filename");
 
-	displayer_clist_status.timestamp_context_id =
+	STATUS->timestamp_context_id =
 		gtk_statusbar_get_context_id(GTK_STATUSBAR(displayer_clist_timestamp_status_bar), "timestamps");
 	gtk_statusbar_push(GTK_STATUSBAR(displayer_clist_timestamp_status_bar),
-		displayer_clist_status.timestamp_context_id, "         ");
+		STATUS->timestamp_context_id, "         ");
 
-	if ((ccd->winPosX >= 0) && (ccd->winPosY >= 0))
-		gdk_window_move(displayer_clist_win->window, ccd->winPosX, ccd->winPosY);
-	else
+//	if ((ccd->winPosX >= 0) && (ccd->winPosY >= 0))
+//		gdk_window_move(displayer_clist_win->window, ccd->winPosX, ccd->winPosY);
+//	else
 		gtk_window_set_position
 			(GTK_WINDOW(displayer_clist_win), GTK_WIN_POS_CENTER);
-
-	displayer_clist_config_update_event(NULL, ccd, NULL);
 }
 
-void displayer_clist_show(SingitSong *cur_song)
+static void displayer_clist_config_update(void)
 {
-#	ifdef CODEDEBUG
-	DEBUG(("displayer_clist.c [displayer_clist_show]\n"));
-#	endif
-
-	if (displayer_clist_win) {
-		if (!GTK_WIDGET_VISIBLE(displayer_clist_win))
-			{ gtk_widget_show(displayer_clist_win); }
-		else { gdk_window_raise(displayer_clist_win->window); }
-	}
-}
-
-void displayer_clist_hide(SingitSong *cur_song)
-{
-	gboolean hide_it = TRUE;
-
-#	ifdef CODEDEBUG
-	DEBUG(("displayer_clist.c [displayer_clist_hide]\n"));
-#	endif
-
-	if (displayer_clist_config != NULL) {
-		hide_it = GET_CFG(displayer_clist_config, hideIfNotFound);
-		if ((hide_it == TRUE) && (GET_DCC(displayer_clist_config)->showOnText == TRUE)) {
-			if (cur_song != NULL) {
-				hide_it = (singit_song_text_found(cur_song) == FALSE);
-			}
-		}
-	}
-
-	if (displayer_clist_win) {
-		if (GTK_WIDGET_VISIBLE(displayer_clist_win) && hide_it)
-			{ gtk_widget_hide(displayer_clist_win); }
-	}
-}
-
-void displayer_clist_toggle(SingitSong *cur_song)
-{
-#	ifdef CODEDEBUG
-	DEBUG(("displayer_clist.c [displayer_clist_toggle]\n"));
-#	endif
-
-	if (displayer_clist_win) {
-		if (GTK_WIDGET_VISIBLE(displayer_clist_win))
-			{ gtk_widget_hide(displayer_clist_win); }
-		else  { gtk_widget_show(displayer_clist_win); }
-	}
-}
-
-void displayer_clist_config_update(const SingitConfigData *singit_config)
-{
-	CListConfigData *ccd = GET_DCC(displayer_clist_config);
-
-	ccd->gblToggleYZ = singit_config->toggleYZ;
-
-	if (ccd->forceGlobals == TRUE)
-		{ displayer_clist_config_update_event(displayer_clist_config, ccd, NULL); }
+	singit_config_gen_emit_update(STATUS->config);
 }
 
 void displayer_clist_configure(void)
 {
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("displayer_clist.c [displayer_clist_configure]\n"));
-#	endif
+#endif
 
 	displayer_clist_config_show();
 }
 
-void displayer_clist_config_update_event(SingitConfigGen *scg, CListConfigData *cfg_data, gpointer user_data)
+static void displayer_clist_set_song(SingitSong *new_song)
 {
-#	define REAL_CFG(val) \
-		((cfg_data->forceGlobals == TRUE) ? GET_SCD->val : cfg_data->val)
+	SingitSong *tmp_song;
+	gboolean hide;
 
+	tmp_song = STATUS->song;
+	STATUS->song = singit_song_attach(new_song);
+	singit_song_detach(&tmp_song);
+	STATUS->line = -1;
+
+	g_return_if_fail(displayer_clist_win != NULL);
+	g_return_if_fail(GTK_WIDGET_REALIZED(displayer_clist_win));
+	g_return_if_fail(STATUS != NULL);
+	g_return_if_fail(STATUS->config != NULL);
+
+	if (new_song) {
+		set_status_filename(new_song->song_filename);
+		update_clist(new_song);
+	}
+	else { lyrics_not_found(); }
+
+	hide = GET_DCC->hideIfNotFound;
+
+	if (new_song && singit_song_lyrics_found(new_song)) {
+		gtk_widget_show(displayer_clist_win);
+	}
+	else if (hide)
+		{ gtk_widget_hide(displayer_clist_win); }
+}
+
+void clist_displayer_real_update(CListConfigData *cfg_data)
+{
 	GtkRcStyle *rc_style;
 	GdkFont *newFont;
 	gchar *font_name;
 	GtkCList *clist;
 
-#	ifdef CODEDEBUG
-	DEBUG(("displayer_clist.c [displayer_clist_config_update_event]\n"));
-#	endif
+#ifdef CODEDEBUG
+	DEBUG(("displayer_clist.c [clist_displayer_real_update]\n"));
+#endif
 
-	if (displayer_clist_win == NULL) { return; }
-
-	if ((cfg_data->forceGlobals == TRUE) && GET_SCD) {
-		cfg_data->autoResize = GET_SCD->autoResize;
-		cfg_data->debugEnable = GET_SCD->debugEnable;
-		cfg_data->showEmpty = GET_SCD->showEmpty;
-	}
+	if (displayer_clist_win == NULL)
+		{ return; }
+	g_return_if_fail(GTK_WIDGET_REALIZED(displayer_clist_win));
 
 	clist = GTK_CLIST(displayer_clist_clst);
 	rc_style = gtk_rc_style_new ();
@@ -725,33 +667,33 @@ void displayer_clist_config_update_event(SingitConfigGen *scg, CListConfigData *
 	gtk_clist_freeze(clist);
 
 // * Check if we could load a font with this name
-	font_name = REAL_CFG(lyricFontName);
+	font_name = cfg_data->lyricFontName;
 	if ((newFont = gdk_font_load(font_name)) != NULL) {
 		gdk_font_unref(newFont);
 		rc_style->font_name = g_strdup(font_name);
 		rc_style->fontset_name = g_strdup(font_name);
 	}
 
-	/* Ok - is there any logic to use these colors ??? */
+	// * Ok - is there any logic to use these colors ??? *
 
 // color of a selected row
-	gdk_color_parse(REAL_CFG(progressBarColor), &rc_style->bg[GTK_STATE_SELECTED]);
+	gdk_color_parse(cfg_data->progressBarColor, &rc_style->bg[GTK_STATE_SELECTED]);
 	rc_style->color_flags[GTK_STATE_SELECTED] |= GTK_RC_BG;
 
 // color of the normal text
-	gdk_color_parse(REAL_CFG(normalTextColor), &rc_style->fg[GTK_STATE_NORMAL]);
+	gdk_color_parse(cfg_data->normalTextColor, &rc_style->fg[GTK_STATE_NORMAL]);
 	rc_style->color_flags[GTK_STATE_NORMAL] |= GTK_RC_FG;
 
 // color of the a selected row text
-	gdk_color_parse(REAL_CFG(progressTextColor), &rc_style->fg[GTK_STATE_SELECTED]);
+	gdk_color_parse(cfg_data->progressTextColor, &rc_style->fg[GTK_STATE_SELECTED]);
 	rc_style->color_flags[GTK_STATE_SELECTED] |= GTK_RC_FG;
 
 // background color of the row
-	gdk_color_parse(REAL_CFG(normalBarColor), &rc_style->base[GTK_STATE_NORMAL]);
+	gdk_color_parse(cfg_data->normalBarColor, &rc_style->base[GTK_STATE_NORMAL]);
 	rc_style->color_flags[GTK_STATE_NORMAL] |= GTK_RC_BASE;
 
 // "background" color of the space between the rows
-	gdk_color_parse(REAL_CFG(backgroundColor), &rc_style->base[GTK_STATE_ACTIVE]);
+	gdk_color_parse(cfg_data->backgroundColor, &rc_style->base[GTK_STATE_ACTIVE]);
 	rc_style->color_flags[GTK_STATE_ACTIVE] |= GTK_RC_BASE;
 
 	gtk_widget_modify_style(displayer_clist_clst, rc_style);
@@ -759,13 +701,13 @@ void displayer_clist_config_update_event(SingitConfigGen *scg, CListConfigData *
 	gtk_rc_style_unref(rc_style);
 
 // * Reseize the window *
-	if (REAL_CFG(autoResize) == TRUE) {
+	if (cfg_data->autoResize == TRUE) {
 		gtk_window_set_default_size(GTK_WINDOW(displayer_clist_win),
 			gtk_clist_columns_autosize(clist) + 45,
-			displayer_clist_status.win_size_y);
+			STATUS->win_size_y);
 	}
 
 	gtk_clist_thaw(clist);
 
-#	undef REAL_CFG
+#undef REAL_CFG
 }
