@@ -27,13 +27,16 @@
 #include <stdio.h>
 #include <string.h>
 
-#include <singit_macros.h>
-#include <singit_config.h>
-#include <singit_config_xmms.h>
+#include "singit/macros.h"
+#include "singit/control.h"
+#include "singit/displayer_plugin.h"
 
 #include "displayer_clist_config.h"
+#include "displayer_clist_status.h"
+#include "displayer_clist.h"
 
-SingitConfigGen *displayer_clist_config = NULL;
+extern DisplayerPlugin clist_dp;
+extern GtkWidget *displayer_clist_win;
 
 static gpointer displayer_clist_config_init_event(SingitConfigGen *scg, gpointer user_data)
 {
@@ -52,7 +55,8 @@ static gpointer displayer_clist_config_init_event(SingitConfigGen *scg, gpointer
 	return clist_config_data;
 }
 
-static void displayer_clist_config_free_event(SingitConfigGen *scg, CListConfigData *cfg_data, gpointer user_data)
+static void displayer_clist_config_free_event
+	(SingitConfigGen *scg, CListConfigData *cfg_data, gpointer user_data)
 {
 
 	if (cfg_data->lyricFontName) { g_free(cfg_data->lyricFontName); }
@@ -65,32 +69,30 @@ static void displayer_clist_config_free_event(SingitConfigGen *scg, CListConfigD
 	g_free(cfg_data);
 }
 
-#define GLOBAL_VAR   forceGlobals
-#define GLOBAL_DATA  scd
-#define CFG_DATA     cfg_data
-#define CFG_FILE     cfg_file
-#define SECTION     "DisplayerCList"
+#define GBL_VAR       forceGlobals
+#define GBL_SESSION   clist_dp.singit_session
+#define CFG_DATA      cfg_data
+#define CFG_FILE      cfg_file
+#define SECTION      "DisplayerCList"
 
-static void displayer_clist_config_load_event(SingitConfigGen *scg, ConfigFile* cfg_file, CListConfigData *cfg_data, gpointer user_data)
+static void displayer_clist_config_load_event
+	(SingitConfigGen *scg, ConfigFile* cfg_file, CListConfigData *cfg_data, gpointer user_data)
 {
-	SingitConfigData *scd = GET_SCD;
-
 	READ_CFG_DEF(boolean,forceGlobals,TRUE);
 
-	READ_CFG_DEF_GBL(boolean, hideIfNotFound,);
-	READ_CFG_DEF_GBL(boolean, showEmpty,);
-	READ_CFG_DEF_GBL(boolean, autoResize,);
+	READ_CFG_DEF_GBL(boolean,hideIfNotFound,hide_if_not_found);
+	READ_CFG_DEF_GBL(boolean,autoResize,auto_resize);
 #ifdef CODEDEBUG
-	READ_CFG_DEF_GBL(boolean,debugEnable,);
+	READ_CFG_DEF_GBL(boolean,debugEnable,debug_enabled);
 #endif
 
-	READ_CFG_DEF_GBL(string,lyricFontName,g_strdup);
+	READ_CFG_DEF_GBL(string,lyricFontName,lyric_font_name);
 
-	READ_CFG_DEF_GBL(color,backgroundColor,g_strdup);
-	READ_CFG_DEF_GBL(color,normalTextColor,g_strdup);
-	READ_CFG_DEF_GBL(color,normalBarColor,g_strdup);
-	READ_CFG_DEF_GBL(color,progressTextColor,g_strdup);
-	READ_CFG_DEF_GBL(color,progressBarColor,g_strdup);
+	READ_CFG_DEF_GBL_ARG(color,backgroundColor,color,0);
+	READ_CFG_DEF_GBL_ARG(color,normalTextColor,color,1);
+	READ_CFG_DEF_GBL_ARG(color,normalBarColor,color,2);
+	READ_CFG_DEF_GBL_ARG(color,progressTextColor,color,3);
+	READ_CFG_DEF_GBL_ARG(color,progressBarColor,color,4);
 
 	// * global independant config *
 	READ_CFG_DEF(boolean,showOnText,TRUE);
@@ -99,7 +101,8 @@ static void displayer_clist_config_load_event(SingitConfigGen *scg, ConfigFile*
 	READ_CFG_DEF(int,winPosY,-1);
 
 	// * global config copies *
-	cfg_data->gblToggleYZ = scd->toggleYZ;
+	cfg_data->gblToggleYZ =
+		singit_remote_cfg_toggle_yz(clist_dp.singit_session);
 }
 
 static void displayer_clist_config_save_event(SingitConfigGen *scg, ConfigFile* cfg_file, CListConfigData *cfg_data, gpointer user_data)
@@ -107,7 +110,6 @@ static void displayer_clist_config_save_event(SingitConfigGen *scg, ConfigFile*
 	// * boolean values *
 	WRITE_CFG(boolean, forceGlobals);
 	WRITE_CFG(boolean, hideIfNotFound);
-	WRITE_CFG(boolean, showEmpty);
 	WRITE_CFG(boolean, autoResize);
 #ifdef CODEDEBUG
 	WRITE_CFG(boolean, debugEnable);
@@ -131,32 +133,54 @@ static void displayer_clist_config_save_event(SingitConfigGen *scg, ConfigFile*
 #undef SECTION
 #undef CFG_FILE
 #undef CFG_DATA
-#undef GLOBAL_DATA
-#undef GLOBAL_VAR
+#undef GBL_SESSION
+#undef GBL_VAR
 
-static void displayer_clist_config_destroy_event(SingitConfigGen *scg, gpointer user_data)
+#define CTRL_SESSION	clist_dp.singit_session
+#define CTRL_CFG_DATA	ccd
+
+static void displayer_clist_config_update_event(SingitConfigGen *scg)
 {
-	displayer_clist_config = NULL;
+	CListConfigData *ccd;
+
+	g_return_if_fail(scg != NULL);
+
+	ccd = singit_config_gen_get_data(scg);
+
+	REMOTE_CFG_V(toggle_yz, gblToggleYZ);
+
+	if (ccd->forceGlobals == TRUE) {
+		REMOTE_CFG_V(auto_resize, autoResize);
+		REMOTE_CFG_V(debug_enabled, debugEnable);
+	}
+
+	clist_displayer_real_update(ccd);
 }
 
+#undef CTRL_CFG_DATA
+#undef CTRL_SESSION
+
 SingitConfigGen* displayer_clist_config_new(void)
 {
-	GtkObject *dcc;
+	g_return_val_if_fail(STATUS != NULL, NULL);
+	g_return_val_if_fail(STATUS->config == NULL,
+		SINGIT_CONFIG_GEN(STATUS->config));
 
-	if (displayer_clist_config != NULL) { return displayer_clist_config; }
+	STATUS->config = singit_config_xmms_new();
+	singit_config_gen_clear_initial(&STATUS->config);
+	singit_config_gen_set_filename
+		(STATUS->config, CONFIG_FILENAME);
 
-	dcc = singit_config_gen_new(CONFIG_FILENAME, NULL);
-
-	gtk_signal_connect(GTK_OBJECT(dcc), "init",
+	gtk_signal_connect(GTK_OBJECT(STATUS->config), "init_data",
 		GTK_SIGNAL_FUNC(displayer_clist_config_init_event), NULL);
-	gtk_signal_connect(GTK_OBJECT(dcc), "free",
+	gtk_signal_connect(GTK_OBJECT(STATUS->config), "free_data",
 		GTK_SIGNAL_FUNC(displayer_clist_config_free_event), NULL);
-	gtk_signal_connect(GTK_OBJECT(dcc), "load",
+	gtk_signal_connect(GTK_OBJECT(STATUS->config), "load",
 		GTK_SIGNAL_FUNC(displayer_clist_config_load_event), NULL);
-	gtk_signal_connect(GTK_OBJECT(dcc), "save",
+	gtk_signal_connect(GTK_OBJECT(STATUS->config), "save",
 		GTK_SIGNAL_FUNC(displayer_clist_config_save_event), NULL);
-	gtk_signal_connect(GTK_OBJECT(dcc), "destroy",
-		GTK_SIGNAL_FUNC(displayer_clist_config_destroy_event), NULL);
+	gtk_signal_connect(GTK_OBJECT(STATUS->config), "update",
+		GTK_SIGNAL_FUNC(displayer_clist_config_update_event), NULL);
 
-	return SINGIT_CONFIG_GEN(dcc);
+	return STATUS->config;
 }
