@@ -1,3 +1,5 @@
+
+
 /*
  *  SingIt Lyrics Displayer
  *  Copyright (C) 2000 - 2003 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
@@ -21,7 +23,7 @@
 #ifndef __DISPLAYER_CLIST_CONFIG_H__
 #define __DISPLAYER_CLIST_CONFIG_H__
 
-#include "singit_config_gen.h"
+#include "singit/config_xmms.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -33,7 +35,6 @@ typedef struct _CListConfigData {
 
 	/* has global equivalent */
 	gboolean hideIfNotFound;
-	gboolean showEmpty;
 	gboolean autoResize;
 	gboolean debugEnable;
 	gboolean showOnText;
@@ -57,12 +58,14 @@ CListConfigData;
 
 SingitConfigGen *displayer_clist_config_new(void);
 
-extern SingitConfigGen *singit_config;
+#define GET_DCC ((CListConfigData *) \
+	singit_config_gen_get_data(STATUS->config))
 
-#define GET_DCC(x) ((CListConfigData *) singit_config_gen_get_data(SINGIT_CONFIG_GEN(x)))
-#define DEBUG(x)  { if (displayer_clist_config && GET_DCC(displayer_clist_config) && GET_DCC(displayer_clist_config)->debugEnable) debug x; }
+#define DEBUG(x) \
+	do { if (STATUS && GET_DCC && GET_DCC->debugEnable) debug x; } while (0);
 
-#define GET_CFG(cfg,val) (GET_DCC(cfg)->forceGlobals == TRUE) ? (GET_SCD->val) : GET_DCC(cfg)->val
+#define GET_CFG(val) (GET_DCC->forceGlobals == TRUE) \
+	? (GET_SCD->val) : GET_DCC->val
 
 #ifdef __cplusplus
 }
