@@ -29,15 +29,13 @@
 
 #include <xmms/configfile.h>
 
-#include "singit_macros.h"
-#include "singit_config.h"
+#include "singit/macros.h"
+#include "singit/wgt_colorbutton.h"
 
-#include "singit_config_gen.h"
+#include "displayer_clist_status.h"
 #include "displayer_clist_config.h"
 #include "displayer_clist_config_dlg.h"
 
-#include "singit_wgt_colorbutton.h"
-
 static GtkWidget *displayer_clist_config_win = NULL;
 static GtkWidget
 	*displayer_clist_config_vbox,
@@ -69,7 +67,6 @@ static GtkWidget
 				*displayer_clist_config_color_progress_bar_button,
 		*displayer_clist_config_displayer_toggle_vbox, *displayer_clist_config_displayer_toggle_label,
 			*displayer_clist_config_hide_if_not_found_check_button,
-			*displayer_clist_config_show_empty_check_button,
 			*displayer_clist_config_auto_resize_check_button,
 #ifdef CODEDEBUG
 			*displayer_clist_config_enable_debug_check_button,
@@ -93,10 +90,11 @@ typedef struct {
 
 	gboolean updating_displayer_list;
 
+	SingitConfigGen *cscg;
+
 } ConfigStatus;
 
 ConfigStatus displayer_clist_config_status;
-extern SingitConfigGen *displayer_clist_config;
 
 static void displayer_clist_config_font_browse_ok(GtkWidget * w, gpointer data)
 {
@@ -116,7 +114,7 @@ static void displayer_clist_config_font_browse_cb(GtkWidget * w, gpointer data)
 		g_free(temp);
 		gtk_window_set_modal(GTK_WINDOW(displayer_clist_config_fontsel), TRUE);
                 gtk_font_selection_dialog_set_font_name(GTK_FONT_SELECTION_DIALOG(displayer_clist_config_fontsel),
-			GET_DCC(displayer_clist_config)->lyricFontName);
+			GET_DCC->lyricFontName);
                 gtk_signal_connect(GTK_OBJECT(GTK_FONT_SELECTION_DIALOG(displayer_clist_config_fontsel)->ok_button), "clicked",
 			GTK_SIGNAL_FUNC(displayer_clist_config_font_browse_ok), NULL);
                 gtk_signal_connect_object(GTK_OBJECT(GTK_FONT_SELECTION_DIALOG(displayer_clist_config_fontsel)->cancel_button),
@@ -141,20 +139,19 @@ static void displayer_clist_config_force_globals_toggle_event(GtkToggleButton *t
 	gtk_widget_set_sensitive(displayer_clist_config_color_progress_bar_button, state);
 
 	gtk_widget_set_sensitive(displayer_clist_config_hide_if_not_found_check_button, state);
-	gtk_widget_set_sensitive(displayer_clist_config_show_empty_check_button, state);
 	gtk_widget_set_sensitive(displayer_clist_config_auto_resize_check_button, state);
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	gtk_widget_set_sensitive(displayer_clist_config_enable_debug_check_button, state);
-#	endif
+#endif
 }
 
 static void displayer_clist_config_cleanup()
 {
-	CListConfigData *ccd = GET_DCC(displayer_clist_config);
+	CListConfigData *ccd = GET_DCC;
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("dlg_singit_config.c [displayer_clist_config_cleanup]\n"));
-#	endif
+#endif
 
 	if (displayer_clist_config_win && displayer_clist_config_win->window && ccd) {
 		gdk_window_get_position(displayer_clist_config_win->window,
@@ -164,27 +161,24 @@ static void displayer_clist_config_cleanup()
 
 	g_free(displayer_clist_config_status.color_array);
 
-	singit_config_gen_detach(SINGIT_CONFIG_GEN(displayer_clist_config));
+	clist_status_unref(NULL);
 }
 
 static void displayer_clist_config_apply_clicked(GtkButton *button, gpointer user_data)
 {
 	gchar tmp[13];
-	CListConfigData *ccd = GET_DCC(displayer_clist_config);
+	CListConfigData *ccd;
 
-#	ifdef CODEDEBUG
-	DEBUG(("dlg_singit_config.c [displayer_clist_config_apply_clicked] : "));
-#	endif
+#ifdef CODEDEBUG
+	DEBUG(("dlg_singit_config.c [displayer_clist_config_apply_clicked]\n"));
+#endif
 
-	if (!(displayer_clist_config_win &&
-		displayer_clist_config_win->window &&
-		singit_config_gen_attach(SINGIT_CONFIG_GEN(displayer_clist_config))))
-	{
-#		ifdef CODEDEBUG
-		DEBUG(("failed\n"));
-#		endif
-		return;
-	}
+	g_return_if_fail(displayer_clist_config_win != NULL);
+	g_return_if_fail(GTK_WIDGET_REALIZED(displayer_clist_config_win));
+	g_return_if_fail(STATUS != NULL);
+	g_return_if_fail(STATUS->config != NULL);
+
+	ccd = GET_DCC;
 
 	tmp[12] = '\0';
 
@@ -200,14 +194,13 @@ static void displayer_clist_config_apply_clicked(GtkButton *button, gpointer use
 	ccd->forceGlobals = GTK_TOGGLE_BUTTON(displayer_clist_config_force_globals_check_button)->active;
 
 	ccd->lyricFontName = gtk_editable_get_chars(GTK_EDITABLE(displayer_clist_config_font_entry), 0, -1);
-	ccd->showEmpty = GTK_TOGGLE_BUTTON(displayer_clist_config_show_empty_check_button)->active;
 	ccd->autoResize = GTK_TOGGLE_BUTTON(displayer_clist_config_auto_resize_check_button)->active;
 	ccd->hideIfNotFound = GTK_TOGGLE_BUTTON(displayer_clist_config_hide_if_not_found_check_button)->active;
 	ccd->showOnText = GTK_TOGGLE_BUTTON(displayer_clist_config_show_on_text_check_button)->active;
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	ccd->debugEnable = GTK_TOGGLE_BUTTON(displayer_clist_config_enable_debug_check_button)->active;
-#	endif
+#endif
 
 #define GET_RGB_AS_STRING(a,b) { sprintf(tmp, "rgb:%.2x/%.2x/%.2x", \
 		(gushort) ((guchar *) (COLOR_BUTTON(a)->color))[0], \
@@ -225,13 +218,12 @@ static void displayer_clist_config_apply_clicked(GtkButton *button, gpointer use
 
 	ccd->lyricFontName = gtk_editable_get_chars(GTK_EDITABLE(displayer_clist_config_font_entry), 0, -1);
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("Ok\n"));
-#	endif
+#endif
 
-	singit_config_gen_emit_update(SINGIT_CONFIG_GEN(displayer_clist_config));
-	singit_config_gen_save(SINGIT_CONFIG_GEN(displayer_clist_config));
-	singit_config_gen_detach(SINGIT_CONFIG_GEN(displayer_clist_config));
+	singit_config_gen_emit_update(STATUS->config);
+	singit_config_gen_save(STATUS->config);
 }
 
 static void displayer_clist_config_ok_clicked(GtkButton *button, gpointer user_data)
@@ -288,24 +280,18 @@ void displayer_clist_config_show(void)
 {
 	CListConfigData *ccd;
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("dlg_singit_config.c [displayer_clist_config_show]\n"));
-#	endif
+#endif
 
 	if (displayer_clist_config_win) {
 		gdk_window_raise(displayer_clist_config_win->window);
 		return;
 	}
 
-	if (!singit_config_gen_attach(displayer_clist_config)) {
-		displayer_clist_config = displayer_clist_config_new();
-		singit_config_gen_load(SINGIT_CONFIG_GEN(displayer_clist_config));
-	}
-	ccd = GET_DCC(displayer_clist_config);
-	if (!ccd) {
-		singit_config_gen_detach(SINGIT_CONFIG_GEN(displayer_clist_config));
-		return;
-	}
+	g_return_if_fail(clist_status_ref() != NULL);
+
+	ccd = GET_DCC;
 
 	displayer_clist_config_status.color_array = g_malloc(sizeof(guchar) * 3 * 5);
 	displayer_clist_config_status.updating_displayer_list = FALSE;
@@ -425,12 +411,6 @@ void displayer_clist_config_show(void)
 	gtk_notebook_append_page(GTK_NOTEBOOK(displayer_clist_config_notebook),
 		displayer_clist_config_displayer_toggle_vbox, displayer_clist_config_displayer_toggle_label);
 
-	displayer_clist_config_show_empty_check_button = gtk_check_button_new_with_label(_("Show empty lines"));
-	gtk_box_pack_start(GTK_BOX(displayer_clist_config_displayer_toggle_vbox), displayer_clist_config_show_empty_check_button, FALSE, FALSE, 0);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(displayer_clist_config_show_empty_check_button),
-		ccd->showEmpty);
-	gtk_widget_show(displayer_clist_config_show_empty_check_button);
-
 	displayer_clist_config_auto_resize_check_button = gtk_check_button_new_with_label(_("Automagically resize lyric displayer"));
 	gtk_box_pack_start(GTK_BOX(displayer_clist_config_displayer_toggle_vbox), displayer_clist_config_auto_resize_check_button, FALSE, FALSE, 0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(displayer_clist_config_auto_resize_check_button),
@@ -443,13 +423,13 @@ void displayer_clist_config_show(void)
 		ccd->hideIfNotFound);
 	gtk_widget_show(displayer_clist_config_hide_if_not_found_check_button);
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	displayer_clist_config_enable_debug_check_button = gtk_check_button_new_with_label(_("Enable console debug output"));
 	gtk_box_pack_start(GTK_BOX(displayer_clist_config_displayer_toggle_vbox), displayer_clist_config_enable_debug_check_button, FALSE, FALSE, 0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(displayer_clist_config_enable_debug_check_button),
 		ccd->debugEnable);
 	gtk_widget_show(displayer_clist_config_enable_debug_check_button);
-#	endif
+#endif
 
 	displayer_clist_config_1_hsep = gtk_hseparator_new();
 	gtk_box_pack_start(GTK_BOX(displayer_clist_config_displayer_toggle_vbox), displayer_clist_config_1_hsep, FALSE, FALSE, 3);
@@ -507,9 +487,9 @@ void displayer_clist_config_show(void)
 
 void displayer_clist_config_hide(void)
 {
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("dlg_singit_config.c [displayer_clist_config_hide]\n"));
-#	endif
+#endif
 
 	if (displayer_clist_config_win) {
 		displayer_clist_config_cancel_clicked(NULL, NULL);
