@@ -25,8 +25,8 @@
 extern "C" {
 #endif // __cplusplus
 
-void displayer_clist_config_show();
-void displayer_clist_config_hide();
+void displayer_clist_config_show(void);
+void displayer_clist_config_hide(void);
 
 #ifdef __cplusplus
 }
