@@ -22,7 +22,8 @@
 #define __C_WRAPPER_H__
 
 #include <glib.h>
-#include "singit_song.h"
+
+#include "singit/song.h"
 
 #ifdef __cplusplus
 extern "C" {
