@@ -28,7 +28,7 @@
 #include <gltt/GLTTGlyphPolygonizer.h>
 #include <gltt/GLTTGlyphTriangulator.h>
 
-#include "singit_song.h"
+#include "singit/song.h"
 
 
 class CLyricTextEngine
