@@ -27,7 +27,7 @@
 #include "maths.h"
 #include "data.h"
 
-#include "singit_macros.h"
+#include "singit/macros.h"
 
 extern gint16 static_pcm_data[2][512];
 extern gint16 static_freq_data[2][256];
