@@ -25,7 +25,7 @@
 #include "ccamera.h"
 #include "clyrictextengine.h"
 #include "clevelparticleengine.h"
-#include "singit_song.h"
+#include "singit/song.h"
 
 class CScene {
 private:
