@@ -31,30 +31,28 @@
 #include <xmms/xmmsctrl.h>
 #include <xmms/util.h>
 
-#include "singit_displayer_plugin.h"
+#include "singit/displayer_plugin.h"
+#include "singit/control.h"
+
 #include "displayer_opengl.h"
 
 #include "gtkglarea.h"
 #include "c_wrapper.h"
-#include "singit_config.h"
 
 #include "displayer_opengl_config.h"
 #include "displayer_opengl_config_dlg.h"
+#include "displayer_opengl_status.h"
 
-#include "singit_dialogs.h"
+static void displayer_opengl_init(void);
+static void displayer_opengl_finish(void);
 
-void displayer_opengl_init(void);
-void displayer_opengl_finish(void);
+static void displayer_opengl_render_freq(gint16 freq_data[2][256], SingitSoundPrecalcs *ssp);
+static void displayer_opengl_render_pcm(gint16 pcm_data[2][512], SingitSoundPrecalcs *ssp);
+static void displayer_opengl_configure(void);
 
-void displayer_opengl_show(SingitSong *cur_song);
-void displayer_opengl_hide(SingitSong *cur_song);
-void displayer_opengl_toggle(SingitSong *cur_song);
-void displayer_opengl_render_freq(gint16 freq_data[2][256], SingitSoundPrecalcs *ssp);
-void displayer_opengl_render_pcm(gint16 pcm_data[2][512], SingitSoundPrecalcs *ssp);
-void displayer_opengl_configure(void);
-
-void displayer_opengl_set_time(guint time, SingitSong *cur_song, GList *real_next);
-void displayer_opengl_config_update(const SingitConfigData *singit_config);
+static void displayer_opengl_set_song(SingitSong *new_song);
+static void displayer_opengl_set_time(guint time, GList *real_next);
+static void displayer_opengl_config_update(void);
 
 // static void displayer_opengl_limit_fps(gboolean init);
 
@@ -65,17 +63,16 @@ DisplayerPlugin opengl_dp =
 	NULL,
 	NULL,
 	0,
+	0,
+	NULL,
 
 	"OpenGL displayer",
 
 	displayer_opengl_init,
-	NULL,
-	NULL,
-	NULL,
 	displayer_opengl_finish,
-	NULL,
 	displayer_opengl_config_update,
 
+	displayer_opengl_set_song,
 	displayer_opengl_set_time,
 
 	NULL,
@@ -122,35 +119,26 @@ void displayer_opengl_init(void)
 {
 	gchar *title;
 	GtkWidget* box_main;
-	gint posX, posY;
-	OpenGLConfigData *oglcd;
-
-	#ifdef CODEDEBUG
-	DEBUG(("displayer_opengl.c [displayer_opengl_init]\n"));
-	#endif
+//	gint posX, posY;
 
 	g_return_if_fail(displayer_opengl_window == NULL);
 
-	displayer_opengl_status_init();
-
-	if (!singit_config_gen_attach(displayer_opengl_config)) {
-		displayer_opengl_config = displayer_opengl_config_new();
-		singit_config_gen_load(SINGIT_CONFIG_GEN(displayer_opengl_config));
-	}
-
-	oglcd = GET_OGLCD(displayer_opengl_config);
-	if (!oglcd) {
-		singit_config_gen_detach(SINGIT_CONFIG_GEN(displayer_opengl_config));
-		return;
-	}
-
-	displayer_opengl_status.gl_area_widget = create_glarea();
-	if (displayer_opengl_status.gl_area_widget == NULL) {
+	if (opengl_status_ref() == NULL) {
 		gtk_idle_add (displayer_opengl_disable_func, NULL);
 		return;
 	}
-	gtk_signal_connect(GTK_OBJECT(displayer_opengl_status.gl_area_widget),
-		"destroy", GTK_SIGNAL_FUNC(gtk_widget_destroyed), &displayer_opengl_status.gl_area_widget);
+
+#ifdef CODEDEBUG
+	DEBUG(("displayer_opengl.c [displayer_opengl_init]\n"));
+#endif
+
+	STATUS->gl_area_widget = create_glarea();
+	if (STATUS->gl_area_widget == NULL) {
+		gtk_idle_add (displayer_opengl_disable_func, NULL);
+		return;
+	}
+	gtk_signal_connect(GTK_OBJECT(STATUS->gl_area_widget),
+		"destroy", GTK_SIGNAL_FUNC(gtk_widget_destroyed), &STATUS->gl_area_widget);
 
 	displayer_opengl_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_container_border_width(GTK_CONTAINER(displayer_opengl_window), 2);
@@ -166,15 +154,15 @@ void displayer_opengl_init(void)
 	gtk_container_add(GTK_CONTAINER(displayer_opengl_window), box_main);
 	gtk_widget_show(box_main);
 
-	gtk_box_pack_start (GTK_BOX(box_main), displayer_opengl_status.gl_area_widget, TRUE, TRUE, 0);
-	gtk_widget_show(displayer_opengl_status.gl_area_widget);
+	gtk_box_pack_start (GTK_BOX(box_main), STATUS->gl_area_widget, TRUE, TRUE, 0);
+	gtk_widget_show(STATUS->gl_area_widget);
 
 	gtk_widget_show(displayer_opengl_window);
 
-	if (singit_config_load_plugin_position("opengl_window", &posX, &posY, NULL, NULL)) {
-		gtk_widget_set_uposition(displayer_opengl_window, posX, posY);
-	}
-	else
+//	if (singit_config_load_plugin_position("opengl_window", &posX, &posY, NULL, NULL)) {
+//		gtk_widget_set_uposition(displayer_opengl_window, posX, posY);
+//	}
+//	else
 		gtk_window_set_position
 			(GTK_WINDOW(displayer_opengl_window), GTK_WIN_POS_CENTER);
 
@@ -185,112 +173,57 @@ void displayer_opengl_finish(void)
 {
 	OpenGLConfigData *oglcd;
 
-	#ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("displayer_opengl.c [displayer_opengl_finish]\n"));
-	#endif
+#endif
 
 	if (displayer_opengl_window) {
-		oglcd = GET_OGLCD(displayer_opengl_config);
+		oglcd = GET_OGLCD;
 		if (displayer_opengl_window->window && (oglcd != NULL)) {
 			gdk_window_get_root_origin(displayer_opengl_window->window,
 				&oglcd->winPosX, &oglcd->winPosY);
-			singit_config_gen_save(SINGIT_CONFIG_GEN(displayer_opengl_config));
+			singit_config_gen_save(STATUS->config);
 		}
 		gtk_widget_destroy(displayer_opengl_window);
 	}
 
-	singit_config_gen_detach(SINGIT_CONFIG_GEN(displayer_opengl_config));
-
-	displayer_opengl_status_finish();
+	opengl_status_unref(NULL);
 }
 
-void displayer_opengl_show(SingitSong *cur_song)
+void displayer_opengl_set_time(guint time, GList *real_next)
 {
-	#ifdef CODEDEBUG
-	DEBUG(("displayer_opengl.c [displayer_opengl_show]\n"));
-	#endif
-
-	if (displayer_opengl_window) {
-		if (!GTK_WIDGET_VISIBLE(displayer_opengl_window))
-			{ gtk_widget_show(displayer_opengl_window); }
-		else { gdk_window_raise(displayer_opengl_window->window); }
-	}
-}
-
-void displayer_opengl_hide(SingitSong *cur_song)
-{
-	#ifdef CODEDEBUG
-	DEBUG(("displayer_opengl.c [displayer_opengl_hide]\n"));
-	#endif
-
-	if (displayer_opengl_window) {
- 		if (GTK_WIDGET_VISIBLE(displayer_opengl_window))
-			gtk_widget_hide(displayer_opengl_window);
-	}
-}
-
-void displayer_opengl_toggle(SingitSong *cur_song)
-{
-	#ifdef CODEDEBUG
-	DEBUG(("displayer_opengl.c [displayer_opengl_toggle]\n"));
-	#endif
-
-	if (displayer_opengl_window) {
-		if (GTK_WIDGET_VISIBLE(displayer_opengl_window)) {
-			gtk_widget_hide(displayer_opengl_window);
-		}
-		else { gtk_widget_show(displayer_opengl_window); }
-	}
-}
-
-void displayer_opengl_set_time(guint time, SingitSong *cur_song, GList *real_next)
-{
-	SingitSong *my_song;
-
 	if (displayer_opengl_window != NULL)
 	{
-		my_song = singit_song_attach(cur_song);
-		if ((my_song != displayer_opengl_status.song) ||
-			(strcmp(my_song->song_filename, displayer_opengl_status.song->song_filename) != 0))
-		{
-			singit_song_detach(&displayer_opengl_status.song);
-			displayer_opengl_status.song = singit_song_attach(my_song);
-			displayer_opengl_status.rotate = !singit_song_lyrics_found(my_song);
-			GDK_THREADS_ENTER();
-			opengl_lyrics_set_song(my_song);
-			gtk_widget_queue_draw(displayer_opengl_status.gl_area_widget);
-			GDK_THREADS_LEAVE();
-		}
-		singit_song_detach(&my_song);
-		displayer_opengl_status.time = time;
+		STATUS->time = time;
 	}
 }
 
-void displayer_opengl_config_update(const SingitConfigData *singit_config)
+void displayer_opengl_config_update(void)
 {
-	#ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("displayer_opengl.c [displayer_opengl_config_update]\n"));
-	#endif
+#endif
 
-	displayer_opengl_status.toggle_yz = singit_config->toggleYZ;
+	GET_OGLCD->gblToggleYZ =
+		singit_remote_cfg_toggle_yz(opengl_dp.singit_session);
 }
 
 void displayer_opengl_configure(void)
 {
-	#ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("displayer_opengl.c [displayer_opengl_configure]\n"));
-	#endif
+#endif
 
 	displayer_opengl_config_show();
 }
 
 void displayer_opengl_render_pcm(gint16 pcm_data[2][512], SingitSoundPrecalcs *ssp)
 {
-	if (displayer_opengl_status.gl_area_widget != NULL) {
+	if (STATUS->gl_area_widget != NULL) {
 		memcpy(static_pcm_data, pcm_data, 2 * 2 * 512);
-		displayer_opengl_status.beat = ssp->beat;
+		STATUS->beat = ssp->beat;
 
-		gtk_widget_queue_draw(displayer_opengl_status.gl_area_widget);
+		gtk_widget_queue_draw(STATUS->gl_area_widget);
 	}
 }
 
@@ -308,9 +241,9 @@ void displayer_opengl_render_freq(gint16 freq_data[2][256], SingitSoundPrecalcs
 				madspin_data[i] = 1.0;
 		}
 
-		displayer_opengl_status.level[0] = ssp->level[0];
-		displayer_opengl_status.level[1] = ssp->level[1];
-		displayer_opengl_status.level[2] = ssp->level[2];
+		STATUS->level[0] = ssp->level[0];
+		STATUS->level[1] = ssp->level[1];
+		STATUS->level[2] = ssp->level[2];
 
 //		g_print("levels - l: %f / r: %f / c: %f\n", ssp->level[0], ssp->level[1], ssp->level[2]);
 	}
@@ -342,7 +275,8 @@ static gboolean displayer_opengl_win_keypress(GtkWidget * w, GdkEventKey * event
                         opengl_dp.disable(&opengl_dp);
                         break;
 		case GDK_a:
-			if (event->state & GDK_CONTROL_MASK) { singit_about_show(); }
+			if (event->state & GDK_CONTROL_MASK)
+				{ singit_remote_show_about_dlg(opengl_dp.singit_session); }
 			break;
                 case GDK_b:
                         xmms_remote_playlist_next(opengl_dp.xmms_session);
@@ -352,13 +286,16 @@ static gboolean displayer_opengl_win_keypress(GtkWidget * w, GdkEventKey * event
 			else { xmms_remote_pause(opengl_dp.xmms_session); }
                         break;
 		case GDK_e:
-			if (event->state & GDK_CONTROL_MASK) { singit_editor_show(); }
+			if (event->state & GDK_CONTROL_MASK)
+				{ singit_remote_show_editor_dlg(opengl_dp.singit_session); }
 			break;
 		case GDK_i:
-			if (event->state & GDK_CONTROL_MASK) { singit_tag_manager_show(); }
+			if (event->state & GDK_CONTROL_MASK)
+				{ singit_remote_show_tag_manager_dlg(opengl_dp.singit_session); }
 			break;
 		case GDK_p:
-			if (event->state & GDK_CONTROL_MASK) { singit_config_show(); }
+			if (event->state & GDK_CONTROL_MASK)
+				{ singit_remote_show_prefs_dlg(opengl_dp.singit_session); }
 			break;
                 case GDK_v:
                         xmms_remote_stop(opengl_dp.xmms_session);
@@ -367,11 +304,11 @@ static gboolean displayer_opengl_win_keypress(GtkWidget * w, GdkEventKey * event
                         xmms_remote_play(opengl_dp.xmms_session);
                         break;
 		case GDK_y:
-			if (displayer_opengl_status.toggle_yz)
+			if (GET_OGLCD->gblToggleYZ)
 				{ xmms_remote_playlist_prev(opengl_dp.xmms_session); }
 			break;
                 case GDK_z:
-			if (!displayer_opengl_status.toggle_yz)
+			if (!GET_OGLCD->gblToggleYZ)
 				{ xmms_remote_playlist_prev(opengl_dp.xmms_session); }
                         break;
 		case GDK_KP_Add:
@@ -385,14 +322,14 @@ static gboolean displayer_opengl_win_keypress(GtkWidget * w, GdkEventKey * event
 			xmms_remote_set_main_volume(opengl_dp.xmms_session, volume);
 			break;
 		case GDK_KP_Enter:
-			if (displayer_opengl_status.jump_to_song == 0) { break; }
+			if (STATUS->jump_to_song == 0) { break; }
 			if (xmms_remote_get_playlist_pos(opengl_dp.xmms_session) !=
-				(displayer_opengl_status.jump_to_song - 1)) {
+				(STATUS->jump_to_song - 1)) {
 				xmms_remote_set_playlist_pos
-					(opengl_dp.xmms_session, (displayer_opengl_status.jump_to_song - 1));
+					(opengl_dp.xmms_session, (STATUS->jump_to_song - 1));
 			}
 		case GDK_KP_Decimal:
-			displayer_opengl_status.jump_to_song = 0;
+			STATUS->jump_to_song = 0;
 			break;
 		case GDK_KP_0:
 		case GDK_KP_1:
@@ -422,9 +359,9 @@ static gboolean displayer_opengl_win_keypress(GtkWidget * w, GdkEventKey * event
 				enable_plugin(((value + 9) % 10));
 			}
 			else {
-				displayer_opengl_status.jump_to_song = (displayer_opengl_status.jump_to_song * 10) + value;
-				if (displayer_opengl_status.jump_to_song > xmms_remote_get_playlist_length
-					(opengl_dp.xmms_session)) { displayer_opengl_status.jump_to_song = value; }
+				STATUS->jump_to_song = (STATUS->jump_to_song * 10) + value;
+				if (STATUS->jump_to_song > xmms_remote_get_playlist_length
+					(opengl_dp.xmms_session)) { STATUS->jump_to_song = value; }
 			}
 			break;
                 default:
@@ -498,10 +435,10 @@ gint glarea_draw (GtkWidget* widget, GdkEventExpose* event)
 
 	if (gtk_gl_area_make_current(GTK_GL_AREA(widget))) {
 
-		opengl_lyrics_draw(displayer_opengl_status.time,
-			displayer_opengl_status.rotate,
-			displayer_opengl_status.beat,
-			displayer_opengl_status.level);
+		opengl_lyrics_draw(STATUS->time,
+			STATUS->rotate,
+			STATUS->beat,
+			STATUS->level);
 		gtk_gl_area_swap_buffers(GTK_GL_AREA(widget));
 
 //		displayer_opengl_limit_fps(FALSE);
@@ -527,9 +464,9 @@ gint glarea_init (GtkWidget* widget)
 {
 //	const float light_pos[] = { -1.0, -1.0, 2.0, 0.0 };
 
-	#ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("displayer_opengl.c [glarea_init] - GTK GL Area Realize Event\n"));
-	#endif
+#endif
 
 	if (gtk_gl_area_make_current (GTK_GL_AREA(widget))) {
 
@@ -575,11 +512,11 @@ gint glarea_init (GtkWidget* widget)
 
 gint glarea_destroy (GtkWidget* widget)
 {
-	#ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("displayer_opengl.c [glarea_destroy] - GTK GL Area Destroy Event\n"));
-	#endif
+#endif
 
-	glDeleteLists(displayer_opengl_status.display_list, 1);
+	glDeleteLists(STATUS->display_list, 1);
 	opengl_lyrics_free();
 
 	return TRUE;
@@ -592,24 +529,24 @@ gint glarea_destroy (GtkWidget* widget)
 
 gint glarea_button_release (GtkWidget* widget, GdkEventButton* event)
 {
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	int x = event->x;
 	int y = event->y;
-#	endif
+#endif
 
 	if (event->button == 1) {
 		/* Mouse button 1 was released */
-#		ifdef CODEDEBUG
+#ifdef CODEDEBUG
 		DEBUG(("displayer_opengl.c [glarea_button_release] - Button 1 release  (%d, %d)\n", x, y));
-#		endif
+#endif
 		return TRUE;
 	}
 
 	if (event->button == 2) {
 		/* Mouse button 2 was released */
-#		ifdef CODEDEBUG
+#ifdef CODEDEBUG
 		DEBUG(("displayer_opengl.c [glarea_button_release] - Button 2 release  (%d, %d)\n", x, y));
-#		endif
+#endif
 		return TRUE;
 	}
 
@@ -618,24 +555,24 @@ gint glarea_button_release (GtkWidget* widget, GdkEventButton* event)
 
 gint glarea_button_press (GtkWidget* widget, GdkEventButton* event)
 {
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	int x = event->x;
 	int y = event->y;
-#	endif
+#endif
 
 	if (event->button == 1) {
 		/* Mouse button 1 was engaged */
-#		ifdef CODEDEBUG
+#ifdef CODEDEBUG
 		DEBUG(("displayer_opengl.c [glarea_button_release] - Button 1 press  (%d, %d)\n", x, y));
-#		endif
+#endif
 		return TRUE;
 	}
 
 	if (event->button == 2) {
 		/* Mouse button 2 was engaged */
-#		ifdef CODEDEBUG
+#ifdef CODEDEBUG
 		DEBUG(("displayer_opengl.c [glarea_button_release] - Button 2 press  (%d, %d)\n", x, y));
-#		endif
+#endif
 		return TRUE;
 	}
 
@@ -658,17 +595,17 @@ gint glarea_motion_notify (GtkWidget* widget, GdkEventMotion* event)
 	}
 
 	if (state & GDK_BUTTON1_MASK) {
-		/* Mouse button 1 is engaged */
-		#ifdef CODEDEBUG
+		// * Mouse button 1 is engaged *
+#ifdef CODEDEBUG
 		DEBUG(("displayer_opengl.c [glarea_motion_notify] - Button 1 motion  (%d, %d)\n", x, y));
-		#endif
+#endif
 	}
 
 	if (state & GDK_BUTTON2_MASK) {
-		/* Mouse button 2 is engaged */
-		#ifdef CODEDEBUG
+		// * Mouse button 2 is engaged *
+#ifdef CODEDEBUG
 		DEBUG(("displayer_opengl.c [glarea_motion_notify] - Button 2 motion  (%d, %d)\n", x, y));
-		#endif
+#endif
 	}
 
 	return TRUE;
@@ -702,3 +639,34 @@ static void displayer_opengl_limit_fps (gboolean init)
 	}
 }
 */
+
+void displayer_opengl_set_song(SingitSong *new_song)
+{
+	SingitSong *tmp_song;
+
+#ifdef CODEDEBUG
+	DEBUG(("displayer_opengl.c [displayer_opengl_set_song]\n"));
+#endif
+
+	tmp_song = STATUS->song;
+	STATUS->song = singit_song_attach(new_song);
+	singit_song_detach(&tmp_song);
+
+	g_return_if_fail(displayer_opengl_window != NULL);
+
+	STATUS->rotate =
+		!singit_song_lyrics_found(new_song);
+	opengl_lyrics_set_song(new_song);
+	gtk_widget_queue_draw(STATUS->gl_area_widget);
+/*
+	if (new_song && singit_song_lyrics_found(new_song)) {
+		if (!GTK_WIDGET_VISIBLE(displayer_opengl_window))
+			{ gtk_widget_show(displayer_opengl_window); }
+		else { gdk_window_raise(displayer_opengl_window->window); }
+	}
+	else {
+		if (GTK_WIDGET_VISIBLE(displayer_opengl_window))
+			gtk_widget_hide(displayer_opengl_window);
+	}
+*/
+}
