@@ -21,8 +21,9 @@
 #ifndef __DISPLAYER_OPENGL_H__
 #define __DISPLAYER_OPENGL_H__
 
-#include "singit_macros.h"
+#include "singit/macros.h"
 
 #include "displayer_opengl_status.h"
+#include "displayer_opengl_config.h"
 
 #endif // __DISPLAYER_OPENGL_H__
