@@ -21,7 +21,7 @@
 #ifndef __DISPLAYER_SDL_H__
 #define __DISPLAYER_SDL_H__
 
-#include "singit_macros.h"
+#include "singit/macros.h"
 
 #include "displayer_sdl_status.h"
 
