@@ -27,16 +27,14 @@
 #include <stdio.h>
 #include <string.h>
 
-#include <xmms/configfile.h>
+#include "singit/macros.h"
+#include "singit/config_gen.h"
 
-#include "singit_macros.h"
-#include "singit_config.h"
-
-#include "singit_config_gen.h"
+#include "displayer_sdl_status.h"
 #include "displayer_sdl_config.h"
 #include "displayer_sdl_config_dlg.h"
 
-#include "singit_wgt_colorbutton.h"
+#include "singit/wgt_colorbutton.h"
 
 static GtkWidget *displayer_sdl_config_win = NULL;
 static GtkWidget
@@ -83,15 +81,17 @@ typedef struct {
 
 	gboolean updating_displayer_list;
 
+	SingitConfigGen *sdl_cfg;
+
 } ConfigStatus;
 
 ConfigStatus displayer_sdl_config_status;
-extern SingitConfigGen *displayer_sdl_config;
 
 static void displayer_sdl_config_font_browse_ok(GtkWidget * w, gpointer data)
 {
-        gtk_entry_set_text(GTK_ENTRY(displayer_sdl_config_font_entry), 
-		gtk_file_selection_get_filename(GTK_FILE_SELECTION(displayer_sdl_config_fontsel)));
+        gtk_entry_set_text(GTK_ENTRY(displayer_sdl_config_font_entry),
+		gtk_file_selection_get_filename(GTK_FILE_SELECTION
+			(displayer_sdl_config_fontsel)));
         gtk_widget_destroy(displayer_sdl_config_fontsel);
 	displayer_sdl_config_fontsel = NULL;
 }
@@ -100,7 +100,7 @@ static void displayer_sdl_config_font_browse_cb(GtkWidget * w, gpointer data)
 {
 	if (displayer_sdl_config_fontsel != NULL)
 		{ return; }
-	
+
 	displayer_sdl_config_fontsel = gtk_file_selection_new(_("Select preferred TTF font"));
 	gtk_window_set_modal(GTK_WINDOW(displayer_sdl_config_fontsel), TRUE);
 
@@ -114,7 +114,7 @@ static void displayer_sdl_config_font_browse_cb(GtkWidget * w, gpointer data)
 		"clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy), (gpointer) displayer_sdl_config_fontsel);
 
 	gtk_file_selection_set_filename(GTK_FILE_SELECTION(displayer_sdl_config_fontsel),
-			GET_DSCD(displayer_sdl_config)->lyricFontName);
+			GET_DSCD->lyricFontName);
 	gtk_file_selection_complete(GTK_FILE_SELECTION(displayer_sdl_config_fontsel), "*.ttf");
 
 	gtk_window_set_transient_for(GTK_WINDOW(displayer_sdl_config_fontsel), GTK_WINDOW(displayer_sdl_config_win));
@@ -132,48 +132,45 @@ static void displayer_sdl_config_force_globals_toggle_event(GtkToggleButton *tog
 	gtk_widget_set_sensitive(displayer_sdl_config_hide_if_not_found_check_button, state);
 	gtk_widget_set_sensitive(displayer_sdl_config_show_empty_check_button, state);
 	gtk_widget_set_sensitive(displayer_sdl_config_auto_resize_check_button, state);
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	gtk_widget_set_sensitive(displayer_sdl_config_enable_debug_check_button, state);
-#	endif
+#endif
 }
 
 static void displayer_sdl_config_cleanup()
 {
-	SDLConfigData *scd = GET_DSCD(displayer_sdl_config);
-
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("dlg_singit_config.c [displayer_sdl_config_cleanup]\n"));
-#	endif
-
+#endif
+/*
 	if (displayer_sdl_config_win && displayer_sdl_config_win->window && scd) {
 		gdk_window_get_position(displayer_sdl_config_win->window,
 			&(scd->winPosX), &(scd->winPosY));
 //		displayer_sdl_config_save_positions();
 	}
-
+*/
 	g_free(displayer_sdl_config_status.color_array);
 
-	singit_config_gen_detach(SINGIT_CONFIG_GEN(displayer_sdl_config));
+	sdl_status_unref(NULL);
+
+	gtk_widget_destroy(displayer_sdl_config_win);
 }
 
 static void displayer_sdl_config_apply_clicked(GtkButton *button, gpointer user_data)
 {
+	SDLConfigData *scd;
 	gchar tmp[13];
-	SDLConfigData *scd = GET_DSCD(displayer_sdl_config);
 
-#	ifdef CODEDEBUG
-	DEBUG(("dlg_singit_config.c [displayer_sdl_config_apply_clicked] : "));
-#	endif
+#ifdef CODEDEBUG
+	DEBUG(("dlg_singit_config.c [displayer_sdl_config_apply_clicked]\n"));
+#endif
 
-	if (!(displayer_sdl_config_win &&
-		displayer_sdl_config_win->window &&
-		singit_config_gen_attach(displayer_sdl_config)))
-	{
-#		ifdef CODEDEBUG
-		DEBUG(("failed\n"));
-#		endif
-		return;
-	}
+	g_return_if_fail(displayer_sdl_config_win != NULL);
+	g_return_if_fail(GTK_WIDGET_REALIZED(displayer_sdl_config_win));
+	g_return_if_fail(STATUS != NULL);
+	g_return_if_fail(STATUS->config != NULL);
+
+	scd = GET_DSCD;
 
 	tmp[12] = '\0';
 
@@ -190,49 +187,37 @@ static void displayer_sdl_config_apply_clicked(GtkButton *button, gpointer user_
 	scd->hideIfNotFoundFullscreen = GTK_TOGGLE_BUTTON(displayer_sdl_config_hide_if_not_found_fullscreen_check_button)->active;
 	scd->optimizeFontSize = GTK_TOGGLE_BUTTON(displayer_sdl_config_optimize_font_size_check_button)->active;
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	scd->debugEnable = GTK_TOGGLE_BUTTON(displayer_sdl_config_enable_debug_check_button)->active;
-#	endif
+#endif
 
 	scd->lyricFontName = gtk_editable_get_chars(GTK_EDITABLE(displayer_sdl_config_font_entry), 0, -1);
 
 	scd->lyricFontSize =
 		gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(displayer_sdl_config_font_size_spinbutton));
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("Ok\n"));
-#	endif
+#endif
 
-	singit_config_gen_emit_update(SINGIT_CONFIG_GEN(displayer_sdl_config));
-	singit_config_gen_save(SINGIT_CONFIG_GEN(displayer_sdl_config));
-	singit_config_gen_detach(SINGIT_CONFIG_GEN(displayer_sdl_config));
+	singit_config_gen_emit_update(STATUS->config);
+	singit_config_gen_save(STATUS->config);
 }
 
 static void displayer_sdl_config_ok_clicked(GtkButton *button, gpointer user_data)
 {
-	/* apply and save config */
 	displayer_sdl_config_apply_clicked(NULL, NULL);
 	displayer_sdl_config_cleanup();
-
-	/* close and destroy window */
-	gtk_widget_destroy(displayer_sdl_config_win);
 }
 
 static void displayer_sdl_config_cancel_clicked(GtkButton *button, gpointer user_data)
 {
 	displayer_sdl_config_cleanup();
-
-	/* close and destroy window */
-	gtk_widget_destroy(displayer_sdl_config_win);
 }
 
 static gint dlg_displayer_sdl_config_delete_event( GtkWidget *widget, GdkEvent  *event, gpointer data )
 {
 	displayer_sdl_config_cleanup();
-
-	/* close and destroy window */
-	gtk_widget_destroy(displayer_sdl_config_win);
-
 	return (FALSE);
 }
 
@@ -241,22 +226,21 @@ void displayer_sdl_config_show(void)
 	SDLConfigData *scd;
 	gchar *temp;
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("dlg_singit_config.c [displayer_sdl_config_show]\n"));
-#	endif
+#endif
 
 	if (displayer_sdl_config_win) {
 		gdk_window_raise(displayer_sdl_config_win->window);
 		return;
 	}
 
-	if (!singit_config_gen_attach(displayer_sdl_config)) {
-		displayer_sdl_config = displayer_sdl_config_new();
-		singit_config_gen_load(SINGIT_CONFIG_GEN(displayer_sdl_config));
-	}
-	scd = GET_DSCD(displayer_sdl_config);
+	if (sdl_status_ref() == NULL)
+		{ return; }
+
+	scd = GET_DSCD;
 	if (!scd) {
-		singit_config_gen_detach(SINGIT_CONFIG_GEN(displayer_sdl_config));
+		sdl_status_unref(NULL);
 		return;
 	}
 
@@ -350,16 +334,16 @@ void displayer_sdl_config_show(void)
 
 	displayer_sdl_config_font_size_spinbutton_adj = gtk_adjustment_new
 		(scd->lyricFontSize, 8, 50, 1, 1, 1);
-	displayer_sdl_config_font_size_spinbutton = 
+	displayer_sdl_config_font_size_spinbutton =
 		gtk_spin_button_new(GTK_ADJUSTMENT(displayer_sdl_config_font_size_spinbutton_adj), 1, 0);
 	gtk_entry_set_max_length(GTK_ENTRY(displayer_sdl_config_font_size_spinbutton), 2);
-	gtk_box_pack_start(GTK_BOX(displayer_sdl_config_font_size_hbox), 
+	gtk_box_pack_start(GTK_BOX(displayer_sdl_config_font_size_hbox),
 		displayer_sdl_config_font_size_spinbutton, FALSE, FALSE, 2);
 	gtk_widget_show (displayer_sdl_config_font_size_spinbutton);
-	
-	displayer_sdl_config_optimize_font_size_check_button = 
+
+	displayer_sdl_config_optimize_font_size_check_button =
 		gtk_check_button_new_with_label(_("Optimize font size"));
-	gtk_box_pack_start(GTK_BOX(displayer_sdl_config_font_vbox), 
+	gtk_box_pack_start(GTK_BOX(displayer_sdl_config_font_vbox),
 		displayer_sdl_config_optimize_font_size_check_button, FALSE, FALSE, 0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(displayer_sdl_config_optimize_font_size_check_button),
 		scd->optimizeFontSize);
@@ -394,13 +378,13 @@ void displayer_sdl_config_show(void)
 		scd->hideIfNotFound);
 	gtk_widget_show(displayer_sdl_config_hide_if_not_found_check_button);
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	displayer_sdl_config_enable_debug_check_button = gtk_check_button_new_with_label(_("Enable console debug output"));
 	gtk_box_pack_start(GTK_BOX(displayer_sdl_config_displayer_toggle_vbox), displayer_sdl_config_enable_debug_check_button, FALSE, FALSE, 0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(displayer_sdl_config_enable_debug_check_button),
 		scd->debugEnable);
 	gtk_widget_show(displayer_sdl_config_enable_debug_check_button);
-#	endif
+#endif
 
 	displayer_sdl_config_1_hsep = gtk_hseparator_new();
 	gtk_box_pack_start(GTK_BOX(displayer_sdl_config_displayer_toggle_vbox), displayer_sdl_config_1_hsep, FALSE, FALSE, 3);
@@ -458,9 +442,9 @@ void displayer_sdl_config_show(void)
 
 void displayer_sdl_config_hide(void)
 {
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("dlg_singit_config.c [displayer_sdl_config_hide]\n"));
-#	endif
+#endif
 
 	if (displayer_sdl_config_win) {
 		displayer_sdl_config_cancel_clicked(NULL, NULL);
