@@ -29,7 +29,7 @@
 
 #include "SDL_prim.h"
 
-#include "singit_displayer_plugin.h"
+#include "singit/displayer_plugin.h"
 #include "displayer_sdl.h"
 
 #include "displayer_sdl_config.h"
@@ -86,39 +86,90 @@ typedef struct _SDLLyrics {
 }
 SDLLyrics;
 
-#define SDL_LYRICS_INITIALIZER { NULL, NULL, -1, NULL, NULL, NULL, NULL, \
-	NULL, { 0, 0, 0, 0 }, 0, { 0, 0, 0, 0 }, 0, { 0, 0, 0, 0 }, 0, \
-	{ 0, 0, 0, 0 }, 0, { 0, 0, 0, 0 }, NULL, NULL, 0, \
-	-1, -1, FALSE, FALSE, 0, 0, 0, 0, FALSE, FALSE, \
-	PTHREAD_MUTEX_INITIALIZER }
-
 #define MIN_BORDER(font) (TTF_FontHeight(font))
-#define LINE_WIDTH(font) (displayer_sdl_status.screen->w - 2 * MIN_BORDER(font))
+#define LINE_WIDTH(font) (STATUS->screen->w - 2 * MIN_BORDER(font))
 
-static SDLLyrics sdl_lyrics = SDL_LYRICS_INITIALIZER;
+static SDLLyrics sdl_lyrics;
 
 extern DisplayerPlugin sdl_dp;
-extern SingitConfigGen *displayer_sdl_config;
 
 static void lyrics_optimize_font(gboolean lock);
 static void sdl_lyrics_resize_real(gboolean lock);
 
+static inline void set_sdl_color
+	(SDL_Color *col, Uint8 r, Uint8 g, Uint8 b, Uint8 a)
+{
+	col->r = r;
+	col->g = g;
+	col->b = b;
+	col->unused = a;
+}
+
+static inline void set_sdl_rect
+	(SDL_Rect *rect, Sint16 x, Sint16 y, Uint16 w, Uint16 h)
+{
+	rect->x = x;
+	rect->y = y;
+	rect->w = w;
+	rect->h = h;
+}
+
 void sdl_lyrics_init(void)
 {
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("displayer_sdl.c [lyrics_init]\n"));
-#	endif
+#endif
+
+	sdl_lyrics.song = NULL;
+	sdl_lyrics.last_token = NULL;
+	sdl_lyrics.last_line = -1;
+
+	sdl_lyrics.first_line = NULL;
+	sdl_lyrics.second_line = NULL;
+	sdl_lyrics.blurred_line = NULL;
+	sdl_lyrics.progress_line = NULL;
+
+	sdl_lyrics.active_line = NULL;
+
+	set_sdl_color(&sdl_lyrics.active_text_color, 0, 0, 0, 0);
+	sdl_lyrics.active_text_color_mapped = 0;
+
+	set_sdl_color(&sdl_lyrics.passive_text_color, 0, 0, 0, 0);
+	sdl_lyrics.passive_text_color_mapped = 0;
+
+	set_sdl_color(&sdl_lyrics.blurred_text_color, 0, 0, 0, 0);
+	sdl_lyrics.blurred_text_color_mapped = 0;
+
+	set_sdl_color(&sdl_lyrics.background_color, 0, 0, 0, 0);
+	sdl_lyrics.background_color_mapped = 0;
+
+	set_sdl_rect(&sdl_lyrics.clip_rect, 0, 0, 0, 0);
+
+	sdl_lyrics.font = NULL;
+	sdl_lyrics.font_file_name = NULL;
+	sdl_lyrics.font_size = 0;
+	sdl_lyrics.font_size_optimized = -1;
+	sdl_lyrics.font_line_skip = -1;
+
+	sdl_lyrics.color_changed = FALSE;
+	sdl_lyrics.real_color_change = FALSE;
+
+	sdl_lyrics.longest_line = 0;
+	sdl_lyrics.longest_line_length = 0;
+	sdl_lyrics.ball_diameter = 0;
+	sdl_lyrics.min_width = 0;
 
 	sdl_lyrics.draw_mode = FALSE;
+	sdl_lyrics.optimize_font_size = FALSE;
 
 	pthread_mutex_init(&sdl_lyrics.lyrics_draw_mutex, NULL);
 }
 
 void sdl_lyrics_finish(void)
 {
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("displayer_sdl.c [lyrics_finish]\n"));
-#	endif
+#endif
 
 	pthread_mutex_destroy(&sdl_lyrics.lyrics_draw_mutex);
 
@@ -158,22 +209,22 @@ void sdl_lyrics_finish(void)
 void sdl_lyrics_remap_colors()
 {
 	sdl_lyrics.active_text_color_mapped = SDL_MapRGB
-		(displayer_sdl_status.screen->format,
+		(STATUS->screen->format,
 		sdl_lyrics.active_text_color.r, sdl_lyrics.active_text_color.g,
 		sdl_lyrics.active_text_color.b);
 
 	sdl_lyrics.passive_text_color_mapped = SDL_MapRGB
-		(displayer_sdl_status.screen->format,
+		(STATUS->screen->format,
 		sdl_lyrics.passive_text_color.r, sdl_lyrics.passive_text_color.g,
 		sdl_lyrics.passive_text_color.b);
 
 	sdl_lyrics.blurred_text_color_mapped = SDL_MapRGB
-		(displayer_sdl_status.screen->format,
+		(STATUS->screen->format,
 		sdl_lyrics.blurred_text_color.r, sdl_lyrics.blurred_text_color.g,
 		sdl_lyrics.blurred_text_color.b);
 
 	sdl_lyrics.background_color_mapped = SDL_MapRGB
-		(displayer_sdl_status.screen->format,
+		(STATUS->screen->format,
 		sdl_lyrics.background_color.r, sdl_lyrics.background_color.g,
 		sdl_lyrics.background_color.b);
 
@@ -272,7 +323,7 @@ static gboolean lyrics_set_font_int(const gchar *font_file, gint ptsize,
 		sdl_lyrics.min_width = sdl_lyrics.ball_diameter * 16;
 
 		if (refresh)
-			sdl_lyrics_resize();
+			sdl_lyrics_resize_real(FALSE);
 		if (lock)
 			pthread_mutex_unlock(&sdl_lyrics.lyrics_draw_mutex);
 	}
@@ -661,7 +712,7 @@ static void sdl_lyrics_resize_real(gboolean lock)
 	}
 
 	sdl_lyrics.clip_rect.x =
-		(int) (displayer_sdl_status.screen->w - sdl_lyrics.longest_line_length) / 2;
+		(int) (STATUS->screen->w - sdl_lyrics.longest_line_length) / 2;
 	if (sdl_lyrics.clip_rect.x < MIN_BORDER(sdl_lyrics.font)) {
 		sdl_lyrics.clip_rect.x = MIN_BORDER(sdl_lyrics.font);
 		w = LINE_WIDTH(sdl_lyrics.font);
@@ -674,7 +725,7 @@ static void sdl_lyrics_resize_real(gboolean lock)
 		{ w = sdl_lyrics.min_width; }
 
 	sdl_lyrics.clip_rect.w = w;
-	sdl_lyrics.clip_rect.y = displayer_sdl_status.screen->h -
+	sdl_lyrics.clip_rect.y = STATUS->screen->h -
 		sdl_lyrics.font_line_skip -
 		TTF_FontHeight(sdl_lyrics.font) - MIN_BORDER(sdl_lyrics.font);
 	sdl_lyrics.clip_rect.h = sdl_lyrics.font_line_skip;
