@@ -29,12 +29,11 @@
 #include <SDL/SDL_syswm.h>
 #include <SDL/SDL_ttf.h>
 
-#include "singit_displayer_plugin.h"
+#include "singit/displayer_plugin.h"
 #include "displayer_sdl.h"
 #include "displayer_sdl_config.h"
 #include "sdl_skd_handlers.h"
 
-extern SingitConfigGen *displayer_sdl_config;
 
 static gint sdl_skd_render(SingitKaraokeData *skd, gpointer font, gchar* text)
 {
@@ -182,23 +181,23 @@ static gboolean sdl_skd_expose(SingitKaraokeData *skd, GdkRectangle *area, gint
 			sdl_skd_update_ball(skw, offset);
 		}
 
-		if ((displayer_sdl_status.timeIndicators == FALSE) || (event & SKD_EXPOSE_TIMELINE) != event) {
+		if ((STATUS->timeIndicators == FALSE) || (event & SKD_EXPOSE_TIMELINE) != event) {
 //			g_print("Expose-Area: %i\n", time);
 			gtk_widget_queue_draw_area(GTK_WIDGET(user_data),
-				area->x + displayer_sdl_status.sizes[LEFT_RIGHT_WIDGET_BORDER],
-				area->y + displayer_sdl_status.sizes[TOP_BOTTOM_WIDGET_BORDER],
+				area->x + STATUS->sizes[LEFT_RIGHT_WIDGET_BORDER],
+				area->y + STATUS->sizes[TOP_BOTTOM_WIDGET_BORDER],
 				area->width, area->height);
 		}
 //	}
 
-	if ((displayer_sdl_status.timeIndicators == TRUE) && (event & SKD_EXPOSE_TIMELINE)) {
+	if ((STATUS->timeIndicators == TRUE) && (event & SKD_EXPOSE_TIMELINE)) {
 		if ((event & SKD_EXPOSE_TIMELINE) == event) {
 //			g_print("Timeline: %i\n", time);
 			combined_area = *area;
 			draw_timeline(skw, time, &combined_area);
 			gtk_widget_queue_draw_area(GTK_WIDGET(user_data),
-				combined_area.x + displayer_sdl_status.sizes[LEFT_RIGHT_WIDGET_BORDER],
-				combined_area.y + displayer_sdl_status.sizes[TOP_BOTTOM_WIDGET_BORDER],
+				combined_area.x + STATUS->sizes[LEFT_RIGHT_WIDGET_BORDER],
+				combined_area.y + STATUS->sizes[TOP_BOTTOM_WIDGET_BORDER],
 				combined_area.width, combined_area.height);
 		}
 	}
@@ -212,17 +211,17 @@ void draw_timeline(SingitKaraokeWidget *skw, gint time, GdkRectangle *area)
 	GList *next_item, *current;
 	GdkGC *draw_gc = NULL;
 	gint balls, light_balls;
-	gint pos_x = SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter / 2 + 1;
-	gint pos_y = SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->top_lines_height +
-		(SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->text_line_height - SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter) / 2;
+	gint pos_x = SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter / 2 + 1;
+	gint pos_y = SINGIT_KARAOKE_DATA(STATUS->skd)->top_lines_height +
+		(SINGIT_KARAOKE_DATA(STATUS->skd)->text_line_height - SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter) / 2;
 	GdkRectangle area_update;
 	gboolean big_ball;
 
-	if (displayer_sdl_status.double_buffer_pixmap == NULL) { return; }
+	if (STATUS->double_buffer_pixmap == NULL) { return; }
 
-	current = SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->song->active_token;
+	current = SINGIT_KARAOKE_DATA(STATUS->skd)->song->active_token;
 	if (current == NULL) { return; }
-	next_item = inl_singit_song_get_next_token(SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->song);
+	next_item = inl_singit_song_get_next_token(SINGIT_KARAOKE_DATA(STATUS->skd)->song);
 	if (next_item == NULL) { return; }
 	balls = (tTime(next_item) - tTime(current)) / 1000;
 	if (balls < 2) { return; }
@@ -237,47 +236,47 @@ void draw_timeline(SingitKaraokeWidget *skw, gint time, GdkRectangle *area)
 		balls = 10;
 	}
 
-	if (SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->use_ball) {
-		pos_y += SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_line_height +
-			SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->line_seperator_high;
+	if (SINGIT_KARAOKE_DATA(STATUS->skd)->use_ball) {
+		pos_y += SINGIT_KARAOKE_DATA(STATUS->skd)->ball_line_height +
+			SINGIT_KARAOKE_DATA(STATUS->skd)->line_seperator_high;
 	}
 
 	draw_gc = gdk_gc_new (GTK_WIDGET(skw)->window);
 	gdk_gc_set_fill (draw_gc, GDK_SOLID);
-	gdk_gc_set_foreground (draw_gc, &displayer_sdl_status.private_color[skwc_active]);
+	gdk_gc_set_foreground (draw_gc, &STATUS->private_color[skwc_active]);
 
 	area_update.x = pos_x;
 	area_update.y = pos_y;
-	area_update.width = SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter * 2 * balls;
-	area_update.height = SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter;
+	area_update.width = SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter * 2 * balls;
+	area_update.height = SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter;
 	gdk_rectangle_union(area, &area_update, area);
 
-	big_ball = (SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter > 5);
+	big_ball = (SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter > 5);
 	while (balls > 0) {
 		if (big_ball) {
-			gdk_gc_set_foreground (draw_gc, &displayer_sdl_status.private_color[skwc_text]);
+			gdk_gc_set_foreground (draw_gc, &STATUS->private_color[skwc_text]);
 		}
 		else {
 			if (balls > light_balls)
-				gdk_gc_set_foreground (draw_gc, &displayer_sdl_status.private_color[skwc_active]);
+				gdk_gc_set_foreground (draw_gc, &STATUS->private_color[skwc_active]);
 			else
-				gdk_gc_set_foreground (draw_gc, &displayer_sdl_status.private_color[skwc_text]);
+				gdk_gc_set_foreground (draw_gc, &STATUS->private_color[skwc_text]);
 		}
 
-		gdk_draw_arc (displayer_sdl_status.double_buffer_pixmap, draw_gc, TRUE, pos_x, pos_y,
-			SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter,
-			SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter, 0, 360 * 64);
+		gdk_draw_arc (STATUS->double_buffer_pixmap, draw_gc, TRUE, pos_x, pos_y,
+			SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter,
+			SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter, 0, 360 * 64);
 
 		if (big_ball && (balls > light_balls)) {
-			gdk_gc_set_foreground (draw_gc, &displayer_sdl_status.private_color[skwc_active]);
+			gdk_gc_set_foreground (draw_gc, &STATUS->private_color[skwc_active]);
 
-			gdk_draw_arc (displayer_sdl_status.double_buffer_pixmap, draw_gc, TRUE, 2 + pos_x, pos_y + 2,
-				SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter - 4,
-				SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter - 4, 0, 360 * 64);
+			gdk_draw_arc (STATUS->double_buffer_pixmap, draw_gc, TRUE, 2 + pos_x, pos_y + 2,
+				SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter - 4,
+				SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter - 4, 0, 360 * 64);
 		}
 
 		balls--;
-		pos_x += SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter * 2;
+		pos_x += SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter * 2;
 	}
 
 	gdk_gc_unref(draw_gc);
@@ -292,45 +291,45 @@ void create_new_ball_pixmap(SingitKaraokeWidget *skw)
 
 	if (!GTK_WIDGET_REALIZED(skw)) { return; }
 
-#	ifdef WIDGET_DEBUG
+#ifdef WIDGET_DEBUG
 	g_print("New ball pixmap\n");
-#	endif
+#endif
 
-	if (displayer_sdl_status.ball_pixmap != NULL)
-		{ gdk_pixmap_unref(displayer_sdl_status.ball_pixmap); }
+	if (STATUS->ball_pixmap != NULL)
+		{ gdk_pixmap_unref(STATUS->ball_pixmap); }
 
-	if (SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter <= 0) {
-		displayer_sdl_status.ball_pixmap = NULL;
+	if (SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter <= 0) {
+		STATUS->ball_pixmap = NULL;
 		return;
 	}
 
 	draw_gc = gdk_gc_new (GTK_WIDGET(skw)->window);
 	gdk_gc_set_fill (draw_gc, GDK_SOLID);
-	gdk_gc_set_foreground (draw_gc, &displayer_sdl_status.private_color[skwc_background]);
+	gdk_gc_set_foreground (draw_gc, &STATUS->private_color[skwc_background]);
 
-	displayer_sdl_status.ball_pixmap = gdk_pixmap_new(GTK_WIDGET(skw)->window,
-		SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter, SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter, -1);
-	gdk_draw_rectangle(displayer_sdl_status.ball_pixmap, draw_gc, TRUE, 0, 0,
-		SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter, SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter);
+	STATUS->ball_pixmap = gdk_pixmap_new(GTK_WIDGET(skw)->window,
+		SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter, SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter, -1);
+	gdk_draw_rectangle(STATUS->ball_pixmap, draw_gc, TRUE, 0, 0,
+		SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter, SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter);
 
-	gdk_gc_set_foreground (draw_gc, &displayer_sdl_status.private_color[skwc_text]);
-	gdk_draw_arc (displayer_sdl_status.ball_pixmap, draw_gc, TRUE, 0, 0,
-			SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter, SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter, 0, 360 * 64);
+	gdk_gc_set_foreground (draw_gc, &STATUS->private_color[skwc_text]);
+	gdk_draw_arc (STATUS->ball_pixmap, draw_gc, TRUE, 0, 0,
+			SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter, SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter, 0, 360 * 64);
 
-	if (SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter > 5) {
-		gdk_gc_set_foreground (draw_gc, &displayer_sdl_status.private_color[skwc_active]);
-#	ifdef WIDGET_DEBUG
-		g_print("  Ball-Sizes: %i / %i / %i\n", SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter,
-			SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter / 8,
-			SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter / 4);
-#	endif
-		gdk_draw_arc (displayer_sdl_status.ball_pixmap, draw_gc, TRUE,
-			2 + (SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter / 8),
-			2 + (SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter / 8),
-			SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter - 4
-			- (SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter / 4),
-			SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter - 4
-			- (SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_diameter / 4),
+	if (SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter > 5) {
+		gdk_gc_set_foreground (draw_gc, &STATUS->private_color[skwc_active]);
+#ifdef WIDGET_DEBUG
+		g_print("  Ball-Sizes: %i / %i / %i\n", SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter,
+			SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter / 8,
+			SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter / 4);
+#endif
+		gdk_draw_arc (STATUS->ball_pixmap, draw_gc, TRUE,
+			2 + (SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter / 8),
+			2 + (SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter / 8),
+			SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter - 4
+			- (SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter / 4),
+			SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter - 4
+			- (SINGIT_KARAOKE_DATA(STATUS->skd)->ball_diameter / 4),
 			0, 360 * 64);
 	}
 
@@ -346,33 +345,33 @@ void skw_draw_line_rects(SingitKaraokeWidget *skw, GdkPixmap *pixmap, GdkGC *dra
 
 	if ((pixmap == NULL) || (draw_gc == NULL)) { return; }
 
-#	ifdef WIDGET_DEBUG
+#ifdef WIDGET_DEBUG
 	g_print("skw_draw_line_rects\n");
-#	endif
+#endif
 
 	height = 0;
-	for (i = 0; i < SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->top_lines; i++) {
+	for (i = 0; i < SINGIT_KARAOKE_DATA(STATUS->skd)->top_lines; i++) {
 		gdk_draw_rectangle(pixmap, draw_gc,
-			TRUE, 0,height, SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->visual_min_width,
-			SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->text_line_height);
-		height += SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->text_line_height +
-			SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->line_seperator_high;
+			TRUE, 0,height, SINGIT_KARAOKE_DATA(STATUS->skd)->visual_min_width,
+			SINGIT_KARAOKE_DATA(STATUS->skd)->text_line_height);
+		height += SINGIT_KARAOKE_DATA(STATUS->skd)->text_line_height +
+			SINGIT_KARAOKE_DATA(STATUS->skd)->line_seperator_high;
 	}
-	height += SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->active_line_seperator_high;
+	height += SINGIT_KARAOKE_DATA(STATUS->skd)->active_line_seperator_high;
 
-	if (SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->use_ball) {
+	if (SINGIT_KARAOKE_DATA(STATUS->skd)->use_ball) {
 		gdk_draw_rectangle(pixmap, draw_gc,
-			TRUE, 0, height, SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->visual_min_width,
-			SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_line_height);
-		height += SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->ball_line_height + SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->line_seperator_high;
+			TRUE, 0, height, SINGIT_KARAOKE_DATA(STATUS->skd)->visual_min_width,
+			SINGIT_KARAOKE_DATA(STATUS->skd)->ball_line_height);
+		height += SINGIT_KARAOKE_DATA(STATUS->skd)->ball_line_height + SINGIT_KARAOKE_DATA(STATUS->skd)->line_seperator_high;
 	}
 
-	for (i = 0; i < (SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->lines - SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->top_lines); i++) {
+	for (i = 0; i < (SINGIT_KARAOKE_DATA(STATUS->skd)->lines - SINGIT_KARAOKE_DATA(STATUS->skd)->top_lines); i++) {
 		gdk_draw_rectangle(pixmap, draw_gc,
-			TRUE, 0,height, SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->visual_min_width,
-			SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->text_line_height);
-		height += SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->text_line_height + SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->line_seperator_high;
-		if (i == 0) { height += SINGIT_KARAOKE_DATA(displayer_sdl_status.skd)->active_line_seperator_high; }
+			TRUE, 0,height, SINGIT_KARAOKE_DATA(STATUS->skd)->visual_min_width,
+			SINGIT_KARAOKE_DATA(STATUS->skd)->text_line_height);
+		height += SINGIT_KARAOKE_DATA(STATUS->skd)->text_line_height + SINGIT_KARAOKE_DATA(STATUS->skd)->line_seperator_high;
+		if (i == 0) { height += SINGIT_KARAOKE_DATA(STATUS->skd)->active_line_seperator_high; }
 	}
 }
 */
@@ -390,35 +389,35 @@ static void sdl_skd_new_ball(SingitKaraokeData *skd, gint ball_diameter, gpointe
 
 	skw = SINGIT_KARAOKE_WIDGET(user_data);
 
-#	ifdef WIDGET_DEBUG
+#ifdef WIDGET_DEBUG
 	g_print("New ball pixmap\n");
-#	endif
+#endif
 
-	if (displayer_sdl_status.ball_pixmap != NULL)
-		{ gdk_pixmap_unref(displayer_sdl_status.ball_pixmap); }
+	if (STATUS->ball_pixmap != NULL)
+		{ gdk_pixmap_unref(STATUS->ball_pixmap); }
 
 	if (ball_diameter <= 0) {
-		displayer_sdl_status.ball_pixmap = NULL;
+		STATUS->ball_pixmap = NULL;
 		return;
 	}
 
 	draw_gc = gdk_gc_new (GTK_WIDGET(skw)->window);
 	gdk_gc_set_fill (draw_gc, GDK_SOLID);
-	gdk_gc_set_foreground (draw_gc, &displayer_sdl_status.private_color[skwc_background]);
+	gdk_gc_set_foreground (draw_gc, &STATUS->private_color[skwc_background]);
 
-	displayer_sdl_status.ball_pixmap = gdk_pixmap_new(GTK_WIDGET(skw)->window,
+	STATUS->ball_pixmap = gdk_pixmap_new(GTK_WIDGET(skw)->window,
 		ball_diameter, ball_diameter, -1);
-	gdk_draw_rectangle(displayer_sdl_status.ball_pixmap, draw_gc, TRUE, 0, 0,
+	gdk_draw_rectangle(STATUS->ball_pixmap, draw_gc, TRUE, 0, 0,
 		ball_diameter, ball_diameter);
 
-	gdk_gc_set_foreground (draw_gc, &displayer_sdl_status.private_color[skwc_text]);
-	gdk_draw_arc (displayer_sdl_status.ball_pixmap, draw_gc, TRUE, 0, 0,
+	gdk_gc_set_foreground (draw_gc, &STATUS->private_color[skwc_text]);
+	gdk_draw_arc (STATUS->ball_pixmap, draw_gc, TRUE, 0, 0,
 			ball_diameter, ball_diameter, 0, 360 * 64);
 
 	if (ball_diameter > 5) {
-		gdk_gc_set_foreground (draw_gc, &displayer_sdl_status.private_color[skwc_active]);
+		gdk_gc_set_foreground (draw_gc, &STATUS->private_color[skwc_active]);
 
-		gdk_draw_arc (displayer_sdl_status.ball_pixmap, draw_gc, TRUE, 2, 2,
+		gdk_draw_arc (STATUS->ball_pixmap, draw_gc, TRUE, 2, 2,
 			ball_diameter - 4, ball_diameter - 4, 0, 360 * 64);
 	}
 
@@ -440,9 +439,9 @@ static void sdl_skd_new_visual(SingitKaraokeData *skd, gint wx, gint wy, gpointe
 
 	skw = SINGIT_KARAOKE_WIDGET(user_data);
 
-#	ifdef WIDGET_DEBUG
+#ifdef WIDGET_DEBUG
 	g_print("New doublebuffer pixmap\n");
-#	endif
+#endif
 
 	if (skw->double_buffer_pixmap)
 		{ gdk_pixmap_unref(skw->double_buffer_pixmap); }
@@ -468,29 +467,29 @@ static void sdl_skd_new_visual(SingitKaraokeData *skd, gint wx, gint wy, gpointe
 
 void sdl_skd_init(void)
 {
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("displayer_sdl.c [sdl_skd_init]\n"));
-#	endif
+#endif
 
-	displayer_sdl_status.skd = (gpointer) singit_karaoke_data_new();
-	singit_karaoke_data_set_lines(displayer_sdl_status.skd, 2);
-	singit_karaoke_data_set_toplines(displayer_sdl_status.skd, 1);
-	singit_karaoke_data_set_font(displayer_sdl_status.skd, 
-		displayer_sdl_status.font, TTF_FontHeight(displayer_sdl_status.font));
-	gtk_signal_connect(GTK_OBJECT(displayer_sdl_status.skd), "render", GTK_SIGNAL_FUNC(sdl_skd_render), NULL);
-	gtk_signal_connect(GTK_OBJECT(displayer_sdl_status.skd), "expose", GTK_SIGNAL_FUNC(sdl_skd_expose), NULL);
-	gtk_signal_connect(GTK_OBJECT(displayer_sdl_status.skd), "new_ball", GTK_SIGNAL_FUNC(sdl_skd_new_ball), NULL);
-	gtk_signal_connect(GTK_OBJECT(displayer_sdl_status.skd), "new_visual", GTK_SIGNAL_FUNC(sdl_skd_new_visual), NULL);
+	STATUS->skd = (gpointer) singit_karaoke_data_new();
+	singit_karaoke_data_set_lines(STATUS->skd, 2);
+	singit_karaoke_data_set_toplines(STATUS->skd, 1);
+	singit_karaoke_data_set_font(STATUS->skd,
+		STATUS->font, TTF_FontHeight(STATUS->font));
+	gtk_signal_connect(GTK_OBJECT(STATUS->skd), "render", GTK_SIGNAL_FUNC(sdl_skd_render), NULL);
+	gtk_signal_connect(GTK_OBJECT(STATUS->skd), "expose", GTK_SIGNAL_FUNC(sdl_skd_expose), NULL);
+	gtk_signal_connect(GTK_OBJECT(STATUS->skd), "new_ball", GTK_SIGNAL_FUNC(sdl_skd_new_ball), NULL);
+	gtk_signal_connect(GTK_OBJECT(STATUS->skd), "new_visual", GTK_SIGNAL_FUNC(sdl_skd_new_visual), NULL);
 }
 
 void sdl_skd_finish(void)
 {
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(("displayer_sdl.c [displayer_sdl_finish]\n"));
-#	endif
+#endif
 
-	if (displayer_sdl_status.skd != NULL) {
-		gtk_object_unref(GTK_OBJECT(displayer_sdl_status.skd));
-		displayer_sdl_status.skd = NULL;
+	if (STATUS->skd != NULL) {
+		gtk_object_unref(GTK_OBJECT(STATUS->skd));
+		STATUS->skd = NULL;
 	}
 }
