@@ -26,20 +26,7 @@ void displayer_test_msg_status_init(void)
 {
 	displayer_test_msg_status.song = NULL;
 
-	displayer_test_msg_status.is_fullscreen = FALSE;
-
-	displayer_test_msg_status.time = 0;
-
-	displayer_test_msg_status.jump_to_song = -1;
-
-	displayer_test_msg_status.kill = FALSE;
-	displayer_test_msg_status.timeout = 0;
-
 	displayer_test_msg_status.xmms_playing = FALSE;
-	displayer_test_msg_status.singit_playing = FALSE;
-
-	displayer_test_msg_status.hideIfNotFound = FALSE;
-	displayer_test_msg_status.hideIfNotFoundFullscreen = FALSE;
 }
 
 void displayer_test_msg_status_finish(void)
