@@ -21,7 +21,7 @@
 #ifndef __DISPLAYER_TEST_MSG_STATUS_H__
 #define __DISPLAYER_TEST_MSG_STATUS_H__
 
-#include "singit_song.h"
+#include "singit/song.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -31,20 +31,9 @@ typedef struct _TestMSGStatus
 {
 	SingitSong *song;
 
-	gboolean is_fullscreen;
-
 	guint time;
 
-	gint jump_to_song;
-
-	gboolean kill;
-	guint timeout;
-
 	gboolean xmms_playing;
-	gboolean singit_playing;
-
-	gboolean hideIfNotFound;
-	gboolean hideIfNotFoundFullscreen;
 }
 TestMSGStatus;
 
