@@ -21,23 +21,20 @@
 #ifndef __DISPLAYER_TEST_SDL_H__
 #define __DISPLAYER_TEST_SDL_H__
 
-#include "singit_song.h"
-#include "singit_macros.h"
-#include "singit_karaoke_data.h"
+#include <glib.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif // __cplusplus
+#include "displayer_test_sdl_status.h"
 
-#define MY_SDL_MUSTLOCK(sf) \
-	(SDL_MUSTLOCK((SDL_Surface*) sf) && (SDL_LockSurface((SDL_Surface*) sf) == 0))
-#define MY_SDL_UNLOCK(sf) \
-	((SDL_MUSTLOCK((SDL_Surface*) sf) && (SDL_UnlockSurface((SDL_Surface*) sf)))
+#include "singit/macros.h"
 
-#define DEBUG(x) g_print x
+#define DEBUG(a) g_print a
 
-#ifdef __cplusplus
-}
-#endif // __cplusplus
+#define MY_SDL_MUSTLOCK(sf) (SDL_MUSTLOCK((SDL_Surface*) sf) && \
+	(SDL_LockSurface((SDL_Surface*) sf) == 0))
+#define MY_SDL_UNLOCK(sf) ((SDL_MUSTLOCK((SDL_Surface*) sf) && \
+	(SDL_UnlockSurface((SDL_Surface*) sf)))
+
+gint displayer_test_sdl_disable_func(gpointer data);
+void displayer_test_sdl_get_position(gint *x, gint *y);
 
 #endif // __DISPLAYER_TEST_SDL_H__
