@@ -1,6 +1,6 @@
 /*
  *  SingIt Lyrics Displayer
- *  Copyright (C) 2000 - 2002 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
+ *  Copyright (C) 2000 - 2003 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,71 +28,48 @@
 #include <xmms/plugin.h>
 #include <xmms/xmmsctrl.h>
 
-#include "singit_debug.h"
-#include "singit_config.h"
+#include "singit/song.h"
 
-#include "singit_song.h"
+#include "singit_debug.h"
 #include "singit_song_private.h"
 #include "editor_singit_main.h"
-#include "editor_singit_private.h"
 #include "editor_config.h"
+#include "editor_status.h"
 
 #include "editor_clist_timestamps.h"
 
-enum {
-	ARG_0,
-	ARG_CURSOR_TEXT_OFFSET
-};
+static SingitEditorViewClass *parent_class = NULL;
 
-extern EditorStatus editor_status;
 extern VisPlugin singit_vp;
-extern SingitConfigGen *editor_config;
-extern SingitConfigGen *singit_config;
-
-static GtkBinClass *parent_class = NULL;
 
 static gboolean editor_clist_timestamps_keypress(GtkWidget *widget, GdkEventKey *event, gpointer data);
 static gboolean editor_clist_clicked_event(GtkWidget *widget, GdkEventButton *event, gpointer user_data);
 static void editor_clist_select_row_event(GtkWidget *widget, gint row, gint column, GdkEventButton *event, gpointer user_data);
 
-static void editor_clist_timestamps_set_arg (GtkObject *object, GtkArg *arg, guint arg_id);
-static void editor_clist_timestamps_get_arg (GtkObject *object, GtkArg *arg, guint arg_id);
 static void editor_clist_timestamps_destroy (GtkObject *object);
-static void editor_clist_timestamps_draw (GtkWidget *widget, GdkRectangle *area);
-static gint editor_clist_timestamps_expose (GtkWidget *widget, GdkEventExpose *event);
-static void editor_clist_timestamps_size_request (GtkWidget *widget, GtkRequisition *requisition);
-static void editor_clist_timestamps_size_allocate (GtkWidget *widget, GtkAllocation *allocation);
+static gchar *editor_clist_timestamps_get_text(SingitEditorView *sev);
+static void editor_clist_timestamps_set_text(SingitEditorView *sev, const gchar *text);
 
-static void editor_clist_timestamps_class_init (EditorClistTimestampsClass *class)
+static void editor_clist_timestamps_class_init (EditorClistTimestampsClass *klass)
 {
-	GtkObjectClass *object_class;
-	GtkWidgetClass *widget_class;
+	GtkObjectClass *object_klass;
+	SingitEditorViewClass *sev_klass;
 
-	object_class = (GtkObjectClass*) class;
-	widget_class = (GtkWidgetClass*) class;
+	object_klass = (GtkObjectClass*) klass;
+	sev_klass = (SingitEditorViewClass*) klass;
 
-	if (!parent_class)
-		parent_class = gtk_type_class (gtk_bin_get_type ());
+	parent_class = gtk_type_class(TYPE_SINGIT_EDITOR_VIEW);
 
-	gtk_object_add_arg_type ("EditorClistTimestamps::cursoroffset",
-			GTK_TYPE_UINT,
-			GTK_ARG_READABLE,
-			ARG_CURSOR_TEXT_OFFSET);
-
-	object_class->set_arg = editor_clist_timestamps_set_arg;
-	object_class->get_arg = editor_clist_timestamps_get_arg;
-	object_class->destroy = editor_clist_timestamps_destroy;
-	widget_class->draw = editor_clist_timestamps_draw;
-	widget_class->expose_event = editor_clist_timestamps_expose;
-	widget_class->size_request = editor_clist_timestamps_size_request;
-	widget_class->size_allocate = editor_clist_timestamps_size_allocate;
+	object_klass->destroy = editor_clist_timestamps_destroy;
+	sev_klass->get_text = editor_clist_timestamps_get_text;
+	sev_klass->set_text = editor_clist_timestamps_set_text;
 }
 
 static void editor_clist_timestamps_init (EditorClistTimestamps *ect)
 {
 	ect->scrolled_window = gtk_scrolled_window_new(NULL, NULL);
 
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(ect->scrolled_window),
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(ect->scrolled_window),
 		GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
 	gtk_container_add(GTK_CONTAINER(ect), ect->scrolled_window);
 	gtk_widget_show(GTK_WIDGET(ect->scrolled_window));
@@ -129,7 +106,7 @@ GtkType editor_clist_timestamps_get_type (void)
 			(GtkClassInitFunc) NULL
 		};
 
-		ect_type = gtk_type_unique (gtk_bin_get_type(), &ect_info);
+		ect_type = gtk_type_unique (TYPE_SINGIT_EDITOR_VIEW, &ect_info);
 	}
 
 	return ect_type;
@@ -145,156 +122,19 @@ static void editor_clist_timestamps_destroy (GtkObject *object)
 		(* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
 
-static void editor_clist_timestamps_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
-{
-	EditorClistTimestamps *editor;
-
-	editor = EDITOR_CLIST_TIMESTAMPS(object);
-
-#ifdef CODEDEBUG
-	DEBUG(DLV_ALL, ("editor_clist_timestamps.c [editor_clist_timestamps_set_arg]\n"));
-#endif
-
-	switch (arg_id) {
-	case ARG_CURSOR_TEXT_OFFSET:
-		editor->cursor_text_offset = GTK_VALUE_UINT(*arg);
-		break;
-	default:
-		break;
-	}
-}
-
-static void editor_clist_timestamps_get_arg (GtkObject *object, GtkArg *arg, guint arg_id)
-{
-	EditorClistTimestamps *editor;
-
-	editor = EDITOR_CLIST_TIMESTAMPS(object);
-
-#ifdef CODEDEBUG
-	DEBUG(DLV_ALL, ("editor_clist_timestamps.c [editor_clist_timestamps_get_arg]\n"));
-#endif
-
-	switch (arg_id) {
-	case ARG_CURSOR_TEXT_OFFSET:
-		GTK_VALUE_UINT(*arg) = editor->cursor_text_offset;
-		break;
-	default:
-		arg->type = GTK_TYPE_INVALID;
-		break;
-	}
-}
-
-static void editor_clist_timestamps_draw (GtkWidget *widget, GdkRectangle *area)
-{
-	GtkBin *bin;
-	GdkRectangle child_area;
-
-	g_return_if_fail (widget != NULL);
-	g_return_if_fail (IS_EDITOR_CLIST_TIMESTAMPS (widget));
-	g_return_if_fail (area != NULL);
-
-	if (GTK_WIDGET_DRAWABLE (widget)) {
-		bin = GTK_BIN (widget);
-
-		if (bin->child && gtk_widget_intersect (bin->child, area, &child_area))
-			gtk_widget_draw (bin->child, &child_area);
-	}
-}
-
-static gint editor_clist_timestamps_expose (GtkWidget *widget, GdkEventExpose *event)
-{
-	GtkBin *bin;
-	GdkEventExpose child_event;
-
-	g_return_val_if_fail (widget != NULL, FALSE);
-	g_return_val_if_fail (IS_EDITOR_CLIST_TIMESTAMPS (widget), FALSE);
-	g_return_val_if_fail (event != NULL, FALSE);
-
-	if (GTK_WIDGET_DRAWABLE (widget)) {
-		bin = GTK_BIN (widget);
-
-		child_event = *event;
-		if (bin->child &&
-			GTK_WIDGET_NO_WINDOW (bin->child) &&
-			gtk_widget_intersect (bin->child, &event->area, &child_event.area))
-			gtk_widget_event (bin->child, (GdkEvent*) &child_event);
-	}
-
-	return FALSE;
-}
-
-static void editor_clist_timestamps_size_request (GtkWidget *widget, GtkRequisition *requisition)
-{
-	GtkBin *bin;
-
-	g_return_if_fail (widget != NULL);
-	g_return_if_fail (IS_EDITOR_CLIST_TIMESTAMPS (widget));
-	g_return_if_fail (requisition != NULL);
-
-	bin = GTK_BIN (widget);
-
-	requisition->width = (GTK_CONTAINER (widget)->border_width +
-		GTK_WIDGET (widget)->style->klass->xthickness) * 2;
-
-	requisition->height = (GTK_CONTAINER (widget)->border_width +
-		GTK_WIDGET (widget)->style->klass->ythickness) * 2;
-
-	if (bin->child && GTK_WIDGET_VISIBLE (bin->child)) {
-		GtkRequisition child_requisition;
-		gtk_widget_size_request (bin->child, &child_requisition);
-	}
-}
-
-static void editor_clist_timestamps_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
-{
-	GtkBin *bin;
-	GtkAllocation child_allocation;
-
-	g_return_if_fail (widget != NULL);
-	g_return_if_fail (IS_EDITOR_CLIST_TIMESTAMPS (widget));
-	g_return_if_fail (allocation != NULL);
-
-	bin = GTK_BIN (widget);
-
-	if (GTK_WIDGET_MAPPED (widget) &&
-		((widget->allocation.x != allocation->x) ||
-		(widget->allocation.y != allocation->y) ||
-		(widget->allocation.width != allocation->width) ||
-		(widget->allocation.height != allocation->height)) &&
-		(widget->allocation.width != 0) &&
-		(widget->allocation.height != 0))
-	{
-		gtk_widget_queue_clear (widget);
-	}
-
-	widget->allocation = *allocation;
-
-	if (bin->child && GTK_WIDGET_VISIBLE (bin->child)) {
-		child_allocation.x = (GTK_CONTAINER(widget)->border_width +
-			widget->style->klass->xthickness);
-		child_allocation.width = MAX(1, (gint)allocation->width - child_allocation.x * 2);
-
-		child_allocation.y = (GTK_CONTAINER(widget)->border_width +
-			GTK_WIDGET(widget)->style->klass->ythickness);
-		child_allocation.height = MAX (1, ((gint)allocation->height - child_allocation.y -
-					 (gint)GTK_CONTAINER (widget)->border_width -
-					 (gint)GTK_WIDGET (widget)->style->klass->ythickness));
-		child_allocation.x += allocation->x;
-		child_allocation.y += allocation->y;
-		gtk_widget_size_allocate (bin->child, &child_allocation);
-	}
-}
-
-gchar *editor_clist_timestamps_get_text(EditorClistTimestamps *ect, gint *char_offset)
+static gchar *editor_clist_timestamps_get_text(SingitEditorView *sev)
 {
 	gint chars = 0, cur_row = 1;
 	gchar *result = NULL, *temp, *concat_str;
+	EditorClistTimestamps *ect;
 
 #ifdef CODEDEBUG
 	DEBUG(DLV_ALL, ("editor_clist_timestamps.c [editor_clist_timestamps_get_text]\n"));
 #endif
 
-	g_return_val_if_fail (IS_EDITOR_CLIST_TIMESTAMPS(ect), NULL);
+	g_return_val_if_fail(IS_SINGIT_EDITOR_VIEW(sev), NULL);
+
+	ect = EDITOR_CLIST_TIMESTAMPS(sev);
 
 	if (GTK_CLIST(ect->clist)->rows > 0) {
 		gtk_clist_get_text(GTK_CLIST(ect->clist), 0, 0, &concat_str);
@@ -310,21 +150,27 @@ gchar *editor_clist_timestamps_get_text(EditorClistTimestamps *ect, gint *char_o
 			g_free(temp);
 			cur_row++;
 		}
-		if (char_offset) { *char_offset = chars; }
+		sev->cursor_text_offset = chars;
 	}
+	else { sev->cursor_text_offset = 0; }
+
 	return result;
 }
 
-void editor_clist_timestamps_set_text(EditorClistTimestamps *ect, gchar *text, gint char_offset)
+static void editor_clist_timestamps_set_text(SingitEditorView *sev, const gchar *text)
 {
 	gchar **lines, *lbr[1][1];
-	gint i = 0, line = 0, chars = 0;
+	gint i = 0, line = 0;
+	guint chars = 0;
+	EditorClistTimestamps *ect;
 
 #ifdef CODEDEBUG
 	DEBUG(DLV_ALL, ("editor_clist_timestamps.c [editor_clist_timestamps_set_text]\n"));
 #endif
 
-	g_return_if_fail (IS_EDITOR_CLIST_TIMESTAMPS(ect));
+	g_return_if_fail(IS_SINGIT_EDITOR_VIEW(sev));
+
+	ect = EDITOR_CLIST_TIMESTAMPS(sev);
 
 	gtk_clist_freeze(GTK_CLIST(ect->clist));
 	gtk_clist_clear(GTK_CLIST(ect->clist));
@@ -333,7 +179,7 @@ void editor_clist_timestamps_set_text(EditorClistTimestamps *ect, gchar *text, g
 		while (lines[i]) {
 			lbr[0][0] = lines[i];
 			gtk_clist_append(GTK_CLIST(ect->clist), lbr[0]);
-			if ((chars < char_offset) && (i > 0)) {
+			if ((chars < sev->cursor_text_offset) && (i > 0)) {
 				chars += strlen(lines[i-1]) + strlen("\n");
 				line++;
 			}
@@ -342,7 +188,8 @@ void editor_clist_timestamps_set_text(EditorClistTimestamps *ect, gchar *text, g
 		g_strfreev(lines);
 	}
 	gtk_clist_thaw(GTK_CLIST(ect->clist));
-	if (char_offset < 0) { line = GTK_CLIST(ect->clist)->rows - 1; }
+	if (sev->cursor_text_offset < 0)
+		{ line = GTK_CLIST(ect->clist)->rows - 1; }
 	ect->active_line = line;
 	gtk_clist_moveto(GTK_CLIST(ect->clist), line, 0, 0.5, 0);
 
@@ -360,7 +207,7 @@ static gchar* get_time_token_string()
 
 	time = xmms_remote_get_output_time(singit_vp.xmms_session);
 	if (time > GET_SCD->reactionTime) { time -= GET_SCD->reactionTime; }
-	if (GET_ECD(editor_config)->extendedLyrics) {
+	if (GET_ECD->extendedLyrics) {
 		time_stamp[11] = '\0';
 		sprintf(time_stamp, "[%.2i:%.2i:%.3i]", time / 60000, time / 1000 % 60, time % 1000);
 	}
@@ -433,6 +280,8 @@ static gboolean editor_clist_clicked_event(GtkWidget *widget, GdkEventButton *ev
 	DEBUG(DLV_ALL, ("editor_clist_timestamps.c [insert_remove_timestamp_event]\n"));
 #endif
 
+	g_return_val_if_fail(IS_SINGIT_EDITOR_VIEW(user_data), FALSE);
+
 	if (!event) { return TRUE; }
 
 	if (event->type != GDK_BUTTON_PRESS) // skip double and triple click events
@@ -446,7 +295,7 @@ static gboolean editor_clist_clicked_event(GtkWidget *widget, GdkEventButton *ev
 	case 1: // Left button
 #ifdef CODEDEBUG
 		DEBUG_AREA(DLV_ALL,
-			debug("Left button\n");
+			debug("%s\n", "Left button"); // To calm the compiler
 			modifiers = print_modifiers(event->state, TRUE);
 			debug(modifiers);
 			g_free(modifiers);
@@ -483,7 +332,7 @@ static gboolean editor_clist_clicked_event(GtkWidget *widget, GdkEventButton *ev
 	case 3: // Right button
 #ifdef CODEDEBUG
 		DEBUG_AREA(DLV_ALL,
-			debug("Right button\n");
+			debug("%s\n", "Right button"); // To calm the compiler
 			modifiers = print_modifiers(event->state, TRUE);
 			debug(modifiers);
 			g_free(modifiers);
@@ -528,7 +377,8 @@ static gboolean editor_clist_clicked_event(GtkWidget *widget, GdkEventButton *ev
 	default:
 		break;
 	}
-	toggle_modified_state(TRUE);
+
+	singit_editor_view_modify(SINGIT_EDITOR_VIEW(user_data), TRUE);
 	return TRUE;
 }
 
@@ -539,10 +389,6 @@ static gboolean editor_clist_timestamps_keypress(GtkWidget *widget, GdkEventKey
 	EditorClistTimestamps *ect = EDITOR_CLIST_TIMESTAMPS(data);*/
 
 	switch(event->keyval) {
-		case GDK_Escape:
-			if (check_user_continue)
-				singit_editor_hide();
-			break;
 /*
 		case GDK_Insert:
 		case GDK_Delete:
