@@ -1,6 +1,6 @@
 /*
  *  SingIt Lyrics Displayer
- *  Copyright (C) 2000 - 2002 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
+ *  Copyright (C) 2000 - 2003 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@
 #ifndef __EDITOR_CLIST_TIMESTAMPS_H__
 #define __EDITOR_CLIST_TIMESTAMPS_H__
 
+#include "editor_view.h"
+
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
@@ -36,26 +38,22 @@ typedef struct _EditorClistTimestampsClass  EditorClistTimestampsClass;
 
 struct _EditorClistTimestamps
 {
-	GtkBin         bin;
+	SingitEditorView        sev;
 
-	guint          cursor_text_offset;
-	guint          active_line;
+	guint                   active_line;
 
-	GtkWidget     *clist;
-	GtkWidget     *scrolled_window;
+	GtkWidget              *clist;
+	GtkWidget              *scrolled_window;
 };
 
 struct _EditorClistTimestampsClass
 {
-	GtkContainerClass parent_class;
+	SingitEditorViewClass   parent_class;
 };
 
 GtkType    editor_clist_timestamps_get_type  (void);
 GtkWidget *editor_clist_timestamps_new       (void);
 
-gchar *editor_clist_timestamps_get_text  (EditorClistTimestamps *ect, gint *char_offset);
-void editor_clist_timestamps_set_text    (EditorClistTimestamps *ect, gchar *text, gint char_offset);
-
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
