@@ -1,6 +1,6 @@
 /*
  *  SingIt Lyrics Displayer
- *  Copyright (C) 2000 - 2002 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
+ *  Copyright (C) 2000 - 2003 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@
 #ifndef __EDITOR_PLAIN_TEXT_H__
 #define __EDITOR_PLAIN_TEXT_H__
 
+#include "editor_view.h"
+
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
@@ -36,26 +38,21 @@ typedef struct _EditorPlainTextClass  EditorPlainTextClass;
 
 struct _EditorPlainText
 {
-	GtkBin         bin;
+	SingitEditorView       sev;
 
-	guint          cursor_text_offset;
-
-	GtkWidget     *text;
+	GtkWidget             *text;
 };
 
 struct _EditorPlainTextClass
 {
-	GtkBinClass parent_class;
+	SingitEditorViewClass  parent_class;
 };
 
 GtkType    editor_plain_text_get_type  (void);
 GtkWidget *editor_plain_text_new       (void);
 
-// if start < 0 => get selected text
-gchar *editor_plain_text_get_text  (EditorPlainText *ept, gint *char_offset, gint start, gint end);
-void editor_plain_text_set_text    (EditorPlainText *ept, gchar *text, gint char_offset);
-
 // Manipulating selections
+gchar *editor_plain_text_get_selection  (EditorPlainText *ept);
 gboolean editor_plain_text_is_selected (EditorPlainText *ept);
 void editor_plain_text_xchg_selection  (EditorPlainText *ept, gchar *text);
 
