@@ -21,8 +21,10 @@
 #ifndef __EDITOR_SINGIT_MAIN__
 #define __EDITOR_SINGIT_MAIN__
 
-gboolean singit_editor_is_realized();
+gboolean singit_editor_is_realized(void);
 void singit_editor_set_time(guint time);
+
+void singit_editor_show(void);
 void singit_editor_hide(void);
 
 #endif  // __EDITOR_SINGIT_MAIN__
