@@ -29,62 +29,43 @@
 #include <xmms/xmmsctrl.h>
 
 #include "singit_debug.h"
-#include "singit_config.h"
 
 #include "editor_singit_main.h"
-#include "editor_singit_private.h"
 #include "editor_synced_lyrics.h"
 #include "editor_config.h"
+#include "editor_status.h"
 
 enum {
 	ARG_0,
 	ARG_CURSOR_TEXT_OFFSET
 };
 
-static GtkBinClass *parent_class = NULL;
+static SingitEditorViewClass *parent_class = NULL;
 
-extern EditorStatus editor_status;
 extern VisPlugin singit_vp;
-extern SingitConfigGen *editor_config;
-extern SingitConfigGen *singit_config;
-
-static void editor_synced_lyrics_set_arg (GtkObject *object, GtkArg *arg, guint arg_id);
-static void editor_synced_lyrics_get_arg (GtkObject *object, GtkArg *arg, guint arg_id);
-static void editor_synced_lyrics_destroy (GtkObject *object);
-static void editor_synced_lyrics_draw (GtkWidget *widget, GdkRectangle *area);
-static gint editor_synced_lyrics_expose (GtkWidget *widget, GdkEventExpose *event);
-static void editor_synced_lyrics_size_request (GtkWidget *widget, GtkRequisition *requisition);
-static void editor_synced_lyrics_size_allocate (GtkWidget *widget, GtkAllocation *allocation);
 
 void editor_synced_lyrics_text_changed_event (GtkEditable *editable, gpointer user_data);
 void editor_synced_lyrics_text_value_changed_event(GtkAdjustment *adj, gpointer user_data);
 gboolean before_text_button_press_event(GtkWidget *widget, GdkEventButton *event, gpointer user_data);
 gboolean after_text_button_press_event(GtkWidget *widget, GdkEventButton *event, gpointer user_data);
 
-static gboolean editor_synced_lyrics_keypress(GtkWidget *widget, GdkEventKey *event, gpointer data);
+static void editor_synced_lyrics_destroy (GtkObject *object);
+static gchar *editor_synced_lyrics_get_text(SingitEditorView *sev);
+static void editor_synced_lyrics_set_text(SingitEditorView *sev, const gchar *text);
 
-static void editor_synced_lyrics_class_init (EditorSyncedLyricsClass *class)
+static void editor_synced_lyrics_class_init (EditorSyncedLyricsClass *klass)
 {
-	GtkObjectClass *object_class;
-	GtkWidgetClass *widget_class;
+	GtkObjectClass *object_klass;
+	SingitEditorViewClass *sev_klass;
 
-	object_class = (GtkObjectClass*) class;
-	widget_class = (GtkWidgetClass*) class;
+	object_klass = (GtkObjectClass*) klass;
+	sev_klass = (SingitEditorViewClass*) klass;
 
-	parent_class = gtk_type_class (gtk_bin_get_type ());
+	parent_class = gtk_type_class(TYPE_SINGIT_EDITOR_VIEW);
 
-	gtk_object_add_arg_type ("EditorSyncedLyrics::cursoroffset",
-			GTK_TYPE_UINT,
-			GTK_ARG_READABLE,
-			ARG_CURSOR_TEXT_OFFSET);
-
-	object_class->set_arg = editor_synced_lyrics_set_arg;
-	object_class->get_arg = editor_synced_lyrics_get_arg;
-	object_class->destroy = editor_synced_lyrics_destroy;
-	widget_class->draw = editor_synced_lyrics_draw;
-	widget_class->expose_event = editor_synced_lyrics_expose;
-	widget_class->size_request = editor_synced_lyrics_size_request;
-	widget_class->size_allocate = editor_synced_lyrics_size_allocate;
+	object_klass->destroy = editor_synced_lyrics_destroy;
+	sev_klass->get_text = editor_synced_lyrics_get_text;
+	sev_klass->set_text = editor_synced_lyrics_set_text;
 }
 
 static void editor_synced_lyrics_init (EditorSyncedLyrics *esl)
@@ -93,9 +74,6 @@ static void editor_synced_lyrics_init (EditorSyncedLyrics *esl)
 		*editor_before_text_vscrollbar, *editor_after_text_hbox,
 		*editor_after_text_vscrollbar;
 
-	gtk_signal_connect(GTK_OBJECT(esl), "key-press-event",
-		GTK_SIGNAL_FUNC(editor_synced_lyrics_keypress), NULL);
-
 	editor_synced_lyrics_vbox = gtk_vbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(esl), editor_synced_lyrics_vbox);
 	gtk_widget_show(editor_synced_lyrics_vbox);
@@ -158,7 +136,7 @@ GtkType editor_synced_lyrics_get_type (void)
 			(GtkClassInitFunc) NULL
 		};
 
-		ect_type = gtk_type_unique (gtk_bin_get_type(), &ect_info);
+		ect_type = gtk_type_unique (TYPE_SINGIT_EDITOR_VIEW, &ect_info);
 	}
 
 	return ect_type;
@@ -174,167 +152,6 @@ static void editor_synced_lyrics_destroy (GtkObject *object)
 		(* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
 
-static void editor_synced_lyrics_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
-{
-	EditorSyncedLyrics *editor;
-
-	editor = EDITOR_SYNCED_LYRICS(object);
-
-#ifdef CODEDEBUG
-	DEBUG(DLV_ALL, ("editor_synced_lyrics.c [editor_synced_lyrics_set_arg]\n"));
-#endif
-
-	switch (arg_id) {
-	case ARG_CURSOR_TEXT_OFFSET:
-		editor->cursor_text_offset = GTK_VALUE_UINT(*arg);
-		break;
-	default:
-		break;
-	}
-}
-
-static void editor_synced_lyrics_get_arg (GtkObject *object, GtkArg *arg, guint arg_id)
-{
-	EditorSyncedLyrics *editor;
-
-	editor = EDITOR_SYNCED_LYRICS(object);
-
-#ifdef CODEDEBUG
-	DEBUG(DLV_ALL, ("editor_synced_lyrics.c [editor_synced_lyrics_get_arg]\n"));
-#endif
-
-	switch (arg_id) {
-	case ARG_CURSOR_TEXT_OFFSET:
-		GTK_VALUE_UINT(*arg) = editor->cursor_text_offset;
-		break;
-	default:
-		arg->type = GTK_TYPE_INVALID;
-		break;
-	}
-}
-
-static void editor_synced_lyrics_draw (GtkWidget *widget, GdkRectangle *area)
-{
-	GtkBin *bin;
-	GdkRectangle child_area;
-
-	g_return_if_fail (widget != NULL);
-	g_return_if_fail (IS_EDITOR_SYNCED_LYRICS (widget));
-	g_return_if_fail (area != NULL);
-
-	if (GTK_WIDGET_DRAWABLE (widget)) {
-		bin = GTK_BIN (widget);
-
-		if (bin->child && gtk_widget_intersect (bin->child, area, &child_area))
-			gtk_widget_draw (bin->child, &child_area);
-	}
-}
-
-static gint editor_synced_lyrics_expose (GtkWidget *widget, GdkEventExpose *event)
-{
-	GtkBin *bin;
-	GdkEventExpose child_event;
-
-	g_return_val_if_fail (widget != NULL, FALSE);
-	g_return_val_if_fail (IS_EDITOR_SYNCED_LYRICS (widget), FALSE);
-	g_return_val_if_fail (event != NULL, FALSE);
-
-	if (GTK_WIDGET_DRAWABLE (widget)) {
-		bin = GTK_BIN (widget);
-
-		child_event = *event;
-		if (bin->child &&
-			GTK_WIDGET_NO_WINDOW (bin->child) &&
-			gtk_widget_intersect (bin->child, &event->area, &child_event.area))
-			gtk_widget_event (bin->child, (GdkEvent*) &child_event);
-	}
-
-	return FALSE;
-}
-
-static void editor_synced_lyrics_size_request (GtkWidget *widget, GtkRequisition *requisition)
-{
-	GtkBin *bin;
-
-	g_return_if_fail (widget != NULL);
-	g_return_if_fail (IS_EDITOR_SYNCED_LYRICS (widget));
-	g_return_if_fail (requisition != NULL);
-
-	bin = GTK_BIN (widget);
-
-	requisition->width = (GTK_CONTAINER (widget)->border_width +
-		GTK_WIDGET (widget)->style->klass->xthickness) * 2;
-
-	requisition->height = (GTK_CONTAINER (widget)->border_width +
-		GTK_WIDGET (widget)->style->klass->ythickness) * 2;
-
-	if (bin->child && GTK_WIDGET_VISIBLE (bin->child)) {
-		GtkRequisition child_requisition;
-		gtk_widget_size_request (bin->child, &child_requisition);
-	}
-}
-
-static void editor_synced_lyrics_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
-{
-	GtkBin *bin;
-	GtkAllocation child_allocation;
-
-	g_return_if_fail (widget != NULL);
-	g_return_if_fail (IS_EDITOR_SYNCED_LYRICS (widget));
-	g_return_if_fail (allocation != NULL);
-
-	bin = GTK_BIN (widget);
-
-	if (GTK_WIDGET_MAPPED (widget) &&
-		((widget->allocation.x != allocation->x) ||
-		(widget->allocation.y != allocation->y) ||
-		(widget->allocation.width != allocation->width) ||
-		(widget->allocation.height != allocation->height)) &&
-		(widget->allocation.width != 0) &&
-		(widget->allocation.height != 0))
-	{
-		gtk_widget_queue_clear (widget);
-	}
-
-	widget->allocation = *allocation;
-
-	if (bin->child && GTK_WIDGET_VISIBLE (bin->child)) {
-		child_allocation.x = (GTK_CONTAINER(widget)->border_width +
-			widget->style->klass->xthickness);
-		child_allocation.width = MAX(1, (gint)allocation->width - child_allocation.x * 2);
-
-		child_allocation.y = (GTK_CONTAINER(widget)->border_width +
-			GTK_WIDGET(widget)->style->klass->ythickness);
-		child_allocation.height = MAX (1, ((gint)allocation->height - child_allocation.y -
-					 (gint)GTK_CONTAINER (widget)->border_width -
-					 (gint)GTK_WIDGET (widget)->style->klass->ythickness));
-		child_allocation.x += allocation->x;
-		child_allocation.y += allocation->y;
-		gtk_widget_size_allocate (bin->child, &child_allocation);
-	}
-}
-
-static gboolean editor_synced_lyrics_keypress(GtkWidget *widget, GdkEventKey *event, gpointer data)
-{
-	gboolean result = TRUE;
-
-	switch(event->keyval) {
-		case GDK_Escape:
-			if (check_user_continue)
-				singit_editor_hide();
-			break;
-		default:
-			result = FALSE;
-			break;
-        }
-        return result;
-}
-
-void editor_synced_lyrics_text_changed_event (GtkEditable *editable, gpointer user_data)
-{
-	toggle_modified_state(TRUE);
-}
-
 gboolean before_text_button_press_event (GtkWidget *widget, GdkEventButton *event, gpointer user_data)
 {
 	if (event->type != GDK_BUTTON_PRESS) // skip double and triple click events
@@ -405,7 +222,7 @@ static gint find_end_pos(gchar *text, gboolean *is_breaker)
 
 gboolean after_text_button_press_event (GtkWidget *widget, GdkEventButton *event, gpointer user_data)
 {
-	EditorSyncedLyrics *esl = EDITOR_SYNCED_LYRICS(user_data);
+	EditorSyncedLyrics *esl;
 	gchar *after_string;
 	gint time;
 	gchar time_stamp[12];
@@ -413,9 +230,15 @@ gboolean after_text_button_press_event (GtkWidget *widget, GdkEventButton *event
 	gint after_text_length, before_text_length;
 	gboolean is_breaker;
 
-	if (event->type != GDK_BUTTON_PRESS) // skip double and triple click events
+	g_return_val_if_fail(event != NULL, FALSE);
+	g_return_val_if_fail(IS_EDITOR_SYNCED_LYRICS(user_data), FALSE);
+
+	// skip double and triple click events
+	if (event->type != GDK_BUTTON_PRESS)
 		{ return TRUE; }
 
+	esl = EDITOR_SYNCED_LYRICS(user_data);
+
 	// Do not leak this
 	after_string = gtk_editable_get_chars(GTK_EDITABLE(esl->after_text), 0, -1);
 
@@ -426,7 +249,7 @@ gboolean after_text_button_press_event (GtkWidget *widget, GdkEventButton *event
 	switch (event->button) {
 	case 1: // Left mouse button
 		if (time > GET_SCD->reactionTime) { time -= GET_SCD->reactionTime; }
-		if (GET_ECD(editor_config)->extendedLyrics) {
+		if (GET_ECD->extendedLyrics) {
 			time_stamp[11] = '\0';
 			sprintf(time_stamp, "[%.2i:%.2i:%.3i]", time / 60000, time / 1000 % 60, time % 1000);
 		}
@@ -438,7 +261,7 @@ gboolean after_text_button_press_event (GtkWidget *widget, GdkEventButton *event
 				gtk_text_get_length(GTK_TEXT(esl->before_text)));
 		gtk_text_insert(GTK_TEXT(esl->before_text), NULL,
 			&esl->after_text->style->black, NULL, &time_stamp[0], strlen(time_stamp));
-		toggle_modified_state(TRUE);
+		singit_editor_view_modify(SINGIT_EDITOR_VIEW(esl), TRUE);
 		if ((after_string == NULL) || (strlen(after_string) == 0))
 			{ break; }
 
@@ -539,35 +362,42 @@ void editor_synced_lyrics_text_value_changed_event(GtkAdjustment *adj, gpointer
 	g_free(before_string);
 }
 
-gchar *editor_synced_lyrics_get_text(EditorSyncedLyrics *esl, gint *char_offset)
+static gchar *editor_synced_lyrics_get_text(SingitEditorView *sev)
 {
 	gchar *result = NULL, *concat_str;
+	EditorSyncedLyrics *esl;
 
 #ifdef CODEDEBUG
 	DEBUG(DLV_ALL, ("editor_synced_lyrics.c [editor_synced_lyrics_get_text]\n"));
 #endif
 
-	g_return_val_if_fail (IS_EDITOR_SYNCED_LYRICS(esl), NULL);
+	g_return_val_if_fail(IS_SINGIT_EDITOR_VIEW(sev), NULL);
+
+	esl = EDITOR_SYNCED_LYRICS(sev);
 
 	concat_str = gtk_editable_get_chars(GTK_EDITABLE(esl->before_text), 0, -1);
 	result = g_strconcat(concat_str, gtk_editable_get_chars
 		(GTK_EDITABLE(esl->after_text), 0, -1), NULL);
-	if (char_offset) { *char_offset = strlen(concat_str); }
+
+	sev->cursor_text_offset = strlen(concat_str);
+
 	g_free(concat_str);
 	return result;
 }
 
-void editor_synced_lyrics_set_text(EditorSyncedLyrics *esl, gchar *text, gint char_offset)
+static void editor_synced_lyrics_set_text(SingitEditorView *sev, const gchar *text)
 {
-	gint before_text_length, after_text_length;
+	gint before_text_length, after_text_length, char_offset;
 	const gchar *breaker = "\n";
-	gchar *pos_insert;
+	EditorSyncedLyrics *esl;
 
 #ifdef CODEDEBUG
 	DEBUG(DLV_ALL, ("editor_synced_lyrics.c [editor_synced_lyrics_set_text]\n"));
 #endif
 
-	g_return_if_fail (IS_EDITOR_SYNCED_LYRICS(esl));
+	g_return_if_fail(IS_SINGIT_EDITOR_VIEW(sev));
+
+	esl = EDITOR_SYNCED_LYRICS(sev);
 
 	gtk_text_freeze(GTK_TEXT(esl->before_text));
 	gtk_text_freeze(GTK_TEXT(esl->after_text));
@@ -581,12 +411,19 @@ void editor_synced_lyrics_set_text(EditorSyncedLyrics *esl, gchar *text, gint ch
 		gtk_text_forward_delete(GTK_TEXT(esl->after_text),
 			gtk_text_get_length(GTK_TEXT(esl->after_text)));
 	}
+
+	char_offset = sev->cursor_text_offset;
+
 	if (text) {
 		if (char_offset > 0) {
-			pos_insert = &text[char_offset];
-			while (((pos_insert - text) > 0) && (pos_insert[0] != breaker[strlen(breaker) - 1]) &&
-				(pos_insert[0] != ' ')) { pos_insert--; }
-			char_offset = pos_insert - text + 1;
+			while ((text[char_offset] != breaker[strlen(breaker) - 1]) &&
+				(text[char_offset] != ' '))
+			{
+				char_offset--;
+				if (char_offset == -1)
+					{ break; }
+			}
+			char_offset++;
 		}
 		if (char_offset > 0) {
 			before_text_length = MIN((gint) strlen(text), char_offset);
