@@ -21,6 +21,8 @@
 #ifndef __EDITOR_SYNCED_LYRICS_H__
 #define __EDITOR_SYNCED_LYRICS_H__
 
+#include "editor_view.h"
+
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
@@ -36,27 +38,22 @@ typedef struct _EditorSyncedLyricsClass  EditorSyncedLyricsClass;
 
 struct _EditorSyncedLyrics
 {
-	GtkBin         bin;
+	SingitEditorView       sev;
 
-	guint          cursor_text_offset;
-
-	GtkWidget     *before_text;
-	GtkWidget     *after_text;
-	GtkWidget     *percent_text_scale;
-        GtkObject     *percent_text_adj;
+	GtkWidget             *before_text;
+	GtkWidget             *after_text;
+	GtkWidget             *percent_text_scale;
+        GtkObject             *percent_text_adj;
 };
 
 struct _EditorSyncedLyricsClass
 {
-	GtkBinClass parent_class;
+	SingitEditorViewClass  parent_class;
 };
 
 GtkType    editor_synced_lyrics_get_type  (void);
 GtkWidget *editor_synced_lyrics_new       (void);
 
-gchar *editor_synced_lyrics_get_text  (EditorSyncedLyrics *esl, gint *char_offset);
-void editor_synced_lyrics_set_text    (EditorSyncedLyrics *esl, gchar *text, gint char_offset);
-
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
