@@ -23,7 +23,8 @@
 #include <xmms/plugin.h>
 
 #include "singit_debug.h"
-#include "singit_dialogs.h"
+
+#include "dialogs.h"
 #include "singit_main.h"
 #include "singit_plugin_scanner.h"
 
@@ -36,8 +37,6 @@ static void main_playback_stop(void);
 static void main_render_freq(gint16 freq_data[2][256]);
 static void main_render_pcm(gint16 pcm_data[2][512]);
 
-extern SingitStatus singit_status;
-
 VisPlugin singit_vp =
 {
 	NULL,
@@ -107,7 +106,7 @@ static void main_playback_start(void)
 	DEBUG(DLV_XMMS, ("main.c [main_playback_start]\n"));
 #endif
 
-	singit_status.playing = TRUE;
+	STATUS->playing = TRUE;
 	dis_plugin_playback_start(-1);
 }
 
@@ -117,7 +116,7 @@ static void main_playback_stop(void)
 	DEBUG(DLV_XMMS, ("main.c [main_playback_stop]\n"));
 #endif
 
-	singit_status.playing = FALSE;
+	STATUS->playing = FALSE;
 	dis_plugin_playback_stop(-1);
 }
 
