@@ -24,10 +24,9 @@
 #include <stdio.h>
 #include <stdarg.h>
 
-#include "singit_macros.h"
-#include "singit_macros_private.h"
+#include "singit_debug.h"
 
-void debug(char *format, ...)
+void debug(const char *format, ...)
 {
 	va_list ap;
 
