@@ -29,12 +29,9 @@
 #include <sched.h>
 #endif
 
-#include "singit_displayer_plugin.h"
+#include "singit/displayer_plugin.h"
 #include "singit_debug.h"
-#include "singit_config_gen.h"
-#include "singit_config.h"
-#include "singit_config_private.h"
-#include "singit_song.h"
+#include "singit/song.h"
 #include "singit_song_private.h"
 #include "dlg_singit_config.h"
 
@@ -52,78 +49,78 @@
 #endif
 
 extern VisPlugin singit_vp;
-extern SingitConfigGen *singit_config;
 
 static void singit_main_set_timeout(void);
 
+static pthread_mutex_t status_init_mutex = PTHREAD_MUTEX_INITIALIZER;
+
 void singit_main_init(gboolean initialize_plugins)
 {
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(8, ("singit_main.c [singit_main_init]\n"));
-#	endif
+#endif
+	pthread_mutex_lock(&status_init_mutex);
 
-	singit_status.attachments++;
-	if (singit_status.attachments <= 1) {
+	if (singit_status_ref() == NULL) {
+		pthread_mutex_unlock(&status_init_mutex);
+		return;
+	}
 
-#		if ((defined CODEDEBUG) && (defined USE_MTRACE))
+	if (singit_singleton_initialize(SINGIT_SINGLETON(STATUS)) == TRUE)
+	{
+#if ((defined CODEDEBUG) && (defined USE_MTRACE))
 		g_print("singit_main.c [singit_main_init] : mtrace\n");
 		mtrace();
-#		endif
-
-		singit_status.singit_sound_precalcs = g_malloc(sizeof(SingitSoundPrecalcs));
-
-		pthread_mutex_init(&singit_status.config_rw_mutex, NULL);
-		pthread_mutex_init(&singit_status.lyrics_rw_mutex, NULL);
-
-#		ifdef ENABLE_NLS
+#endif
+#ifdef ENABLE_NLS
 		setlocale (LC_ALL, "");
 		bindtextdomain (PACKAGE, LOCALE_DIR);
-#		endif
-
-		if (!singit_config_gen_attach(singit_config)) {
-			singit_config_new();
-			singit_config_gen_load(singit_config);
-		}
-
+#endif
 		plugins_init();
 
-		singit_status.singit_framerate_counter =
+		STATUS->singit_framerate_counter =
 			SINGIT_FRAMERATE_COUNTER
 			(singit_framerate_counter_new(15));
 		singit_framerate_counter_set_ticktype
-			(singit_status.singit_framerate_counter, GLIB_TICKS);
+			(STATUS->singit_framerate_counter, GLIB_TICKS);
 	}
 
+	pthread_mutex_unlock(&status_init_mutex);
+
 	if (initialize_plugins) {
 		plugins_initialize();
-		singit_status.initialize_plugins = TRUE;
+		STATUS->initialize_plugins = TRUE;
 	}
 	singit_main_set_timeout();
 }
 
 void singit_main_finish(gboolean finish_plugins)
 {
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(8, ("singit_main.c [singit_main_finish]\n"));
-#	endif
+#endif
 
-	singit_status.attachments--;
-	if (singit_status.attachments > 0) {
-		if (finish_plugins) {
-			plugins_finalize();
-		}
+	pthread_mutex_lock(&status_init_mutex);
+
+	if (GTK_OBJECT(STATUS)->ref_count > 1) {
+		singit_status_unref(NULL);
+
+		if (finish_plugins)
+			{ plugins_finalize(); }
+
+		pthread_mutex_unlock(&status_init_mutex);
 		singit_main_set_timeout();
 		return;
 	}
 
-	if (singit_status.display_thread || singit_status.check_thread) {
+	if (STATUS->display_thread || STATUS->check_thread) {
 
-		singit_status.kill_threads = TRUE;
+		STATUS->kill_threads = TRUE;
 
-		pthread_join(singit_status.check_thread, NULL);
-		pthread_join(singit_status.display_thread, NULL);
+		pthread_join(STATUS->check_thread, NULL);
+		pthread_join(STATUS->display_thread, NULL);
 
-		singit_status.kill_threads = FALSE;
+		STATUS->kill_threads = FALSE;
 	}
 
 	plugins_finish();
@@ -135,88 +132,98 @@ void singit_main_finish(gboolean finish_plugins)
 #endif
 	singit_editor_hide();
 
-	singit_config_gen_detach(SINGIT_CONFIG_GEN(singit_config));
+	singit_status_unref(NULL);
 
-	singit_main_status_finish();
-
-#	if ((defined CODEDEBUG) && (defined USE_MTRACE))
+#if ((defined CODEDEBUG) && (defined USE_MTRACE))
 	g_print("singit_main.c [singit_main_finish] : muntrace\n");
 	muntrace();
-#	endif
+#endif
+
+	pthread_mutex_unlock(&status_init_mutex);
 }
 
 static void singit_main_set_timeout(void)
 {
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(5, ("singit_main.c [singit_main_set_timeout]: "));
-#	endif
+#endif
 
-	if (!is_dis_plugin_running(-1) && singit_status.display_thread &&
+	if (!is_dis_plugin_running(-1) && STATUS->display_thread &&
 		!singit_editor_is_realized()) {
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 		DEBUG(5, ("finish\n"));
-#	endif
-		singit_status.kill_threads = TRUE;
+#endif
+		STATUS->kill_threads = TRUE;
 
-		pthread_join(singit_status.check_thread, NULL);
-		pthread_join(singit_status.display_thread, NULL);
+		pthread_join(STATUS->check_thread, NULL);
+		pthread_join(STATUS->display_thread, NULL);
 
-		singit_status.kill_threads = FALSE;
-		singit_status.next_lyric_line = NULL;
+		STATUS->kill_threads = FALSE;
+		STATUS->next_lyric_line = NULL;
 	}
 	else {
 		if ((is_dis_plugin_running(-1) || singit_editor_is_realized()) &&
-			!singit_status.display_thread)
+			!STATUS->display_thread)
 		{
-#		ifdef CODEDEBUG
+#ifdef CODEDEBUG
 			DEBUG(5, ("start\n"));
-#		endif
-			if (pthread_create(&singit_status.check_thread, NULL,
+#endif
+			if (pthread_create(&STATUS->check_thread, NULL,
 				check_thread_func, NULL))
 			{
-				singit_status.check_thread = 0;
+				STATUS->check_thread = 0;
 				g_print("Unable to create check thread\n");
 			}
 
-			if (pthread_create(&singit_status.display_thread, NULL,
+			if (pthread_create(&STATUS->display_thread, NULL,
 				display_thread_func, NULL))
 			{
-				singit_status.display_thread = 0;
+				STATUS->display_thread = 0;
 				g_print("Unable to create display thread\n");
 			}
 		}
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 		else {
 			DEBUG(5, ("unchanged\n"));
 		}
-#	endif
+#endif
 	}
 }
 
 // * This is the function to  start a plugin from an other plugin
 // * Because of the locking it has to run as a GTK idle loop
 // * Otherwise key handling inside the *set_time call would lock the plugin
-// * (It took me one afternoon to fix it - so I'm quite sure about it ;-(
+// * (It took me one afternoon to fix / find it - so I'm quite sure about it ;-(
 static gint enable_plugin_real(gpointer data)
 {
-#	ifdef CODEDEBUG
+	SingitConfigData *scd;
+
+	g_return_val_if_fail(STATUS->config != NULL, FALSE);
+
+#ifdef CODEDEBUG
 	DEBUG(8, ("singit_main.c [enable_plugin_real]\n"));
-#	endif
+#endif
+
+	scd = GET_SCD;
 
 	GDK_THREADS_ENTER();
 	set_dis_plugin_status(GPOINTER_TO_INT(data), TRUE);
 	config_dis_plugins_rescan();
 	GDK_THREADS_LEAVE();
 
+	dis_plugin_set_time(GPOINTER_TO_INT(data),
+		STATUS->old_time, STATUS->next_lyric_line);
+
 	return FALSE;
 }
 
 void enable_plugin(gint plugin)
 {
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(8, ("singit_main.c [enable_plugin]\n"));
-#	endif
+#endif
 
-	gtk_idle_add(enable_plugin_real, GINT_TO_POINTER(plugin));
+	gtk_idle_add_priority(G_PRIORITY_HIGH_IDLE,
+		enable_plugin_real, GINT_TO_POINTER(plugin));
 }
