@@ -1,5 +1,6 @@
-/* SingIt Lyrics Displayer
- * Copyright (C) 2000, 2001 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
+/*
+ *  SingIt Lyrics Displayer
+ *  Copyright (C) 2000 - 2003 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,33 +21,12 @@
 #ifndef __SINGIT_MAIN_H__
 #define __SINGIT_MAIN_H__
 
-#ifndef USE_GLIB_IDLE
-#include <pthread.h>
-#endif
-
-typedef struct {
-
-        gchar *fileName;
-        GList *next_lyric_line;
-
-	pthread_t display_thread;
-	pthread_t check_thread;
-
-	pthread_mutex_t config_rw_mutex;
-	pthread_mutex_t lyrics_rw_mutex;
-	pthread_mutex_t time_update_mutex;
-
-	gboolean kill_display_thread;
-	gboolean kill_check_thread;
-	gboolean initialize_plugins;
-
-	gboolean config_update;
-
-	gint attachments;
-
-} SingitStatus;
+#include "singit_main_status.h"
 
 void singit_main_init(gboolean initialize_plugins);
 void singit_main_finish(gboolean finish_plugins);
 
+void *display_thread_func(void *args);
+void *check_thread_func(void *args);
+
 #endif  // __SINGIT_MAIN_H__
