@@ -37,24 +37,20 @@
 #include "ltdl_wrapper.h"
 
 #include "singit_debug.h"
-#include "singit_config_gen.h"
-#include "singit_config.h"
-#include "singit_config_private.h"
+// #include "singit/config_gen.h"
 #include "singit_main.h"
 #include "singit_plugin_data.h"
 #include "singit_plugin_scanner.h"
 #include "dlg_singit_config.h"
 #include "singit_sound_precalcs_private.h"
-#include "singit_displayer_plugin.h"
-#include "singit_wgt_karaoke.h"
+#include "singit/displayer_plugin.h"
+#include "singit/wgt_karaoke.h"
 
 DisplayerPluginData *dp_data = NULL;
 
 #define PLUGINSUBDIR "xmms-singit"
 
 extern VisPlugin singit_vp;
-extern SingitStatus singit_status;
-extern SingitConfigGen *singit_config;
 
 static void scan_dis_plugins(gchar *dirname);
 static gboolean plugins_finalize_real(gboolean has_lock);
@@ -78,6 +74,7 @@ static gint dislist_compare_func(const void *a, const void *b)
 void plugins_init()
 {
 	gchar *dir;
+	SingitConfigGen *scg_o;
 
 #ifdef CODEDEBUG
 	DEBUG(8, ("singit_plugin_scanner.c [plugins_init]\n"));
@@ -112,10 +109,12 @@ void plugins_init()
 	scan_dis_plugins(dir);
 	g_free(dir);
 
-	dp_data->displayer_list = g_list_sort(dp_data->displayer_list, dislist_compare_func);
-	if (singit_config_gen_attach(singit_config)) {
+	dp_data->displayer_list =
+		g_list_sort(dp_data->displayer_list, dislist_compare_func);
+
+	if ((scg_o = singit_config_gen_attach(STATUS->config)) != NULL) {
 		dis_plugin_enable_from_stringified_list(GET_SCD->enabled_dplugins);
-		singit_config_gen_detach(SINGIT_CONFIG_GEN(singit_config));
+		singit_config_gen_detach(&scg_o);
 	}
 }
 
@@ -159,7 +158,7 @@ static void add_dis_plugin(gchar *filename)
 
 	if (dis_plugin_is_duplicate_libname(filename) == TRUE)
 		{ return; }
-	
+
 	if ((h = wrp_dlopen(filename)) == NULL)
 	{
 		g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
@@ -175,6 +174,7 @@ static void add_dis_plugin(gchar *filename)
 		p = (DisplayerPlugin *) gpi();
 		p->handle = (void*) h;
 		p->filename = g_strdup(filename);
+		p->singit_session = -1;
 		p->xmms_session = singit_vp.xmms_session;
 		p->disable = dis_plugin_disable;
 		dp_data->displayer_list = g_list_prepend(dp_data->displayer_list, p);
@@ -200,7 +200,7 @@ static void scan_dis_plugins(gchar *dirname)
 			{ continue; }
 
 		filename = g_strdup_printf("%s/%s", dirname, ent->d_name);
-		if (!stat(filename, &statbuf) && S_ISREG(statbuf.st_mode) && 
+		if (!stat(filename, &statbuf) && S_ISREG(statbuf.st_mode) &&
 			wrp_is_libname(filename))
 		{
 			add_dis_plugin(filename);
@@ -215,6 +215,7 @@ void plugins_finish(void)
 	DisplayerPlugin *dp;
 	GList *node;
 	gboolean init;
+	SingitConfigGen *scg_o;
 
 #ifdef CODEDEBUG
 	DEBUG(8, ("singit_plugin_scanner.c [plugins_finish] : "));
@@ -236,7 +237,8 @@ void plugins_finish(void)
 
 	init = displayer_plugin_data_lock_init_ext(dp_data, TRUE, FALSE, FALSE);
 
-	if (singit_config_gen_attach(singit_config)) {
+	if ((scg_o = singit_config_gen_attach(STATUS->config)) != NULL)
+	{
 		g_free(GET_SCD->enabled_dplugins);
 		GET_SCD->enabled_dplugins = dis_plugin_stringify_enabled_list();
 		if ((GET_SCD->enabled_dplugins == NULL) &&
@@ -247,7 +249,7 @@ void plugins_finish(void)
 		}
 		singit_config_save_plugins();
 		if (init) { singit_config_save_positions(); }
-		singit_config_gen_detach(SINGIT_CONFIG_GEN(singit_config));
+		singit_config_gen_detach(&scg_o);
 	}
 
 	if (init) { plugins_finalize_real(TRUE); }
@@ -268,7 +270,7 @@ void plugins_finish(void)
 		displayer_plugin_data_unlock_init(dp_data);
 }
 
-void plugins_set_time(gint time, SingitSong *cur_song, GList *real_next)
+void dis_plugin_set_time(gint plugin, gint time, GList *real_next)
 {
 	DisplayerPlugin *dp;
 	GList *node;
@@ -276,14 +278,28 @@ void plugins_set_time(gint time, SingitSong *cur_song, GList *real_next)
 	if (displayer_plugin_data_lock_plugins(dp_data, TRUE) == FALSE)
 		{ return; }
 
-	node = get_dis_plugin_enabled_list(TRUE);
-	while (node != NULL)
-	{
-		dp = (DisplayerPlugin *) node->data;
-		if ((dp != NULL) && (dp->set_time != NULL)) {
-			dp->set_time(time, cur_song, real_next);
+	if (plugin < 0) {
+		node = get_dis_plugin_enabled_list(TRUE);
+		while (node != NULL)
+		{
+			dp = (DisplayerPlugin *) node->data;
+			if ((dp != NULL) && (dp->set_time != NULL))
+				dp->set_time(time, real_next);
+			node = g_list_next(node);
 		}
-		node = g_list_next(node);
+	}
+	else {
+		node = g_list_nth(dp_data->displayer_list, plugin);
+		if (node != NULL &&
+			g_list_find(get_dis_plugin_enabled_list(TRUE), node->data))
+		{
+			dp = (DisplayerPlugin *) node->data;
+			if ((dp != NULL) && (dp->set_time != NULL))
+				dp->set_time(time, real_next);
+		}
+		else
+			g_log(G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
+				"Plugin not available");
 	}
 
 	displayer_plugin_data_unlock_plugins(dp_data);
@@ -291,9 +307,7 @@ void plugins_set_time(gint time, SingitSong *cur_song, GList *real_next)
 
 typedef enum {
 
-	dpc_show = 0,
-	dpc_hide,
-	dpc_toggle,
+	dpc_set_song = 0,
 	dpc_update,
 	dpc_playback_start,
 	dpc_playback_stop,
@@ -327,31 +341,15 @@ static inline gboolean real_emitter
 		if (enabled == FALSE)
 			{ return FALSE; }
 	}
-	
+
 	switch (callback) {
-	case dpc_show:
-		if (!g_list_find(dp_data->visible_list, node->data)) {
-			dp_data->visible_list = g_list_append
-				(dp_data->visible_list, node->data);
-			if (dp->show)
-				dp->show(cur_song);
-		}
-		break;
-	case dpc_hide:
-		if (g_list_find(dp_data->visible_list, node->data)) {
-			dp_data->visible_list = g_list_remove
-				(dp_data->visible_list, node->data);
-			if (dp->hide)
-				dp->hide(cur_song);
-		}
-		break;
-	case dpc_toggle:
-		if (dp->toggle)
-			dp->toggle(cur_song);
+	case dpc_set_song:
+		if (dp->set_song)
+			dp->set_song(cur_song);
 		break;
 	case dpc_update:
 		if (dp->update)
-			dp->update(GET_SCD);
+			dp->update();
 		break;
 	case dpc_playback_start:
 		if (dp->playback_start)
@@ -372,7 +370,7 @@ static inline gboolean real_emitter
 static void emit_callback(DPCallback callback, gint plugin, SingitSong *cur_song)
 {
 	GList *node;
-	gboolean plugins, initialized;
+	gboolean plugins, initialized = TRUE;
 
 	g_return_if_fail(dp_data != NULL);
 
@@ -389,9 +387,9 @@ static void emit_callback(DPCallback callback, gint plugin, SingitSong *cur_song
 		plugins = TRUE;
 		break;
 	}
-		
+
 	if (plugin < 0) {
-		node = get_dis_plugin_enabled_list(FALSE);
+		node = get_dis_plugin_enabled_list(TRUE);
 		while (node != NULL)
 		{
 			if (real_emitter(node, callback, cur_song, initialized) == FALSE)
@@ -402,44 +400,26 @@ static void emit_callback(DPCallback callback, gint plugin, SingitSong *cur_song
 	else {
 		node = g_list_nth(dp_data->displayer_list, plugin);
 		if (node != NULL)
-			real_emitter(node, callback, cur_song, initialized && 
+			real_emitter(node, callback, cur_song, initialized &&
 				is_dis_plugin_enabled(plugin));
 		else
 			g_log(G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
 				"Plugin not available");
 	}
 
-	if (plugins == FALSE) 
+	if (plugins == FALSE)
 		{ displayer_plugin_data_unlock_init(dp_data); }
 	else
 		{ displayer_plugin_data_unlock_plugins(dp_data); }
 }
 
-void dis_plugin_show(gint plugin, SingitSong *cur_song)
+void dis_plugin_set_song(gint plugin, SingitSong *cur_song)
 {
 #ifdef CODEDEBUG
-	DEBUG(DLV_ALL, ("singit_plugin_scanner.c [dis_plugin_show]\n"));
+	DEBUG(DLV_ALL, ("singit_plugin_scanner.c [dis_plugin_set_song]\n"));
 #endif
 
-	emit_callback(dpc_show, plugin, cur_song);
-}
-
-void dis_plugin_hide(gint plugin, SingitSong *cur_song)
-{
-#ifdef CODEDEBUG
-	DEBUG(DLV_ALL, ("singit_plugin_scanner.c [dis_plugin_hide]\n"));
-#endif
-
-	emit_callback(dpc_hide, plugin, cur_song);
-}
-
-void dis_plugin_toggle(gint plugin, SingitSong *cur_song)
-{
-#ifdef CODEDEBUG
-	DEBUG(DLV_ALL, ("singit_plugin_scanner.c [dis_plugin_toggle]\n"));
-#endif
-
-	emit_callback(dpc_toggle, plugin, cur_song);
+	emit_callback(dpc_set_song, plugin, cur_song);
 }
 
 void dis_plugin_update(gint plugin)
@@ -457,7 +437,7 @@ void dis_plugin_playback_start(gint plugin)
 	DEBUG(DLV_ALL, ("singit_plugin_scanner.c [dis_plugin_playback_start]\n"));
 #endif
 
-	if (!dp_data || dp_data->playback_started) 
+	if (!dp_data || dp_data->playback_started)
 		{ return; }
 
 	emit_callback(dpc_playback_start, plugin, NULL);
@@ -498,13 +478,13 @@ void dis_plugin_render_freq(gint16 freq_data[2][256])
 	GList *node;
 	node = get_dis_plugin_enabled_list(TRUE);
 
-	if (node && (singit_status.singit_sound_precalcs != NULL)) {
-		sigit_sound_precalcs_freq(singit_status.singit_sound_precalcs, &freq_data[0][0]);
+	if (node && (STATUS->singit_sound_precalcs != NULL)) {
+		sigit_sound_precalcs_freq(STATUS->singit_sound_precalcs, &freq_data[0][0]);
 	}
 	while (node)
 	{
 		if (((DisplayerPlugin *) node->data)->render_freq)
-			((DisplayerPlugin *) node->data)->render_freq(freq_data, singit_status.singit_sound_precalcs);
+			((DisplayerPlugin *) node->data)->render_freq(freq_data, STATUS->singit_sound_precalcs);
 		node = g_list_next(node);
 	}
 }
@@ -514,13 +494,13 @@ void dis_plugin_render_pcm(gint16 pcm_data[2][512])
 	GList *node;
 	node = get_dis_plugin_enabled_list(TRUE);
 
-	if (node && (singit_status.singit_sound_precalcs != NULL)) {
-		sigit_sound_precalcs_pcm(singit_status.singit_sound_precalcs, &pcm_data[0][0]);
+	if (node && (STATUS->singit_sound_precalcs != NULL)) {
+		sigit_sound_precalcs_pcm(STATUS->singit_sound_precalcs, &pcm_data[0][0]);
 	}
 	while (node)
 	{
 		if (((DisplayerPlugin *) node->data)->render_pcm)
-			((DisplayerPlugin *) node->data)->render_pcm(pcm_data, singit_status.singit_sound_precalcs);
+			((DisplayerPlugin *) node->data)->render_pcm(pcm_data, STATUS->singit_sound_precalcs);
 		node = g_list_next(node);
 	}
 }
@@ -591,6 +571,7 @@ gboolean set_dis_plugin_status(gint plugin, gboolean enable)
 	DisplayerPlugin *dp;
 	gboolean search;
 	gboolean initialized;
+	gboolean result = FALSE;
 
 	g_return_val_if_fail(dp_data != NULL, FALSE);
 
@@ -599,24 +580,25 @@ gboolean set_dis_plugin_status(gint plugin, gboolean enable)
 	if (enable) { DEBUG(DLV_ALL, ("Enable\n")); }
 	else { DEBUG(DLV_ALL, ("Disable\n")); }
 #endif
+	if (displayer_plugin_data_lock_lower(dp_data, &initialized) == FALSE)
+		{ goto unlock_lower; }
 
 	// Find the plugin, look and look if it is (!enable)
 	if ((guint) plugin >= g_list_length(dp_data->displayer_list))
-		{ return FALSE; }
+		{ goto unlock_lower; }
 
 	node = g_list_nth(dp_data->displayer_list, plugin);
 
-	g_return_val_if_fail(node != NULL, FALSE);
-	g_return_val_if_fail(node->data != NULL, FALSE);
+	g_goto_label_if_fail(node != NULL, unlock_lower);
+	g_goto_label_if_fail(node->data != NULL, unlock_lower);
 
 	dp = (DisplayerPlugin *) node->data;
 
 	search = (g_list_find(dp_data->enabled_list, dp) != NULL);
 	if (enable == search)
-		{ return FALSE; }
+		{ goto unlock_lower; }
 
-	if (displayer_plugin_data_lock_lower(dp_data, &initialized) == FALSE)
-		{ return FALSE; }
+	result = TRUE;
 
 	if (enable) {
 		// Start the displayer plugin
@@ -625,13 +607,14 @@ gboolean set_dis_plugin_status(gint plugin, gboolean enable)
 		if (initialized == FALSE)
 			{ goto unlock_lower; }
 
-		if (dp->init) {
+		if (dp->init)
 			dp->init();
-			if (dp->update) {
-				dp->update(GET_SCD);
-			}
-		}
-		singit_status.initialize_plugins = TRUE;
+		if (dp->update)
+			dp->update();
+		if (dp->set_song)
+			dp->set_song(STATUS->song);
+
+		STATUS->initialize_plugins = TRUE;
 	}
 	else {
 		// Stop the displayer plugin
@@ -650,7 +633,7 @@ gboolean set_dis_plugin_status(gint plugin, gboolean enable)
 			dp->finish();
 		}
 
-		singit_status.initialize_plugins = TRUE;
+		STATUS->initialize_plugins = TRUE;
 		singit_config_save_positions();
 
 		if (!dp_data->enabled_list) {
@@ -662,10 +645,10 @@ gboolean set_dis_plugin_status(gint plugin, gboolean enable)
 unlock_lower:
 	if (initialized == TRUE)
 		{ displayer_plugin_data_unlock_plugins(dp_data); }
-	else 
+	else
 		{ displayer_plugin_data_unlock_init(dp_data); }
 
-	return TRUE;
+	return result;
 }
 
 gchar *dis_plugin_stringify_enabled_list(void)
@@ -690,7 +673,7 @@ gchar *dis_plugin_stringify_enabled_list(void)
 			(((DisplayerPlugin *) node->data)->handle)) + 1;
 		node = g_list_next(node);
 	}
-	
+
 	dest_pos = enabled_str = g_new(gchar, len);
 	enabled_str[0] = '\0';
 
@@ -701,13 +684,13 @@ gchar *dis_plugin_stringify_enabled_list(void)
 		len = strlen(src_pos);
 		memcpy(dest_pos, src_pos, len);
 		dest_pos += len;
-		dest_pos[0] = ','; 
+		dest_pos[0] = ',';
 		dest_pos++;
 		node = g_list_next(node);
 	}
 	dest_pos--;
 	dest_pos[0] = '\0';
-	
+
 	return enabled_str;
 }
 
@@ -762,12 +745,12 @@ gboolean plugins_initialize()
 	while (node)
 	{
 		dp = node->data;
-		if(dp->init) {
+		if (dp->init)
 			dp->init();
-			if (dp->update) {
-				dp->update(GET_SCD);
-			}
-		}
+		if (dp->update)
+			dp->update();
+		// XMMS can't process requests during init, so we don't set the song
+
 		node = g_list_next(node);
 	}
 
