@@ -25,6 +25,8 @@
 
 #include <glib.h>
 
+#include "singit/song.h"
+
 // * The plugins_init and plugins_finish functions are nested.
 // * In other words, you have to  call plugins_finish as often as plugins_init!
 // * This has to be done, because you can open the configuration without
@@ -59,9 +61,9 @@ gchar *dis_plugin_stringify_enabled_list(void);
 void dis_plugin_enable_from_stringified_list(gchar *list);
 
 // * Calls the plugin funtion from the enabled list *
-void dis_plugin_show(gint plugin, SingitSong *cur_song);
-void dis_plugin_hide(gint plugin, SingitSong *cur_song);
-void dis_plugin_toggle(gint plugin, SingitSong *cur_song);
+void dis_plugin_set_song(gint plugin, SingitSong *cur_song);
+void dis_plugin_set_time(gint plugin, gint time, GList *real_next);
+
 void dis_plugin_update(gint plugin);
 void dis_plugin_playback_start(gint plugin);
 void dis_plugin_playback_stop(gint plugin);
@@ -71,7 +73,4 @@ void dis_plugin_configure(gint plugin);
 void dis_plugin_render_freq(gint16 freq_data[2][256]);
 void dis_plugin_render_pcm(gint16 pcm_data[2][512]);
 
-// * Tell all enabled plugins the actual time / song *
-void plugins_set_time(gint time, SingitSong *cur_song, GList *real_next);
-
 #endif // __SINGIT_PLUGIN_SCANNER_H__
