@@ -1,6 +1,6 @@
 /*
  *  SingIt Lyrics Displayer
- *  Copyright (C) 2000 - 2002 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
+ *  Copyright (C) 2000 - 2003 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,6 @@
 #include <config.h>
 #endif
 
-#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -37,27 +36,17 @@
 #endif
 
 #include "singit_debug.h"
-#include "singit_song.h"
+#include "singit/song.h"
 #include "singit_song_private.h"
 #include "singit_tools.h"
 #include "singit_file_info.h"
 
-enum {
-	FREE,
-	UPDATE,
-	LAST_SIGNAL
-};
 
 static GtkObjectClass *parent_class = NULL;
-static guint song_signals[LAST_SIGNAL] = { 0 };
-
-// static gint counter = 0;
 
 static void singit_song_class_init (SingitSongClass *klass);
 static void singit_song_init (SingitSong *ssong);
 
-//static void singit_song_set_arg(GtkObject *object, GtkArg *arg, guint arg_id);
-//static void singit_song_get_arg(GtkObject *object, GtkArg *arg, guint arg_id);
 static void singit_song_destroy(GtkObject *object);
 
 GtkType singit_song_get_type (void)
@@ -89,33 +78,7 @@ static void singit_song_class_init (SingitSongClass *klass)
 	GtkObjectClass *object_class = (GtkObjectClass*) klass;
 	parent_class = gtk_type_class(GTK_TYPE_OBJECT);
 
-//	object_class->set_arg = singit_song_set_arg;
-//	object_class->get_arg = singit_song_get_arg;
 	object_class->destroy = singit_song_destroy;
-
-//	gtk_object_add_arg_type ("SingitSong::attachments", GTK_TYPE_UINT, GTK_ARG_READABLE, ARG_ATTACHMENTS);
-
-	song_signals[FREE] =
-		gtk_signal_new("free",
-			GTK_RUN_LAST,
-			object_class->type,
-			GTK_SIGNAL_OFFSET (SingitSongClass, free),
-			gtk_marshal_NONE__POINTER,
-			GTK_TYPE_NONE, 1,
-			GTK_TYPE_POINTER);
-
-	song_signals[UPDATE] =
-		gtk_signal_new("update",
-			GTK_RUN_FIRST,
-			object_class->type,
-			GTK_SIGNAL_OFFSET (SingitSongClass, update),
-			gtk_marshal_NONE__NONE,
-			GTK_TYPE_NONE, 0);
-
-	klass->free = NULL;
-	klass->update = NULL;
-
-	gtk_object_class_add_signals (object_class, song_signals, LAST_SIGNAL);
 }
 
 static void singit_song_init (SingitSong *ssong)
@@ -132,6 +95,10 @@ static void singit_song_init (SingitSong *ssong)
 	ssong->lyric_filename = NULL;
 	ssong->delimiter = NULL;
 	ssong->lyric_type = LT_NONE;
+
+	ssong->artist = NULL;
+	ssong->album = NULL;
+	ssong->title = NULL;
 }
 
 static void singit_song_destroy (GtkObject *object)
@@ -143,15 +110,11 @@ static void singit_song_destroy (GtkObject *object)
 
 	ssong = SINGIT_SONG (object);
 
-//	if (ssong->config_data != NULL)
-//		gtk_signal_emit (GTK_OBJECT(ssong), song_signals[FREE], ssong->config_data);
-
-//	g_print ("Free Song\n");
 	singit_song_clear(ssong);
 
 	if (ssong->song_filename != NULL)
 		{ g_free(ssong->song_filename); }
-		
+
 	if (ssong->file_info != NULL)
 		{ singit_file_info_free((SingitFileInfo*) ssong->file_info); }
 
@@ -159,9 +122,6 @@ static void singit_song_destroy (GtkObject *object)
 	ID3Tag_Delete(TAG(ssong));
 #endif
 
-/*	if (ssong->adjustment)
-		gtk_signal_disconnect_by_data (GTK_OBJECT(ssong->adjustment), ssong);*/
-
 	if (GTK_OBJECT_CLASS(parent_class)->destroy)
 		GTK_OBJECT_CLASS(parent_class)->destroy(object);
 }
@@ -170,28 +130,25 @@ GtkObject *singit_song_new (gchar* song_filename)
 {
 	SingitSong *ssong = gtk_type_new(TYPE_SINGIT_SONG);
 
-//	counter++;
-//	g_print ("New Song\n");
-
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(DLV_ALL, ("singit_song.c [singit_song_new]\n"));
-#	endif
+#endif
 
 	ssong->file_info = (SingitFileInfo*)
 		singit_file_info_new(song_filename, TRUE);
-	
+
 	if (song_filename) {
 		ssong->song_filename = g_strdup(song_filename);
-#		ifdef HAVE_ID3
+#ifdef HAVE_ID3
 		ssong->id3tag = ID3Tag_New();
 		ID3Tag_Link_WRP(TAG(ssong), song_filename);
-#		endif
+#endif
 	}
 	else {
 		ssong->song_filename = song_filename;
-#		ifdef HAVE_ID3
+#ifdef HAVE_ID3
 		TAG(ssong) = NULL;
-#		endif
+#endif
 	}
 	return GTK_OBJECT(ssong);
 }
@@ -201,10 +158,9 @@ void singit_song_clear(SingitSong* ssong)
 	GList *token;
 	gchar *song_filename;
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(DLV_ALL, ("singit_song.c [singit_song_clear]\n"));
-#	endif
-
+#endif
 	g_return_if_fail (ssong != NULL);
 	g_return_if_fail (IS_SINGIT_SONG (ssong));
 
@@ -214,13 +170,17 @@ void singit_song_clear(SingitSong* ssong)
 			g_free((LToken*) (token->data));
 			token = g_list_next(token);
 		}
-//		g_free((LToken*) (token->data));
 		g_list_free(ssong->first_token);
 	}
+
 	if (ssong->lyrics) { g_strfreev(ssong->lyrics); }
 	if (ssong->lyric_filename) { g_free(ssong->lyric_filename); }
 	if (ssong->delimiter) { g_free(ssong->delimiter); }
 
+	if (ssong->artist != NULL) { g_free(ssong->artist); }
+	if (ssong->album != NULL) { g_free(ssong->album); }
+	if (ssong->title != NULL) { g_free(ssong->title); }
+
 	song_filename = ssong->song_filename;
 	singit_song_init(ssong);
 	ssong->song_filename = song_filename;
@@ -228,9 +188,9 @@ void singit_song_clear(SingitSong* ssong)
 
 void singit_song_free(SingitSong* ssong)
 {
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(DLV_ALL, ("singit_song.c [singit_song_free]\n"));
-#	endif
+#endif
 
 	g_return_if_fail (ssong != NULL);
 	g_return_if_fail (IS_SINGIT_SONG (ssong));
@@ -240,27 +200,24 @@ void singit_song_free(SingitSong* ssong)
 
 SingitSong* singit_song_attach(SingitSong *ssong)
 {
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(DLV_ALL, ("singit_song.c [singit_song_attach] : "));
-#	endif
+#endif
 
 	if (ssong != NULL) {
 
-//		counter++;
-//		g_print ("Attach Song: %i\n", counter);
-
 		g_return_val_if_fail (IS_SINGIT_SONG (ssong), NULL);
 
 		gtk_object_ref(GTK_OBJECT(ssong));
 
-#		ifdef CODEDEBUG
+#ifdef CODEDEBUG
 		DEBUG(DLV_ALL, ("Attached\n"));
-#		endif
+#endif
 		return ssong;
 	}
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(DLV_ALL, ("Failed\n"));
-#	endif
+#endif
 	return NULL;
 }
 
@@ -271,18 +228,15 @@ void singit_song_detach(SingitSong **ssong)
 	g_return_if_fail(ssong != NULL);
 	_ssong = *ssong;
 	if (_ssong == NULL) { return; }
-	
+
 	g_return_if_fail(IS_SINGIT_SONG(_ssong));
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(DLV_ALL, ("singit_song.c [singit_song_detach]\n"));
-#	endif
-
-//	counter--;
-//	g_print ("Detach Song: %i\n", counter);
+#endif
 
 	gtk_object_unref(GTK_OBJECT(_ssong));
-	_ssong = NULL;
+	(*ssong) = NULL;
 }
 
 gboolean singit_song_set_song_filename(SingitSong *ssong, gchar *filename)
@@ -319,9 +273,9 @@ gint singit_song_find_line(SingitSong* ssong, gint line)
 {
 	GList *item = NULL;
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(DLV_ALL, ("singit_song.c [singit_song_find_line]\n"));
-#	endif
+#endif
 
 	item = ssong->first_token;
 	while (item != ssong->last_token) {
@@ -336,9 +290,9 @@ gint singit_song_find_time(SingitSong* ssong, gint time)
 {
 	GList *item = NULL;
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(DLV_ALL, ("singit_song.c [singit_song_find_time]\n"));
-#	endif
+#endif
 
 	item = ssong->first_token;
 	while (item != ssong->last_token) {
@@ -367,7 +321,7 @@ gint compare_token_by_rpos(gconstpointer a, gconstpointer b)
 
 	if (ta->line < tb->line) { return 1; }
 	if (ta->line > tb->line) { return -1; }
-	
+
 	if (ta->pos < ta->pos) { return 1; }
 	if (ta->pos > ta->pos) { return -1; }
 
@@ -389,7 +343,7 @@ gint compare_token_by_pos(gconstpointer a, gconstpointer b)
 
 	if (ta->line < tb->line) { return -1; }
 	if (ta->line > tb->line) { return 1; }
-	
+
 	if (ta->pos < ta->pos) { return -1; }
 	if (ta->pos > ta->pos) { return 1; }
 
@@ -401,7 +355,7 @@ gint compare_token_by_pos(gconstpointer a, gconstpointer b)
 		if (ta->time < tb->time) { return -1; }
 		if (ta->time > tb->time) { return 1; }
 	}
-		
+
 	return 0;
 }
 #undef tb
@@ -422,35 +376,35 @@ gboolean singit_song_load_lyrics(SingitSong *ssong, gchar *filename)
 	gboolean result;
 	struct stat stats;
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(7, ("singit_song.c [singit_song_load_lyrics]\n"));
 	DEBUG(8, ("     %s\n", filename));
-#	endif
+#endif
 
 	if (!singit_song_attach(ssong)) { return FALSE; }
 	singit_song_clear(ssong);
 
 	if (stat(filename, &stats) == -1) { singit_song_detach(&ssong); return FALSE; }
 	if (S_ISDIR(stats.st_mode)) { singit_song_detach(&ssong); return FALSE; }
-	
+
 	if (!(file = fopen(filename, "r"))) { singit_song_detach(&ssong); return FALSE; }
 	fclose(file);
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(8, ("1: File found\n"));
-#	endif
+#endif
 
-#	ifdef HAVE_ID3
+#ifdef HAVE_ID3
 	result = singit_song_load_id3v2xx_lyrics(ssong, filename);
 	if (!result) {
-#	endif
+#endif
 		result = singit_song_load_midi_lyrics(ssong, filename);
 		if (!result)
 			result = singit_song_load_from_text_file(ssong, filename);
-#	ifdef HAVE_ID3
+#ifdef HAVE_ID3
 	}
-#	endif
-	
+#endif
+
 	singit_song_detach(&ssong);
 
 	return result;
@@ -460,9 +414,9 @@ GList* singit_song_find_current_token(SingitSong *ssong, gint time, gint state)
 {
 	GList *item = NULL;
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	DEBUG(DLV_ALL, ("singit_song.c [singit_song_find_current_token] : "));
-#	endif
+#endif
 
 	if (state == 0) { state = inl_singit_song_is_time_ok(ssong, time); }
 	switch (state) {
@@ -494,17 +448,19 @@ gboolean singit_song_lyrics_changed(SingitSong *ssong)
         struct stat stats;
 	gboolean result;
 
-	if (ssong == NULL) { return TRUE; }
-	if (ssong->lyric_filename == NULL) { stat_name = ssong->song_filename; }
+	if (ssong == NULL)
+		{ return TRUE; }
+
+	if (ssong->lyric_filename == NULL)
+		{ stat_name = ssong->song_filename; }
 	else { stat_name = ssong->lyric_filename; }
-	if (stat(stat_name, &stats) == -1) { return singit_song_text_found(ssong); }
-        if (!(file = fopen(stat_name, "r"))) { return singit_song_text_found(ssong); }
-/*
-	if ((ssong->lyric_type != LT_TAG) && (stats.st_size > 50000)) {
-		fclose(file);
-		return TRUE;
-	}
-*/
+
+	if (stat(stat_name, &stats) == -1)
+		{ return singit_song_text_found(ssong); }
+
+        if (!(file = fopen(stat_name, "r")))
+		{ return singit_song_text_found(ssong); }
+
 	result = (singit_file_info_changed(INFO(ssong), &stats, file, TRUE) > 0);
 
 	fclose(file);
@@ -518,12 +474,20 @@ inline gint inl_singit_song_get_text_length(SingitSong *ssong)
 	gint length = 0;
 	GList *next = NULL;
 
-	if (ssong->active_token == NULL) { return -2; }
+	if (ssong->active_token == NULL)
+		{ return -2; }
+
 	next = g_list_next(ssong->active_token);
-	if (next == NULL) { return -1; }
-	if (tLine(ssong->active_token) != tLine(next)) { return -1; }
+	if (next == NULL)
+		{ return -1; }
+
+	if (tLine(ssong->active_token) != tLine(next))
+		{ return -1; }
+
 	length = (tPos(next) - tPos(ssong->active_token));
-	if (length > 0) { return length; }
+
+	if (length > 0)
+		{ return length; }
 	else { return -2; }
 }
 
@@ -535,111 +499,81 @@ gint singit_song_get_text_length(SingitSong *ssong)
 inline gboolean singit_song_is_empty_item(SingitSong *ssong, GList *item, gboolean check_end)
 {
 	guint length = strlen(ssong->lyrics[tLine(item)]);
-	
-	if ((check_end == TRUE) && (tPos(item) == length)) 
+
+	if ((check_end == TRUE) && (tPos(item) == length))
 		{ return TRUE; }
-	if (length == 0) 
+
+	if (length == 0)
 		{ return TRUE; }
+
 	return FALSE;
 }
 
 GList* singit_song_find_next_lyric_line(SingitSong *ssong, GList *item, gboolean empty, guint *hops)
 {
-	GList *runner = item;
+	GList *iterator;
 	guint run_hops = 0;
-	if (!item) { runner = ssong->first_token; }
-	if (!empty) {
-		while (runner) {
-			runner = g_list_next(runner);
-			run_hops++;
-			while (runner) {
-				if (!singit_song_is_empty_item(ssong, runner, FALSE)) {
-					if (!item) {
-						if (hops) { *hops = run_hops; }
-						return runner;
-					}
-					if (tLine(runner) != tLine(item)) {
-						if (hops) { *hops = run_hops; }
-						return runner;
-					}
-				}
-				runner = g_list_next(runner);
-				run_hops++;
-			}
-		}
+
+	if (item == NULL)
+		{ iterator = ssong->first_token; }
+	else { iterator = item; }
+
+	if (iterator != NULL) {
+		iterator = g_list_next(iterator);
+		run_hops++;
 	}
-	else {
-		while (runner) {
-			runner = g_list_next(runner);
-			run_hops++;
-			if (runner) {
-				if (!item) {
-					if (hops) { *hops = run_hops; }
-					return runner;
-				}
-				if (tLine(item) != tLine(runner)) {
-					if (hops) { *hops = run_hops; }
-					return runner;
-				}
-			}
+
+	while (iterator != NULL) {
+		if (empty || !singit_song_is_empty_item(ssong, iterator, FALSE)) {
+			if ((item == NULL) || (tLine(iterator) != tLine(item)))
+				{ break; }
 		}
+		iterator = g_list_next(iterator);
+		run_hops++;
 	}
-	if (hops) { *hops = 0; }
-	return NULL;
+
+	if (hops) { *hops = run_hops; }
+
+	return iterator;
 }
 
 GList* singit_song_find_prev_lyric_line(SingitSong *ssong, GList *item, gboolean empty, guint *hops)
 {
-	GList *runner = item;
+	GList *iterator = NULL;
 	guint run_hops = 0;
-	if (!item) { return NULL; }
-	if (!empty) {
-		while (runner) {
-			runner = g_list_previous(runner);
-			run_hops++;
-			while (runner) {
-				if (!singit_song_is_empty_item(ssong, runner, FALSE)) {
-					if (!item) {
-						if (hops) { *hops = run_hops; }
-						return runner;
-					}
-					if (tLine(runner) != tLine(item)) {
-						if (hops) { *hops = run_hops; }
-						return runner;
-					}
-				}
-				runner = g_list_previous(runner);
-				run_hops++;
-			}
-		}
+
+	if (item != NULL) {
+		iterator = g_list_previous(item);
+		run_hops++;
 	}
-	else {
-		while (runner) {
-			runner = g_list_previous(runner);
-			run_hops++;
-			if (runner) {
-				if (!item) {
-					if (hops) { *hops = run_hops; }
-					return runner;
-				}
-				if (tLine(item) != tLine(runner)) {
-					if (hops) { *hops = run_hops; }
-					return runner;
-				}
-			}
+
+	while (iterator != NULL) {
+		if (empty || !singit_song_is_empty_item(ssong, iterator, FALSE)) {
+			if ((item == NULL) || (tLine(iterator) != tLine(item)))
+				{ break; }
 		}
+		iterator = g_list_previous(iterator);
+		run_hops++;
 	}
-	if (hops) { *hops = 0; }
-	return runner;
+
+	if (hops) { *hops = run_hops; }
+
+	return iterator;
 }
 
 gint singit_song_check_sync_lyric_consistency(SingitSong *ssong)
 {
 	GList *cur_item, *prev_item;
-	if (!ssong) { return -1; }
-	if (!ssong->first_token) { return -1; }
-	if (ssong->first_token == ssong->last_token) { return -1; }
-	if (!singit_song_guess_sync_lyrics(ssong)) { return -1; }
+
+	g_return_val_if_fail(ssong != NULL, -1);
+	g_return_val_if_fail(IS_SINGIT_SONG(ssong), -1);
+
+	if ((!ssong->first_token) ||
+		(ssong->first_token == ssong->last_token) ||
+		(!singit_song_guess_sync_lyrics(ssong)))
+	{
+		return -1;
+	}
 
 	prev_item = ssong->first_token;
 
@@ -649,16 +583,21 @@ gint singit_song_check_sync_lyric_consistency(SingitSong *ssong)
 
 	cur_item = prev_item;
 	while (cur_item) {
-		if (tLine(prev_item) > tLine(cur_item)) { return tLine(cur_item); }
+		if (tLine(prev_item) > tLine(cur_item))
+			{ return tLine(cur_item); }
+
 		if (tLine(prev_item) == tLine(cur_item))
-			if (tPos(prev_item) > tPos(cur_item)) { return tLine(cur_item); }
+			if (tPos(prev_item) > tPos(cur_item))
+				{ return tLine(cur_item); }
 
 		prev_item = cur_item;
 		cur_item = g_list_next(cur_item);
+
 		// Don't check empty line items
 		while ((cur_item) && (!singit_song_is_empty_item(ssong, cur_item, FALSE)))
 			{ cur_item = g_list_next(cur_item); }
 	}
+
 	return -1;
 }
 
@@ -681,11 +620,14 @@ void singit_song_modify_overall_time(SingitSong *ssong, gint time)
 gboolean singit_song_guess_sync_lyrics(SingitSong *ssong)
 {
 	GList *cur_item;
-	if (!ssong) { return FALSE; }
+
+	g_return_val_if_fail(ssong != NULL, FALSE);
+	g_return_val_if_fail(IS_SINGIT_SONG(ssong), FALSE);
 
 	cur_item = ssong->first_token;
 	while (cur_item) {
-		if (tPos(cur_item) > 0) { return TRUE; }
+		if (tPos(cur_item) > 0)
+			{ return TRUE; }
 		cur_item = g_list_next(cur_item);
 	}
 	return FALSE;
@@ -693,13 +635,15 @@ gboolean singit_song_guess_sync_lyrics(SingitSong *ssong)
 
 inline GList *inl_singit_song_get_next_token(SingitSong *ssong)
 {
-	if (ssong->active_token) { return g_list_next(ssong->active_token); }
+	if (ssong->active_token)
+		{ return g_list_next(ssong->active_token); }
 	return ssong->first_token;
 }
 
 inline GList *inl_singit_song_get_prev_token(SingitSong *ssong)
 {
-	if (ssong->active_token) { return g_list_previous(ssong->active_token); }
+	if (ssong->active_token)
+		{ return g_list_previous(ssong->active_token); }
 	return NULL;
 }
 
