@@ -18,7 +18,7 @@
  */
 
 
-// By enabling this define there will be a stream write on every read and 
+// By enabling this define there will be a stream write on every read and
 // the results will be displayed in debug mode 9
 // #define TEST_WRITE_FROM_READ
 
@@ -29,7 +29,7 @@
 
 #include "singit_id3lib_wrapper.h"
 
-#include "singit_song.h"
+#include "singit/song.h"
 #include "singit_song_private.h"
 #include "singit_sha.h"
 #include "singit_tools.h"
@@ -41,23 +41,23 @@ static SingitSong* attach_id3tag(SingitSong *ssong, gchar **filename)
 {
 	SingitSong *my_song = singit_song_attach(ssong);
 	struct stat stats;
-	
-	if (my_song == NULL) 
+
+	if (my_song == NULL)
 		{ return NULL; }
 
-	if ((*filename) == NULL) 
+	if ((*filename) == NULL)
 		{ (*filename) = my_song->song_filename; }
 
-	if (stat((*filename), &stats) == -1) { 
+	if (stat((*filename), &stats) == -1) {
 		singit_song_detach(&my_song);
-		return NULL; 
+		return NULL;
 	}
 
-	if (TAG(my_song) == NULL) { 
+	if (TAG(my_song) == NULL) {
 		TAG(my_song) = ID3Tag_New();
 		ID3Tag_Link_WRP(TAG(my_song), (*filename));
 	}
-	
+
 	return my_song;
 }
 
@@ -81,10 +81,10 @@ gboolean singit_song_load_id3v2xx_lyrics(SingitSong *ssong, gchar *filename)
 #	endif
 
 	my_song = singit_song_attach(ssong);
-	if (my_song == NULL) 
+	if (my_song == NULL)
 		{ return FALSE; }
 
-	if (filename == NULL) 
+	if (filename == NULL)
 		{ filename = my_song->song_filename; }
 
 	if (stat(filename, &stats) == -1) {
@@ -95,14 +95,14 @@ gboolean singit_song_load_id3v2xx_lyrics(SingitSong *ssong, gchar *filename)
 	if (TAG(my_song) == NULL)
 		{ TAG(my_song) = ID3Tag_New(); }
 	ID3Tag_Link_WRP(TAG(my_song), filename);
-	
+
 	if (ID3Tag_NumFrames(TAG(my_song)) <= 0) {
 		singit_song_detach(&my_song);
 		return FALSE;
 	}
 
 /*	g_print("%i\n", frm_size);
-	
+
 	if (!ID3Tag_HasTagType(TAG(my_song),
 			ID3TT_ID3V2 |
 			ID3TT_LYRICS3 |
@@ -122,7 +122,7 @@ gboolean singit_song_load_id3v2xx_lyrics(SingitSong *ssong, gchar *filename)
 			timstamp_format = ID3Field_GetINT (id3_field); // (2 == nTimestamp) ? "ms" : "frames"
 		}
 #ifdef CODEDEBUG
-		DEBUG_AREA(DLV_ALL, 
+		DEBUG_AREA(DLV_ALL,
 		if ((id3_field = ID3Frame_GetField(id3_frame, ID3FN_CONTENTTYPE)) != NULL) {
 			content_type = ID3Field_GetINT (id3_field);
 			switch (content_type) {
@@ -163,7 +163,7 @@ gboolean singit_song_load_id3v2xx_lyrics(SingitSong *ssong, gchar *filename)
 		my_song->lyric_filename = g_strdup(filename);
 		my_song->lyric_type = LT_TAG;
 	}
-	
+
 	singit_song_detach(&my_song);
 
 	return result;
@@ -180,26 +180,26 @@ gboolean singit_song_save_id3v2_lyrics(SingitSong *ssong, gchar *filename, gint
 #ifdef CODEDEBUG
 	DEBUG(8, ("singit_song_id3v2xx.c [singit_song_save_id3v2_lyrics]\n"));
 #endif
-	
-	if (my_song == NULL) 
+
+	if (my_song == NULL)
 		{ return FALSE; }
-	if (singit_song_text_found(my_song) == FALSE) 
+	if (singit_song_text_found(my_song) == FALSE)
 		{ return FALSE; }
 
-	if (singit_song_write_id3v2_sync_stream(ssong, &stream, &slength) == FALSE) 
+	if (singit_song_write_id3v2_sync_stream(ssong, &stream, &slength) == FALSE)
 		{ goto cleanup_song; }
 
-	if (filename == NULL) 
+	if (filename == NULL)
 		{ filename = my_song->lyric_filename; }
 
-        if (!(file = fopen(filename, "w"))) 
+        if (!(file = fopen(filename, "w")))
 		{ goto cleanup_stream; }
 
         if (fwrite(stream, 1, slength, file) == slength)
 		{ result = TRUE; }
 	fclose(file);
-	
-	if (my_song->lyric_filename == NULL) 
+
+	if (my_song->lyric_filename == NULL)
 		{ my_song->lyric_filename = g_strdup(filename); }
 
 cleanup_stream:
@@ -227,18 +227,18 @@ gboolean singit_song_read_id3v2_sync_stream(SingitSong *ssong, gpointer stream,
 #ifdef CODEDEBUG
 	DEBUG(8, ("singit_song_id3v2xx.c [singit_song_read_id3v2_sync_stream]\n"));
 #endif
-	
+
 	if ((stream == NULL) || (slength == 0))
 		{ return FALSE; }
 
 	my_song = singit_song_attach(ssong);
-	if (my_song == NULL) 
+	if (my_song == NULL)
 		{ return FALSE; }
 
 	lyrics = g_new(gchar, slength + 1);
-	
+
 	singit_song_clear(my_song);
-	
+
 	stream_pos = stream;
 	lyrics_pos = lyrics;
 	while (stream_pos < ((gchar*) stream) + slength) {
@@ -295,19 +295,19 @@ gboolean singit_song_read_id3v2_sync_stream(SingitSong *ssong, gpointer stream,
 	my_song->first_token = g_list_sort(my_song->first_token, compare_token_by_time);
 
 #if defined CODEDEBUG && defined TEST_WRITE_FROM_READ
-	DEBUG_AREA(DLV_ALL, 
+	DEBUG_AREA(DLV_ALL,
 		singit_song_write_id3v2_sync_stream(my_song, &test_stream, &test_size);
 		debug("Write test sizes: %i / %i\n", slength, test_size);
 		if (slength == test_size) {
-			debug("Write test bcmp: %s (%i)\n", 
-				(memcmp(test_stream, stream, slength) == 0) ? 
+			debug("Write test bcmp: %s (%i)\n",
+				(memcmp(test_stream, stream, slength) == 0) ?
 				"Succeeded" : "Failed", test_size);
 		}
 	);
 #endif
 
 	singit_song_detach(&my_song);
-	
+
 	return TRUE;
 }
 
@@ -323,13 +323,13 @@ gboolean singit_song_write_id3v2_sync_stream(SingitSong *song, gpointer *stream,
 
 	if ((song == NULL) || (stream == NULL) || (slength == NULL))
 		{ return FALSE; }
-	if (!singit_song_text_found(song)) 
+	if (!singit_song_text_found(song))
 		{ return FALSE; }
 	if (lines_info((const gchar**) song->lyrics, &length, &count) == FALSE)
 		{ return FALSE; }
 
 	(*stream) = pos = g_malloc
-		(length + count + g_list_length(song->first_token) * 5); 
+		(length + count + g_list_length(song->first_token) * 5);
 
 	song->first_token = g_list_sort(song->first_token, compare_token_by_pos);
 	item = song->first_token;
@@ -340,7 +340,7 @@ gboolean singit_song_write_id3v2_sync_stream(SingitSong *song, gpointer *stream,
 				length = strlen(song->lyrics[line]);
 				if (offset > 0) {
 					if (offset < length) {
-						memcpy(pos, song->lyrics[line] + offset, 
+						memcpy(pos, song->lyrics[line] + offset,
 							length - offset);
 						pos += (length - offset);
 					}
@@ -406,8 +406,8 @@ gboolean singit_song_write_id3v2_sync_stream(SingitSong *song, gpointer *stream,
 
 	(*slength) = (gint) pos - (gint) (*stream);
 
-	song->first_token = 
+	song->first_token =
 		g_list_sort(song->first_token, compare_token_by_time);
-	
+
 	return TRUE;
 }
