@@ -25,7 +25,7 @@
 
 #include "singit_debug.h"
 
-#include "singit_song.h"
+#include "singit/song.h"
 #include "singit_song_private.h"
 
 typedef enum {
@@ -72,6 +72,7 @@ typedef struct _MidiFile {
 }
 MidiFile;
 
+/*
 static guint getInt32(gchar **buffer)
 {
 	guint result = 0;
@@ -132,7 +133,6 @@ static guchar getByte(gchar **buffer)
 	return result;
 }
 
-
 static MidiEvent *getMidiEvent(gchar *buffer, gint *length, gulong offset)
 {
 	gint command;
@@ -142,7 +142,7 @@ static MidiEvent *getMidiEvent(gchar *buffer, gint *length, gulong offset)
 	command = (gint) getByte(&buffer);
 	result->data = NULL;
 
-	/*
+
 	if (command == 0xff) {
 		command = IOUtils::getByte(in, length);
 		int clen = IOUtils::getIntVar(in, length);
@@ -365,10 +365,10 @@ static MidiEvent *getMidiEvent(gchar *buffer, gint *length, gulong offset)
 	}
 
 	_data = new MidiEventCommand( runningStatus & 0xf , IOUtils::getByte(in,length), IOUtils::getByte(in,length));
-	*/
+
 	return NULL;
 }
-
+	*/
 static gboolean is_midi_file(gchar *buffer)
 {
 	return (!strncmp(buffer, "MThd", 4));
