@@ -21,7 +21,7 @@
 #ifndef __SINGIT_SONG_PRIVATE_H__
 #define __SINGIT_SONG_PRIVATE_H__
 
-#include "singit_macros.h"
+#include "singit/macros.h"
 
 #include <stdio.h>
 
