@@ -27,9 +27,11 @@
 #include <sys/stat.h>
 #include <ctype.h>
 
+#include <gtk/gtktypeutils.h>
+
 #include "singit_debug.h"
 
-#include "singit_song.h"
+#include "singit/song.h"
 #include "singit_song_private.h"
 
 #include "singit_tools.h"
@@ -37,18 +39,28 @@
 
 const gint tag_length[] = { 7, 7, 11, 10 };
 
+// Post: Return the tag-type
+// Types:
+// 	0: No tag
+// 	1: [xx:xx]
+// 	2: [xx:xx:xxx]
+// 	3: [xx:xx.xx]
+// We don't check the length of the string here.
+// For secure use see singit_song_get_timetag_type
+//
 static inline gint get_timetag_type(gchar* tag)
 {
 	if ((tag[0] == '[') && (isdigit(tag[1])) && (isdigit(tag[2])) &&
-		(tag[3] == ':') && (isdigit(tag[4])) && (isdigit(tag[5]))) {
+		(tag[3] == ':') && (isdigit(tag[4])) && (isdigit(tag[5])))
+	{
 		if (tag[6] == ']') { return 1; }
-		if ((tag[6] == ':') && (isdigit(tag[7])) && 
+		if ((tag[6] == ':') && (isdigit(tag[7])) &&
 			(isdigit(tag[8])) && (isdigit(tag[9])) &&
 			(tag[10] == ']'))
-		{ 
-			return 2; 
+		{
+			return 2;
 		}
-		if ((tag[6] == '.') && (isdigit(tag[7])) && 
+		if ((tag[6] == '.') && (isdigit(tag[7])) &&
 			(isdigit(tag[8])) && (tag[9] == ']'))
 		{
 			return 3;
@@ -57,6 +69,7 @@ static inline gint get_timetag_type(gchar* tag)
 	return 0;
 }
 
+// Public function to detect a time tag
 gint singit_song_get_timetag_type(gchar* tag)
 {
 	guint length = strlen(tag);
@@ -66,6 +79,10 @@ gint singit_song_get_timetag_type(gchar* tag)
 	return get_timetag_type(tag);
 }
 
+// Extract the time from a possible tag
+// Post:
+//  *time = if != NULL - contains the time of the tag in milliseconds
+//  return = Sucessfully extracted
 inline gboolean extrakt_timetag_information(gchar* tag, guint* time)
 {
 	gboolean result = TRUE;
@@ -110,14 +127,56 @@ inline gboolean extrakt_timetag_information(gchar* tag, guint* time)
 	return result;
 }
 
+// Extract known info tags and set the values in the song structure
+static inline gboolean extract_info_tags
+	(SingitSong *song, gchar *start_tag, gchar *end_tag)
+{
+	gint info_nr;
+	gchar  **song_offset;
+
+	struct _SongMap {
+		const gchar *id;
+		guint        offset;
+	};
+
+	// We just map saved tags - otherwise we would lose unknown ones
+	static const struct _SongMap info_tags[] = {
+		{ "[ar:", GTK_STRUCT_OFFSET(SingitSong, artist) }, // Artist
+		{ "[ti:", GTK_STRUCT_OFFSET(SingitSong, title) }, // Title
+		{ "[al:", GTK_STRUCT_OFFSET(SingitSong, album) }, // Album
+//		{ "[la:", 0 }, // Language
+//		{ "[by:", 0 }, // Typed by
+		{ NULL },
+	};
+
+	info_nr = 0;
+	while (info_tags[info_nr].id != NULL) {
+		if (strncmp(info_tags[info_nr].id, start_tag, 4) == 0) {
+#ifdef CODEDEBUG
+			DEBUG(8, ("i"));
+#endif
+			song_offset = G_STRUCT_MEMBER_P
+				(song, info_tags[info_nr].offset);
+			if (*song_offset == NULL) {
+				start_tag += 4;
+				*song_offset =
+					g_strndup(start_tag,
+						end_tag - start_tag);
+			}
+#ifdef CODEDEBUG
+			else {
+				DEBUG(8, ("-"));
+			}
+#endif
+			return TRUE;
+		}
+		info_nr++;
+	}
+	return FALSE;
+}
+
 static inline gchar* extract_token(SingitSong* song, gchar* line, guint line_nr)
 {
-	const gchar old_tags[4][5] = {
-		"[ar:",
-		"[ti:",
-		"[la:",
-		"[by:"
-	};
 	gchar *start_tag, *end_tag = line;
 	gint copy_chars;
 
@@ -146,8 +205,8 @@ static inline gchar* extract_token(SingitSong* song, gchar* line, guint line_nr)
 		}
 
 		end_tag = strstr(start_tag, "]");
-		// We have no end tag -> break the loop
-		if (end_tag == NULL) 
+		// We have no end tag -> break the while loop
+		if (end_tag == NULL)
 			{ break; }
 
 		tokenlen = end_tag - start_tag;
@@ -173,21 +232,9 @@ static inline gchar* extract_token(SingitSong* song, gchar* line, guint line_nr)
 				break;
 			}
 		default:
-			if ((end_tag - start_tag > 5) && (start_tag == line)) {
-				tokenlen = 0;
-				while (tokenlen < 4) {
-					if (strncmp(&old_tags[tokenlen][0], start_tag, 4) == 0) {
-#ifdef CODEDEBUG
-						DEBUG(8, ("o"));
-#endif
-						// switch (time) {
-						//default:
-						//}
-						tokenlen = 4;
-						return NULL;
-					}
-					tokenlen++;
-				}
+			if ((tokenlen >= 4) && (start_tag == line)) {
+				if (extract_info_tags(song, start_tag, end_tag) == TRUE)
+					{ return NULL; }
 			}
 			end_tag++;
 			copy_chars = end_tag - start_tag;
@@ -227,10 +274,10 @@ gboolean singit_song_read_text_stream(SingitSong *song, gchar *buffer)
 
 #ifdef CODEDEBUG
 	DEBUG(8, ("singit_song.c [singit_song_read_text_stream]\n"));
-	DEBUG(8, ("        'l' = line / '.' = tag / 'o' = old special tag\n"));
+	DEBUG(8, ("        'l' = line / '.' = tag / 'i' = special info tag ('i-' = dup)\n"));
 #endif
 
-	if ((buffer == NULL) || (song == NULL)) 
+	if ((buffer == NULL) || (song == NULL))
 		{ return FALSE; }
 
   	s = strstr (buffer, delimiter);
@@ -285,9 +332,13 @@ gboolean singit_song_read_text_stream(SingitSong *song, gchar *buffer)
 	song->lyric_lines = n;
 	song->lyrics = g_new (gchar*, n+1);
 
-	song->lyrics[n--] = NULL;
-	for (slist = string_list; slist; slist = slist->next)
-		song->lyrics[n--] = slist->data;
+	song->lyrics[n] = NULL;
+	n--;
+	for (slist = string_list; slist; slist = slist->next) {
+		song->lyrics[n] = slist->data;
+		n--;
+	}
+
 	g_slist_free (string_list);
 
 	if (song->first_token != NULL) {
@@ -314,10 +365,11 @@ gboolean singit_song_read_text_stream(SingitSong *song, gchar *buffer)
 
 gboolean singit_song_write_text_stream(SingitSong *song, gchar **buffer, gint tag_type)
 {
-	gchar **stream, *tmp = NULL, *connected = NULL;
+	gchar **stream, **stream_start, *tmp = NULL, *connected = NULL;
 	GList *item;
 	gchar timeToken[12];
 	gint i, offset = 0, last_line = -1;
+	gint special = 0;
 
 #ifdef CODEDEBUG
 	DEBUG(8, ("singit_song.c [singit_song_write_text_stream]\n"));
@@ -328,27 +380,48 @@ gboolean singit_song_write_text_stream(SingitSong *song, gchar **buffer, gint ta
 
 	timeToken[7] = '\0';
 	timeToken[11] = '\0';
-	stream = g_new(gchar*, song->lyric_lines + 1);
+
+	if (song ->artist != NULL) { special++; }
+	if (song ->title != NULL) { special++; }
+	if (song ->album != NULL) { special++; }
+
+	stream_start = stream = g_new(gchar*, song->lyric_lines + special + 1);
+	stream = &stream_start[special];
 	stream[song->lyric_lines] = NULL;
 	for (i = 0; i < (gint) song->lyric_lines; i++)
 		{ stream[i] = g_strdup(song->lyrics[i]); }
 	item = song->first_token;
 
+	// Insert the special tags
+	i = 0;
+	if (song ->artist != NULL) {
+		stream_start[i] = g_strconcat("[ar:", song->artist, "]", NULL);
+		i++;
+	}
+	if (song ->album != NULL) {
+		stream_start[i] = g_strconcat("[al:", song->album, "]", NULL);
+		i++;
+	}
+	if (song ->title != NULL) {
+		stream_start[i] = g_strconcat("[ti:", song->title, "]", NULL);
+		i++;
+	}
+
 	if ((tag_type != 3) && (tag_type != 2))
 		{ tag_type = 1; }
-		
+
 	while (item) {
 		switch (tag_type) {
 		case 3:
-			sprintf(timeToken, "[%.2i:%.2i.%.2i]", tTime(item) / 60000, 
+			sprintf(timeToken, "[%.2i:%.2i.%.2i]", tTime(item) / 60000,
 				(tTime(item) / 1000) % 60, (tTime(item) % 1000) / 10);
 			break;
 		case 2:
-			sprintf(timeToken, "[%.2i:%.2i:%.3i]", tTime(item) / 60000, 
+			sprintf(timeToken, "[%.2i:%.2i:%.3i]", tTime(item) / 60000,
 				(tTime(item) / 1000) % 60, tTime(item) % 1000);
 			break;
 		default:
-			sprintf(timeToken, "[%.2i:%.2i]", tTime(item) / 60000, 
+			sprintf(timeToken, "[%.2i:%.2i]", tTime(item) / 60000,
 				(tTime(item) / 1000) % 60);
 			break;
 		}
@@ -366,7 +439,9 @@ gboolean singit_song_write_text_stream(SingitSong *song, gchar **buffer, gint ta
 		item = g_list_next(item);
 	}
 
-	*buffer = g_strjoinv("\n", stream);
+	*buffer = g_strjoinv("\n", stream_start);
+	g_strfreev(stream_start);
+
 	return TRUE;
 }
 
@@ -397,7 +472,8 @@ gboolean singit_song_save_to_text_file(SingitSong *song, gchar *filename, gint t
         fclose(file);
 	g_free(buffer);
 
-	if (!song->lyric_filename) { song->lyric_filename = g_strdup(filename); }
+	if (!song->lyric_filename)
+		{ song->lyric_filename = g_strdup(filename); }
 
 	return TRUE;
 }
@@ -415,7 +491,7 @@ gboolean singit_song_load_from_text_file(SingitSong *song, gchar *filename)
 #endif
 
 	my_song = singit_song_attach(song);
-	if (my_song == NULL) 
+	if (my_song == NULL)
 		{ return FALSE; }
 
 	if ((stat(filename, &stats) == -1) ||
