@@ -19,9 +19,11 @@
 
 
 #ifdef HAVE_CONFIG_H
-# include <config.h>
+#include <config.h>
 #endif
 
+#include "singit_tools.h"
+
 #if HAVE_ERRNO_H
 # include <errno.h>
 #endif
@@ -33,9 +35,9 @@
 #include <string.h>
 #include <stdio.h>
 
-#include "singit_tools.h"
+#include <gtk/gtkmenu.h>
 
-gchar* tools_replace_string(const gchar *input_string, 
+gchar* tools_replace_string(const gchar *input_string,
 	const gchar *token, const gchar *replacement)
 {
 	gchar *new_text = NULL, *new_text_pos, *pos_begin, *pos_end;
@@ -86,7 +88,7 @@ gchar* tools_replace_string(const gchar *input_string,
 	return new_text;
 }
 
-gchar* tools_insert_string(const gchar *input_string, 
+gchar* tools_insert_string(const gchar *input_string,
 	const gchar *token, guint offset)
 {
 	gchar *new_text = NULL, *new_text_pos;
@@ -173,25 +175,25 @@ gint lines_length(const gchar **lines)
 {
 	gint i = 0;
 	gint length = 0;
-	
-	if (lines == NULL) 
+
+	if (lines == NULL)
 		{ return -1; }
-	
+
 	while (lines[i] != NULL) {
 		length += strlen(lines[i]);
 		i++;
 	}
-	
+
 	return length;
 }
 
 gint lines_count(const gchar **lines)
 {
 	gint i = 0;
-	
-	if (lines == NULL) 
+
+	if (lines == NULL)
 		{ return -1; }
-	
+
 	while (lines[i] != NULL) { i++; }
 
 	return i;
@@ -208,7 +210,7 @@ gboolean lines_info(const gchar **lines, guint *length, guint *count)
 		(*length) += strlen(lines[(*count)]);
 		(*count)++;
 	}
-	
+
 	return TRUE;
 }
 
@@ -220,7 +222,7 @@ gboolean create_abs_path(const gchar* path, __mode_t mode)
 
 	g_return_val_if_fail(path != NULL, FALSE);
 	g_return_val_if_fail(g_path_is_absolute(path), FALSE);
-	
+
 	cwd = g_get_current_dir();
 
 	// Does the path already exists ?
@@ -252,10 +254,10 @@ gboolean create_abs_path(const gchar* path, __mode_t mode)
 		i++;
 	}
 	g_strfreev(directories);
-	
+
 	chdir(cwd);
 	g_free(cwd);
-	
+
 	return result;
 }
 
@@ -277,7 +279,7 @@ uint32 io::readLENumber(ID3_Reader& reader, size_t len)
 uint32 io::readBENumber(ID3_Reader& reader, size_t len)
 {
 	uint32 val = 0;
-	
+
 	for (ID3_Reader::size_type i = 0; i < len && !reader.atEnd(); ++i)
 	{
 		val *= 256; // 2^8
@@ -289,12 +291,12 @@ uint32 io::readBENumber(ID3_Reader& reader, size_t len)
 
 gchar* create_centered_string(const gchar *input, guint size)
 {
-	gint len = strlen(input);
+	guint len = strlen(input);
 	gchar *result;
-	
+
 	if (len < size) {
 		gint add = (size - len) / 2;
-		
+
 		result = g_strnfill(size, ' ');
 		memcpy(result + add, input, len);
 	}
@@ -302,11 +304,11 @@ gchar* create_centered_string(const gchar *input, guint size)
 		result = g_strndup(input, size);
 	}
 	else { result = g_strdup(input); }
-	
+
 	return result;
 }
 
-void create_std_wgt_description(GtkWidget *widget, 
+void create_std_wgt_description(GtkWidget *widget,
 	const gchar* widget_var_name, gboolean show, GtkWidget *window)
 {
 	gtk_widget_set_name(widget, widget_var_name);
@@ -317,15 +319,15 @@ void create_std_wgt_description(GtkWidget *widget,
 		gtk_widget_show(widget);
 }
 
-const gchar* extract_basename_noext(const gchar *filename, gint *len) 
+const gchar* extract_basename_noext(const gchar *filename, gint *len)
 {
 	const char *basename, *ext;
 
 	g_return_val_if_fail(len != NULL, NULL);
-	
+
 	if (filename != NULL) {
 		basename = g_basename(filename);
-		if (basename == NULL) 
+		if (basename == NULL)
 			{ basename = filename; }
 
 		ext = strrchr(basename, '.');
@@ -337,3 +339,45 @@ const gchar* extract_basename_noext(const gchar *filename, gint *len)
 
 	return NULL;
 }
+
+GtkWidget* lookup_widget (GtkWidget *widget, const gchar *widget_name)
+{
+	GtkWidget *parent, *found_widget;
+
+	for (;;)
+	{
+		if (GTK_IS_MENU (widget))
+			parent = gtk_menu_get_attach_widget(GTK_MENU(widget));
+		else
+			parent = widget->parent;
+		if (parent == NULL)
+			break;
+		widget = parent;
+	}
+
+	found_widget = (GtkWidget*)
+		gtk_object_get_data(GTK_OBJECT(widget), widget_name);
+
+	if (!found_widget)
+		g_warning ("Widget not found: %s", widget_name);
+
+	return found_widget;
+}
+
+gchar* transadd(const gchar *trans_str, const gchar *add)
+{
+	static gchar* temp_str = NULL;
+
+	if (trans_str == NULL) {
+		g_free(temp_str);
+		temp_str = NULL;
+	}
+	else {
+		if (temp_str != NULL)
+			{ g_free(temp_str); }
+
+		temp_str = g_strconcat(trans_str, add, NULL);
+	}
+
+	return temp_str;
+}
