@@ -25,7 +25,7 @@
 #include <gtk/gtkwidget.h>
 #include <sys/stat.h>
 
-gchar* tools_replace_string (const gchar *input_string, 
+gchar* tools_replace_string (const gchar *input_string,
 	const gchar *token, const gchar *replacement);
 
 gchar* tools_insert_string
@@ -53,14 +53,20 @@ gboolean lines_info(const gchar **lines, guint *length, guint *count);
 // Tries to create an absolute path
 gboolean create_abs_path(const gchar* path, __mode_t mode);
 
-// Return a string that is centered 
+// Return a string that is centered
 gchar* create_centered_string(const gchar *input, guint size);
 
 // Create a widget with a gtk data attached description
-void create_std_wgt_description(GtkWidget *widget, 
+void create_std_wgt_description(GtkWidget *widget,
 	const gchar* widget_var_name, gboolean show, GtkWidget *window);
 
 // Extract the basename and cut of one extension by providing len
 const gchar* extract_basename_noext(const gchar *filename, gint *len);
 
+GtkWidget* lookup_widget (GtkWidget *widget, const gchar *widget_name);
+
+// A little helper funtion to append a string to a translation
+// You do not need to free it
+gchar* transadd(const gchar *trans_str, const gchar *add);
+
 #endif // __SINGIT_TOOLS__
