@@ -21,7 +21,7 @@
 #ifndef __SINGIT_SOUND_PRECALCS_PRIVATE_H__
 #define __SINGIT_SOUND_PRECALCS_PRIVATE_H__
 
-#include "singit_sound_precalcs.h"
+#include "singit/sound_precalcs.h"
 
 #ifdef __cplusplus
 extern "C" {
