@@ -32,10 +32,8 @@
 #include <xmms/xmmsctrl.h>
 
 #include "singit_debug.h"
-#include "singit_config.h"
-#include "singit_config_gen.h"
-#include "singit_macros.h"
-#include "singit_config_private.h"
+#include "singit/config_gen.h"
+#include "singit/macros.h"
 #include "singit_tools.h"
 
 #include "list_genres.h"
@@ -85,7 +83,6 @@ static GSList	*id3_modes_group = NULL,
 
 Id3DlgStatus id3dlg_status;
 
-extern SingitConfigGen *singit_config;
 extern VisPlugin singit_vp;
 
 static void singit_language_entry_event(GtkEntry *entry, gpointer user_data)
@@ -199,7 +196,7 @@ static void fill_genre_combo (GtkWidget *combo)
 
 	if (items == NULL) {
 		while (list_genres[i] != NULL) {
-			items = g_list_append(items, 
+			items = g_list_append(items,
 				(gchar*) list_genres[i]);
 			i++;
 		}
@@ -214,7 +211,7 @@ static void fill_language_combo (GtkWidget *combo)
 
 	if (items == NULL) {
 		for (i = 0; i < list_languages_count; i++) {
-			items = g_list_append(items, 
+			items = g_list_append(items,
 				(gchar*) list_languages[i].language_string);
 		}
 	}
@@ -509,34 +506,10 @@ static void singit_tag_manager_fill_dialog(gchar *file_name)
 	}
 }
 
-static void id3v2_select_button_clicked (GtkButton *button, gpointer user_data)
-{
-	if (GTK_IS_CHECK_BUTTON(button)) {
-		if (GTK_TOGGLE_BUTTON(button)->active) { id3dlg_status.id3v2Usage++; }
-		else { id3dlg_status.id3v2Usage--; }
-	}
-}
-
-gchar* transadd(const gchar *trans_str, const gchar *add)
-{
-	static gchar* temp_str = NULL;
-
-	if (trans_str == NULL) {
-		g_free(temp_str);
-		temp_str = NULL;
-	}
-	else {
-		if (temp_str != NULL)
-			{ g_free(temp_str); }
-
-		temp_str = g_strconcat(trans_str, add, NULL);
-	}
-
-	return temp_str;
-}
-
 static void singit_tag_manager_init()
 {
+	SingitConfigGen *scg_o;
+
 #ifdef CODEDEBUG
 	DEBUG(DLV_ALL, ("dlg_singit_tag_manager.c [singit_tag_manager_init]\n"));
 #endif
@@ -549,12 +522,14 @@ static void singit_tag_manager_init()
 
 	id3dlg_status.info_type = IT_ID3;
 
-	g_return_if_fail(singit_config != NULL);
-	singit_config_gen_attach(singit_config);
+	scg_o = STATUS->config;
+	g_return_if_fail(scg_o != NULL);
+	singit_config_gen_attach(scg_o);
 }
 
 static void singit_tag_manager_cleanup()
 {
+	SingitConfigGen *scg_o;
 #ifdef CODEDEBUG
 	DEBUG(DLV_ALL, ("singit_config.c [singit_tag_manager_cleanup]\n"));
 #endif
@@ -574,8 +549,8 @@ static void singit_tag_manager_cleanup()
 		id3dlg_status.mpeg_info = NULL;
 	}
 
-//	singit_config_gen_save(SINGIT_CONFIG_GEN(singit_config));
-	singit_config_gen_detach(SINGIT_CONFIG_GEN(singit_config));
+	scg_o = STATUS->config;
+	singit_config_gen_detach(&scg_o);
 
 	id3_modes_group = NULL;
 	id3_strict_modes_group = NULL;
@@ -955,7 +930,7 @@ void singit_tag_manager_show(void)
 	singit_tag_manager_init();
 
 	// Do we have a song?
-	if (!singit_config || ((my_song = singit_song_attach(GET_SCD->song)) == NULL)) {
+	if (!STATUS || ((my_song = singit_song_attach(STATUS->song)) == NULL)) {
 		singit_tag_manager_cleanup();
 		return;
 	}
