@@ -24,42 +24,17 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
+#include <math.h>
 
 #include "singit_debug.h"
 
-#include "singit_karaoke_data.h"
+#include "singit/karaoke_data.h"
 #include "singit_tools.h"
 
+#include "singit_marshallers.h"
+
 #define left_right_line_border ((skd->ball_diameter / 2) + 1)
 
-/*
-	signal marshaller to marshal a int result and two pointer arguments
-*/
-typedef gint (*GtkSignal_INT__POINTER_POINTER)(GtkObject *object, gpointer arg1, gpointer arg2, gpointer user_data);
-
-static void gtk_marshal_INT__POINTER_POINTER(GtkObject* object, GtkSignalFunc func, gpointer func_data, GtkArg* args)
-{
-	GtkSignal_INT__POINTER_POINTER rfunc;
-	gint *return_val;
-	return_val = GTK_RETLOC_INT(args[2]);
-	rfunc = (GtkSignal_INT__POINTER_POINTER) func;
-	*return_val = (*rfunc)(object, GTK_VALUE_POINTER(args[0]), GTK_VALUE_POINTER(args[1]), func_data);
-}
-
-/*
-	signal marshaller to marshal a bool result and a pointer and two integer arguments
-*/
-typedef gboolean (*GtkSignal_BOOL__POINTER_INT_INT)(GtkObject *object, gpointer arg1, gint arg2, gint arg3, gpointer user_data);
-
-void gtk_marshal_BOOL__POINTER_INT_INT(GtkObject* object, GtkSignalFunc func, gpointer func_data, GtkArg* args)
-{
-	GtkSignal_BOOL__POINTER_INT_INT rfunc;
-	gboolean *return_val;
-	return_val = GTK_RETLOC_BOOL(args[3]);
-	rfunc = (GtkSignal_BOOL__POINTER_INT_INT) func;
-	*return_val = (*rfunc)(object, GTK_VALUE_POINTER(args[0]), GTK_VALUE_INT(args[1]), GTK_VALUE_INT(args[2]), func_data);
-}
-
 /*
  * Uncomment to enable extended debug messages
  */
@@ -71,15 +46,16 @@ void gtk_marshal_BOOL__POINTER_INT_INT(GtkObject* object, GtkSignalFunc func, gp
  */
 enum {
 
-	SONG_CHG = 1 << 1,		// Song has changed
-	FONT_CHG = 1 << 2,		// Font has changed
-	LINE_CHG = 1 << 3		// No of lines has changed
+	SONG_CHG = 1 << 1,	// Song has changed
+	FONT_CHG = 1 << 2,	// Font has changed
+	LINE_CHG = 1 << 3,	// No of lines has changed
+	OPTM_CHG = 1 << 4,	// Any data for font optimization changed
 };
 
-void calc_karaoke_widget_sizes(SingitKaraokeData *skd, gint change);
-void singit_karaoke_data_update_ball(SingitKaraokeData *skd, GdkRectangle *main_area);
-void singit_karaoke_data_update_progess_bar(SingitKaraokeData *skd, gchar *text, GdkRectangle *main_area);
-void skd_draw_line_rects(SingitKaraokeData *skd, GdkPixmap *pixmap, GdkGC *draw_gc);
+static void calc_karaoke_widget_sizes(SingitKaraokeData *skd);
+static void singit_karaoke_data_optimize_font_int(SingitKaraokeData *skd);
+static void singit_karaoke_data_update_ball(SingitKaraokeData *skd, GdkRectangle *main_area);
+static void singit_karaoke_data_update_progess_bar(SingitKaraokeData *skd, gchar *text, GdkRectangle *main_area);
 
 enum {
 	RENDER,
@@ -98,6 +74,8 @@ static void singit_karaoke_data_init (SingitKaraokeData *skd);
 
 static void singit_karaoke_data_destroy(GtkObject *object);
 
+static void str_line_info_free(StrLineInfo* sli);
+
 GtkType singit_karaoke_data_get_type (void)
 {
 	static GtkType singit_karaoke_data_type = 0;
@@ -139,12 +117,13 @@ static void singit_karaoke_data_class_init (SingitKaraokeDataClass *klass)
 
 	skd_signals[OPTIMIZE] =
 		gtk_signal_new("optimize",
-			GTK_RUN_FIRST,
+			GTK_RUN_LAST,
 			object_class->type,
 			GTK_SIGNAL_OFFSET (SingitKaraokeDataClass, optimize),
-			gtk_marshal_NONE__POINTER,
-			GTK_TYPE_NONE, 1,
-			GTK_TYPE_POINTER);
+			gtk_marshal_POINTER__INT_INT,
+			GTK_TYPE_POINTER, 2,
+			GTK_TYPE_INT,
+			GTK_TYPE_INT);
 
 	skd_signals[EXPOSE] =
 		gtk_signal_new("expose",
@@ -214,8 +193,10 @@ static void singit_karaoke_data_init (SingitKaraokeData *skd)
 
 	skd->use_ball = TRUE;
 
+	skd->max_line_nr = -1;
+	skd->max_line_pixel = -1;
+
 	skd->show_empty_lines = FALSE;
-	skd->maxLineWidth = FALSE;
 	skd->last_time = -1;
 	skd->line_seperator_high = 5;
 	skd->active_line_seperator_high = skd->line_seperator_high * 2;
@@ -223,6 +204,9 @@ static void singit_karaoke_data_init (SingitKaraokeData *skd)
 
 	skd->font = NULL;
 	skd->centerLines = FALSE;
+
+	skd->freezers = 0;
+	skd->thaw_refresh = 0;
 }
 
 GtkObject *singit_karaoke_data_new(void)
@@ -238,20 +222,6 @@ GtkObject *singit_karaoke_data_new(void)
 	return karaoke_data_object;
 }
 
-static void singit_karaoke_data_free_line_info(StrLineInfo *line_info)
-{
-#ifdef SKD_DEBUG
-	g_print("skd_free_line_data\n");
-#endif
-
-	g_return_if_fail (line_info != NULL);
-
-	if (line_info->word_pixel != NULL) { g_free(line_info->word_pixel); }
-	if (line_info->space_pixel != NULL) { g_free(line_info->space_pixel); }
-	if (line_info->start_pixel != NULL) { g_free(line_info->start_pixel); }
-	g_free(line_info);
-}
-
 static void singit_karaoke_data_destroy (GtkObject *object)
 {
 	SingitKaraokeData *skd;
@@ -268,12 +238,118 @@ static void singit_karaoke_data_destroy (GtkObject *object)
 	singit_song_detach(&skd->song);
 
 	if (skd->line_info != NULL)
-		{ singit_karaoke_data_free_line_info(skd->line_info); }
+		{ str_line_info_free(skd->line_info); }
 
 	if (GTK_OBJECT_CLASS(parent_class)->destroy)
 		GTK_OBJECT_CLASS(parent_class)->destroy (object);
 }
 
+static StrLineInfo* str_line_info_new
+	(gchar *text, gint pixel_len, gint word_count)
+{
+	StrLineInfo *result;
+
+#ifdef SKD_DEBUG
+	g_print("str_line_info_new\n");
+#endif
+	result = g_malloc(sizeof(StrLineInfo));
+
+	if (result != NULL) {
+		result->text = text;
+		result->str_len = strlen(text);
+		result->str_pixel = pixel_len;
+
+		if (word_count > 0) {
+			result->word_pixel = g_malloc(sizeof(gint) * (word_count + 1));
+			result->word_pixel[word_count] = 0;
+			result->start_pixel = g_malloc(sizeof(gint) * (word_count + 1));
+			result->start_pixel[word_count] = pixel_len;
+			result->start_pixel[0] = 0;
+
+			result->jump_radius = g_malloc(sizeof(gdouble) * word_count);
+			result->jump_radius[word_count - 1] = 0;
+			result->jump_angle = g_malloc(sizeof(gdouble) * word_count);
+			result->jump_angle[word_count - 1] = 0;
+
+			result->space_pixel = g_malloc(sizeof(gint) * word_count);
+			result->space_pixel[word_count - 1] = 0;
+		}
+		else {
+			result->word_pixel = NULL;
+			result->start_pixel = NULL;
+
+			result->jump_radius = NULL;
+			result->jump_angle = NULL;
+
+			result->space_pixel = NULL;
+		}
+	}
+
+	return result;
+}
+
+static void str_line_info_free(StrLineInfo* sli)
+{
+#ifdef SKD_DEBUG
+	g_print("str_line_info_free\n");
+#endif
+	g_return_if_fail(sli != NULL);
+
+	if (sli->word_pixel != NULL) { g_free(sli->word_pixel); }
+	if (sli->space_pixel != NULL) { g_free(sli->space_pixel); }
+	if (sli->start_pixel != NULL) { g_free(sli->start_pixel); }
+	if (sli->jump_radius != NULL) { g_free(sli->jump_radius); }
+	if (sli->jump_angle != NULL) { g_free(sli->jump_angle); }
+
+	g_free(sli);
+}
+
+/*
+ * Check if the StrLineInfo has to be updated
+ * Also set the required data, if needed
+ */
+static inline gboolean str_line_info_need_update(StrLineInfo** sli,
+	gchar *text, gchar ***splitted_line, gint *word_count)
+{
+	g_return_val_if_fail(sli != NULL, FALSE);
+	g_return_val_if_fail(splitted_line != NULL, FALSE);
+	g_return_val_if_fail(word_count != NULL, FALSE);
+
+	if ((text != NULL) && (strlen(text) > 0)) {
+		if ((*sli) != NULL) {
+			if (((*sli)->text != NULL) &&
+				(strcmp(text, (*sli)->text) == 0))
+			{
+				return FALSE;
+			}
+			str_line_info_free(*sli);
+			(*sli) = NULL;
+		}
+	}
+	else {
+		if ((*sli) != NULL) {
+			str_line_info_free(*sli);
+			(*sli) = NULL;
+		}
+		return FALSE;
+	}
+
+	(*splitted_line) = g_strsplit(text, " ", 0);
+	(*word_count) = lines_count
+		((const gchar**) (*splitted_line));
+
+	if (word_count == 0) {
+		g_strfreev((*splitted_line));
+		if ((*sli) != NULL) {
+			str_line_info_free(*sli);
+			(*sli) = NULL;
+		}
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
 /*
  * Splits the active line into word sizes, so the ball knows where to drop
  * This is needed because of different space sizes between the words
@@ -281,142 +357,127 @@ static void singit_karaoke_data_destroy (GtkObject *object)
  * Expl.:
  *
  * String: I'm here and there
- * Splits: I'm| |here| |and| |there|
-
- * You get 7 split position
+ * Splits: |I'm |here |and |there|
+ *
+ * You get 5 start positions, 4 space and word lengths
  * The ball jumps from the start to the middle of the first and second position...
  */
-static void singit_karaoke_data_fill_str_line_info(SingitKaraokeData *skd, gchar *in_text)
+static void singit_karaoke_data_fill_str_line_info
+	(SingitKaraokeData *skd, gchar *in_text)
 {
 	gchar **splitted_line = NULL, *text_dup;
-	gint counter;
+	gint i;
 	gint textpos;
 	gint word_count, space_count;
+	gint pixel_len;
+
+	g_return_if_fail(skd != NULL);
 
 #ifdef SKD_DEBUG
 	g_print("skd_fill_str_line_slinfo\n");
 #endif
 
-/*
- * Checks for changed lines and if do free or new slinfo creation is required
- */
-	g_return_if_fail(skd != NULL);
-
-	if ((in_text != NULL) && (strlen(in_text) > 0)) {
-		if (skd->line_info != NULL) {
-			if ((skd->line_info->text != NULL) &&
-				(strcmp(in_text, skd->line_info->text) == 0)) { return; }
-			singit_karaoke_data_free_line_info(skd->line_info);
-		}
-	}
-	else {
-		if (skd->line_info != NULL) {
-			singit_karaoke_data_free_line_info(skd->line_info);
-			skd->line_info = NULL;
-		}
+// * Checks for changed lines and if do free or new slinfo creation is required
+	if (str_line_info_need_update(&skd->line_info,
+		in_text, &splitted_line, &word_count) == FALSE)
+	{
 		return;
 	}
 
-	/* count words */
-	splitted_line = g_strsplit(in_text, " ", 0);
-	word_count = 0;
-	while (splitted_line[word_count] != 0) { word_count++; }
+	// Set the line_info to
+	skd->line_info = NULL;
+	g_return_if_fail(skd->font != NULL);
 
-	if (word_count == 0) {
-		g_strfreev(splitted_line);
-		if (skd->line_info != NULL) {
-			singit_karaoke_data_free_line_info(skd->line_info);
-			skd->line_info = NULL;
-		}
-		return;
-	}
 	space_count = word_count - 1;
 
-/*
- * Prepare new line slinfo
- */
-	skd->line_info = g_malloc(sizeof(StrLineInfo));
-	skd->line_info->text = in_text;
-	skd->line_info->str_len = strlen(in_text);
-	gtk_signal_emit(GTK_OBJECT(skd), skd_signals[RENDER], skd->font, in_text, &skd->line_info->str_pixel);
+// * Prepare new line slinfo
+	gtk_signal_emit(GTK_OBJECT(skd), skd_signals[RENDER],
+			skd->font, in_text, &pixel_len);
 
-	if (word_count > 0) {
-		skd->line_info->word_pixel = g_malloc(sizeof(gint) * (word_count+1));
-		skd->line_info->word_pixel[word_count] = 0;
-		skd->line_info->start_pixel = g_malloc(sizeof(gint) * (word_count+1));
-		skd->line_info->start_pixel[word_count] = 0;
-	}
-	else {
-		skd->line_info->word_pixel = NULL;
-		skd->line_info->start_pixel = NULL;
-	}
+	skd->line_info = str_line_info_new
+		(in_text, pixel_len, word_count);
 
-	if (space_count > 0) {
-		skd->line_info->space_pixel = g_malloc(sizeof(gint) * (space_count+1));
-		skd->line_info->space_pixel[space_count] = 0;
-	}
-	else { skd->line_info->space_pixel = NULL; }
-
-	counter = space_count;
-
-/*
- * Fill word and space pixel lengths
- */
+// * Fill word pixel lengths
+	i = word_count;
 	textpos = skd->line_info->str_len;
 	text_dup = g_strdup(in_text);
 
-	while (counter >= 0) {
+	while (i > 0) {
 		text_dup[textpos] = '\0';
 
 		// get the length of the text if not full length
-//		if (textpos != slinfo->str_len)
-			gtk_signal_emit(GTK_OBJECT(skd), skd_signals[RENDER], skd->font, text_dup,
-				&skd->line_info->start_pixel[counter]);
+		gtk_signal_emit(GTK_OBJECT(skd), skd_signals[RENDER],
+			skd->font, text_dup, &skd->line_info->start_pixel[i]);
 
 		// make the text one word shorter
-		if (textpos >= 0) {
-			textpos -= (strlen(splitted_line[counter]) + 1);
-		}
+		i--;
+		textpos -= (strlen(splitted_line[i]));
 
 		// get the length of the word
-		gtk_signal_emit(GTK_OBJECT(skd), skd_signals[RENDER], skd->font,
-			(gchar*)(text_dup + textpos + 1), &skd->line_info->word_pixel[counter]);
-
-		counter--;
+		gtk_signal_emit(GTK_OBJECT(skd), skd_signals[RENDER],
+			skd->font, (gchar*)(text_dup + textpos),
+			&skd->line_info->word_pixel[i]);
+		textpos--;
 	}
 	g_strfreev(splitted_line);
-
-	// calculate the spaces if we have some
-	if (space_count > 0) {
-		counter = 0;
-		if (space_count > 1) {
-			while (counter < space_count) {
-				skd->line_info->space_pixel[counter] = skd->line_info->start_pixel[counter+1] -
-					skd->line_info->start_pixel[counter] - skd->line_info->word_pixel[counter+1];
-				counter++;
-			}
-		}
-		skd->line_info->space_pixel[counter] = skd->line_info->str_pixel -
-			skd->line_info->start_pixel[counter] - skd->line_info->word_pixel[counter+1];
-	}
 	g_free(text_dup);
 
+// * Correct start pixels and fill space pixel lengths
+	for (i = 0; i < space_count; i++) {
+		skd->line_info->start_pixel[i+1] =
+			skd->line_info->start_pixel[i+2] -
+			skd->line_info->word_pixel[i+1];
+
+		skd->line_info->space_pixel[i] =
+			skd->line_info->start_pixel[i+1] -
+			skd->line_info->start_pixel[i] -
+			skd->line_info->word_pixel[i];
+	}
+
+	gint jump_distance = 0;
+	gdouble half_distance;
+	gint height;
+	gdouble beta;
+	gdouble x, rad;
+
+// * Set jump radias and angles *
+	for (i = 0; i < word_count; i++) {
+		jump_distance = skd->line_info->start_pixel[i+1] -
+			skd->line_info->start_pixel[i];
+
+		// * For more information see "docs/karaoke-data" *
+		height = MIN((jump_distance - skd->ball_diameter) / 2,
+			skd->ball_line_height - skd->ball_diameter);
+		height = MAX(height,
+			(skd->ball_line_height - skd->ball_diameter) / 2);
+
+		half_distance = jump_distance / 2.0;
+		beta = atan(half_distance / height);
+		x = hypot(half_distance, height);
+		skd->line_info->jump_radius[i] = rad =
+			(x / 2.0) / cos(beta);
+		skd->line_info->jump_angle[i] =
+			acos((rad - height) / rad);
+	}
+
 #ifdef SKD_DEBUG
-	counter = 0;
-	while (skd->line_info->start_pixel[counter+1] != 0) {
-		g_print("| %.4i |      ", skd->line_info->start_pixel[counter]);
-		counter++;
+	g_print("ST: ");
+	for (i = 0; skd->line_info->start_pixel[i] != pixel_len; i++) {
+		g_print("| %.4i ", skd->line_info->start_pixel[i]);
+		if (skd->line_info->start_pixel[i+1] != pixel_len)
+			g_print("       ");
+		else
+			g_print("| %.4i", skd->line_info->start_pixel[i+1]);
 	}
-	g_print("| %.4i |\n", skd->line_info->start_pixel[counter]);
-	counter = 0;
-	while (skd->line_info->word_pixel[counter] != 0) {
-		g_print("| %.4i ", skd->line_info->word_pixel[counter]);
-		if (skd->line_info->space_pixel[counter] != 0)
-			{ g_print("| %.4i ", skd->line_info->space_pixel[counter]); }
-		counter++;
-	}
-	g_print("|\n");
+	g_print("\nWD: ");
+	for (i = 0; skd->line_info->word_pixel[i] != 0; i++)
+		{ g_print("| %.4i |      ", skd->line_info->word_pixel[i]); }
+	g_print("\nSP:  ");
+	for (i = 0; skd->line_info->space_pixel[i] != 0; i++)
+		{ g_print("      | %.4i |", skd->line_info->space_pixel[i]); }
+	g_print("\n");
 #endif
+#undef SMALLEST_JUMP
 }
 
 /*
@@ -425,69 +486,73 @@ static void singit_karaoke_data_fill_str_line_info(SingitKaraokeData *skd, gchar
  */
 static void singit_karaoke_data_set_curr_y_pos(SingitKaraokeData *skd)
 {
-/*
- * This is the smallest range the ball can jump
- * It's the pixel size of the characters "IM"
- */
-#define SMALLEST_JUMP "IM"
-
 	guint x_pbp_position;
-	gint cur_word_pos, new_ball_pos_index = 0, min_size, new_pos = 0;
+	gint cur_word_pos;
 	gint real_max_height = skd->ball_line_height - skd->ball_diameter;
-	gboolean found = FALSE;
-	StrLineInfo *info;
+	StrLineInfo *info = skd->line_info;
 
-	if ((skd->line_info == NULL) || ((skd->pbp_start == 0) && (skd->pbp_offset == 0))) {
+	static gint j = 0;
+	gint i;
+
+	// If we have no line info set the ball to the ground
+	if ((skd->line_info == NULL) ||
+		((skd->pbp_start == 0) && (skd->pbp_offset == 0)))
+	{
 		skd->ball_y_pos = real_max_height;
 		return;
 	}
 
 	x_pbp_position = skd->pbp_start + skd->pbp_offset;
+
+	// If we are still in th range of the last calculation, skip it
 	if ((x_pbp_position < skd->ball_start) ||
 		(x_pbp_position > (skd->ball_start + skd->ball_offset_max)))
 	{
-		info = skd->line_info;
-		new_pos = 0;
-		while ((found != TRUE) && info->start_pixel[new_ball_pos_index]) {
-			if (info->start_pixel[new_ball_pos_index] > (gint) x_pbp_position)
+		i = 0;
+		while (1) {
+			if (info->jump_radius[i] > 0.0)
+				{ j = i; }
+			if (info->start_pixel[i] > (gint) x_pbp_position)
 			{
-				if (new_ball_pos_index == 0) { new_pos = 0; }
-				else { new_pos = info->start_pixel[new_ball_pos_index - 1]; }
-				new_ball_pos_index--;
-				found = TRUE;
-			}
-			new_ball_pos_index++;
-		}
+				if (i == 0) {
+					j = i;
+				}
+				i--;
+				if (i < j)
+					j = i;
 
-		if ((gint) skd->pbp_start > new_pos) { skd->ball_start= skd->pbp_start; }
-		else { skd->ball_start = new_pos; }
+				skd->ball_start = info->start_pixel[j];
 
-		new_pos = 0;
-		gtk_signal_emit(GTK_OBJECT(skd), skd_signals[RENDER], skd->font, 
-			SMALLEST_JUMP, &min_size);
-		while ((new_pos < min_size) && info->start_pixel[new_ball_pos_index]) {
-			new_pos = info->start_pixel[new_ball_pos_index] - skd->ball_start;
-			if (((skd->pbp_offset_max + skd->pbp_start) < (skd->ball_start + new_pos)) &&
-				((skd->pbp_offset_max - skd->pbp_offset) > (guint) min_size))
-			{
-				new_pos = skd->pbp_offset_max + skd->pbp_start - skd->ball_start;
+				skd->ball_offset_max =
+					info->start_pixel[i+1] -
+					skd->ball_start;
+				break;
 			}
-			new_ball_pos_index++;
+			if (info->start_pixel[i] == info->str_pixel) {
+				skd->ball_start = skd->ball_offset_max = 0;
+				break;
+			}
+			i++;
 		}
-		skd->ball_offset_max = new_pos;
 	}
 
-	cur_word_pos = x_pbp_position - skd->ball_start;
-	if (skd->ball_offset_max == 0) {  skd->ball_y_pos = real_max_height; }
-	else {
-		new_pos = 2 * (cur_word_pos / (double) skd->ball_offset_max) * real_max_height;
-		if (new_pos < real_max_height) { new_pos = real_max_height - new_pos; }
-		else { new_pos = new_pos - real_max_height; }
-		skd->ball_y_pos = new_pos;
-	}
+	if (skd->ball_offset_max != 0) {
+		cur_word_pos = x_pbp_position - skd->ball_start;
 
-//	g_print("Pos Y : %i\n", skd->ball_y_pos);
-#undef SMALLEST_JUMP
+		// Why is there a difference between signed end unsigned??? ;-(
+		gdouble beta = info->jump_angle[j] /
+			(gint) skd->ball_offset_max *
+			((gint) skd->ball_offset_max - 2 * cur_word_pos);
+
+		skd->ball_y_pos = (int)
+			rint((1 - cos(beta)) * info->jump_radius[j])
+			+ real_max_height -
+			((1 - cos(info->jump_angle[j])) * info->jump_radius[j]);
+//		g_print("%i / %i / %f / %f\n", i, skd->ball_y_pos,
+//			(1 - cos(beta)) * info->jump_radius[j],
+//			(1 - cos(info->jump_angle[j])) * info->jump_radius[j]);
+	}
+	else { skd->ball_y_pos = real_max_height; }
 }
 
 /*
@@ -503,14 +568,19 @@ static gint singit_karaoke_data_get_offset_pos(SingitKaraokeData *skd, gchar *te
 	gint str_pixel;
 	gchar *offset_pos;
 	gchar old_char;
-
 	gint start_pixel, end_pixel, start_pos, end_pos;
 
-	if (pos == 0) { return 0; }
+	g_return_val_if_fail(text != NULL, 0);
+	g_return_val_if_fail(pos >= 0, 0);
+
+	if (pos == 0)
+		{ return 0; }
 
 	str_len = strlen(text);
-	gtk_signal_emit(GTK_OBJECT(skd), skd_signals[RENDER], skd->font, text, &str_pixel);
-	if (pos == str_len) { return str_pixel; }
+	gtk_signal_emit(GTK_OBJECT(skd),
+		skd_signals[RENDER], skd->font, text, &str_pixel);
+	if (pos == str_len)
+		{ return str_pixel; }
 
 	// If we have some spaces at the position in the string...
 	if ((text[pos-1] == ' ') || (text[pos] == ' '))
@@ -519,7 +589,9 @@ static gint singit_karaoke_data_get_offset_pos(SingitKaraokeData *skd, gchar *te
 		end_pos = pos;
 		while ((end_pos < str_len) && (text[end_pos] == ' ')) { end_pos++; }
 		if (end_pos < str_len) {
-			gtk_signal_emit(GTK_OBJECT(skd), skd_signals[RENDER], skd->font, &text[end_pos], &end_pixel);
+			gtk_signal_emit(GTK_OBJECT(skd),
+				skd_signals[RENDER], skd->font,
+				&text[end_pos], &end_pixel);
 		}
 		else { end_pixel = 0; }
 
@@ -530,7 +602,9 @@ static gint singit_karaoke_data_get_offset_pos(SingitKaraokeData *skd, gchar *te
 			offset_pos = text + start_pos + 1;
 			old_char = offset_pos[0];
 			offset_pos[0] = '\0';
-			gtk_signal_emit(GTK_OBJECT(skd), skd_signals[RENDER], skd->font, text, &start_pixel);
+			gtk_signal_emit(GTK_OBJECT(skd),
+				skd_signals[RENDER],
+				skd->font, text, &start_pixel);
 			offset_pos[0] = old_char;
 		}
 		else { start_pixel = 0; }
@@ -546,7 +620,8 @@ static gint singit_karaoke_data_get_offset_pos(SingitKaraokeData *skd, gchar *te
 		offset_pos = text + pos;
 		old_char = offset_pos[0];
 		offset_pos[0] = '\0';
-		gtk_signal_emit(GTK_OBJECT(skd), skd_signals[RENDER], skd->font, text, &str_pixel);
+		gtk_signal_emit(GTK_OBJECT(skd),
+			skd_signals[RENDER], skd->font, text, &str_pixel);
 		offset_pos[0] = old_char;
 	}
 
@@ -592,19 +667,19 @@ void singit_karaoke_data_set_time (SingitKaraokeData *skd, guint time)
 	SingitSong *my_song = NULL;
 	gchar *text = NULL, *startPos;
 	double multi = 0.0;
-	/* Calculate the karaoke dependant exposure area */
+
+	// * Calculate the karaoke dependant exposure area *
 	GdkRectangle area;
 	gboolean new_has_offset, new_next_has_offset = FALSE;
 	gint expose = 0;
 	gboolean redrawn = FALSE;
 
-	/* First the obvious security checks */
+	// * First a few security checks *
 	g_return_if_fail(skd != NULL);
 	g_return_if_fail(IS_SINGIT_KARAOKE_DATA(skd));
+	g_return_if_fail(skd->font != NULL);
 
-	if (skd->font == NULL) { return; }
-	
-	/* If time didn't change keep old values */
+	// * If time didn't change keep old values *
 	if (skd->last_time == (gint) time) { return; }
 	else { skd->last_time = time; }
 
@@ -618,13 +693,13 @@ void singit_karaoke_data_set_time (SingitKaraokeData *skd, guint time)
 		new_item = my_song->active_token;
 		new_item_next = inl_singit_song_get_next_token(my_song);
 
-		/* Do we have a new next token? */
+		// * Do we have a new next token? *
 		if ((new_item != NULL) && (new_item != skd->current))
 		{
 			text = tText(my_song, new_item);
 			new_has_offset = (tPos(new_item) > 0);
 
-			/* Does the token next to the new token have an offset? */
+			// * Does the token next to the new token have an offset? *
 			if ((new_item_next != NULL) &&
 				(tLine(new_item_next) == tLine(new_item)) &&
 				(tPos(new_item_next) != strlen(text)) &&
@@ -633,12 +708,12 @@ void singit_karaoke_data_set_time (SingitKaraokeData *skd, guint time)
 				new_next_has_offset = TRUE;
 			}
 
-			/* Do we have any offsets? */
+			// * Do we have any offsets? *
 			if (new_has_offset || new_next_has_offset) {
 				// Yes
 				startPos = text;
 
-				/* Dependant on the offset of the new token get the pbp start */
+				// * Dependant on the offset of the new token get the pbp start *
 				if (new_has_offset) {
 					startPos += tPos(new_item);
 					skd->pbp_start =
@@ -646,7 +721,7 @@ void singit_karaoke_data_set_time (SingitKaraokeData *skd, guint time)
 				}
 				else { skd->pbp_start = 0; }
 
-				/* Dependant on the offset of the next new token get the pbp max offset */
+				// * Dependant on the offset of the next new token get the pbp max offset *
 				if (new_next_has_offset) {
 					skd->pbp_offset_max =
 						singit_karaoke_data_get_offset_pos
@@ -658,26 +733,32 @@ void singit_karaoke_data_set_time (SingitKaraokeData *skd, guint time)
 				}
 			}
 			else {
-				/* No offsets - start at zero and end at the text length */
+				// * No offsets - start at zero and end at the text length *
 				skd->pbp_start = 0;
-				skd->ball_y_pos = skd->ball_line_height - skd->ball_diameter;
-				gtk_signal_emit(GTK_OBJECT(skd), skd_signals[RENDER], skd->font, text, &skd->pbp_offset_max);
+				skd->ball_y_pos =
+					skd->ball_line_height - skd->ball_diameter;
+				gtk_signal_emit(GTK_OBJECT(skd),
+					skd_signals[RENDER], skd->font,
+					text, &skd->pbp_offset_max);
 			}
 			skd->pbp_offset = 0;
 
-			/* Do we have to redraw the whole widget? */
-			if ((skd->current == NULL) || (tLine(new_item) != tLine(skd->current)))
+			// * Do we have to redraw the whole widget? *
+			if ((skd->current == NULL) || (tLine(new_item) != tLine(skd->current)) ||
+				(skd->show_empty_lines == TRUE) ||
+				(singit_song_is_empty_item(my_song, skd->current, TRUE) == FALSE))
 			{
-				if ((skd->current != g_list_previous(new_item)) || ((skd->current != NULL) &&
-					((skd->show_empty_lines == TRUE) ||
-						(singit_song_is_empty_item(my_song, skd->current, FALSE) == FALSE))))
-				{
-					expose |= SKD_EXPOSE_ALL;
-					area.width = skd->visual_min_width;
-					area.height = skd->visual_min_height;
-					singit_karaoke_data_reset_progress_data(skd, my_song, new_item);
-				}
+				expose |= SKD_EXPOSE_ALL;
+				area.width = skd->visual_min_width;
+				area.height = skd->visual_min_height;
+				singit_karaoke_data_reset_progress_data
+					(skd, my_song, new_item);
 			}
+/*			else if (tPos(new_item) != tPos(skd->current)) {
+				expose |= SKD_EXPOSE_PROGRESS;
+				singit_karaoke_data_reset_progress_data
+					(skd, my_song, new_item);
+			}*/
 			skd->current = new_item;
 		}
 
@@ -734,7 +815,7 @@ void singit_karaoke_data_set_time (SingitKaraokeData *skd, guint time)
 		if ((skd->freezers == 0) && (((area.width != 0) && (area.height != 0)) || (expose != 0))) {
 			gtk_signal_emit(GTK_OBJECT(skd), skd_signals[EXPOSE], &area, expose, time, &redrawn);
 
-			/* Just store the last settings if drawing was successfull */
+			// * Just store the last settings if drawing was successfull *
 			if (redrawn == TRUE) {
 				skd->pbp_offset_last = skd->pbp_offset;
 				skd->pbp_start_last = skd->pbp_start;
@@ -749,7 +830,7 @@ void singit_karaoke_data_set_time (SingitKaraokeData *skd, guint time)
 /*
  * Calculate the exposure area for the ball
  */
-void singit_karaoke_data_update_ball(SingitKaraokeData *skd, GdkRectangle *main_area)
+static void singit_karaoke_data_update_ball(SingitKaraokeData *skd, GdkRectangle *main_area)
 {
 	gint pos_x, height;
 	gint xpos[2];
@@ -785,7 +866,7 @@ void singit_karaoke_data_update_ball(SingitKaraokeData *skd, GdkRectangle *main_
 /*
  * Calculate the exposure area of the progress bar
  */
-void singit_karaoke_data_update_progess_bar(SingitKaraokeData *skd, gchar *text, GdkRectangle *main_area)
+static void singit_karaoke_data_update_progess_bar(SingitKaraokeData *skd, gchar *text, GdkRectangle *main_area)
 {
 	GdkRectangle area;
 	gint height;
@@ -796,7 +877,9 @@ void singit_karaoke_data_update_progess_bar(SingitKaraokeData *skd, gchar *text,
 	area.height = skd->text_line_height;
 
 	height = skd->top_lines_height;
-	if (skd->use_ball) { height += (skd->ball_line_height + skd->line_seperator_high); }
+	if (skd->use_ball) {
+		height += (skd->ball_line_height + skd->line_seperator_high);
+	}
 
 	ranges[0] = skd->pbp_start_last + skd->pbp_offset_last;
 	ranges[1] = skd->pbp_start + skd->pbp_offset;
@@ -804,7 +887,8 @@ void singit_karaoke_data_update_progess_bar(SingitKaraokeData *skd, gchar *text,
 	ranges[3] = MAX(ranges[0], ranges[1]) - ranges[2]; // width
 
 	if (main_area && (skd->freezers == 0)) {
-		area.x = ranges[2] + singit_karaoke_data_get_line_offset(skd, FALSE);
+		area.x = ranges[2] +
+			singit_karaoke_data_get_line_offset(skd, FALSE);
 		area.y = height;
 		area.width = ranges[3];
 		gdk_rectangle_union(main_area, &area, main_area);
@@ -813,13 +897,12 @@ void singit_karaoke_data_update_progess_bar(SingitKaraokeData *skd, gchar *text,
 
 static void singit_karaoke_data_refresh (SingitKaraokeData *skd, gint add_changer)
 {
-	static gint changer = 0;
 	GdkRectangle area;
 	SingitSong *my_song;
 	gboolean result;
 	gchar *text;
 
-	changer |= add_changer;
+	skd->thaw_refresh |= add_changer;
 
 	if (skd->freezers != 0) { return; }
 	if (!skd->song) { return; }
@@ -828,7 +911,8 @@ static void singit_karaoke_data_refresh (SingitKaraokeData *skd, gint add_change
 	g_print("skd_refresh\n");
 #endif
 
-	calc_karaoke_widget_sizes(skd, changer);
+	calc_karaoke_widget_sizes(skd);
+
 	skd->current = NULL;
 	area.x = 0;
 	area.y = 0;
@@ -837,14 +921,19 @@ static void singit_karaoke_data_refresh (SingitKaraokeData *skd, gint add_change
 
 	my_song = singit_song_attach(skd->song);
 	if (my_song != NULL) {
-		text = singit_karaoke_data_reset_progress_data(skd, my_song, my_song->active_token);
+		text = singit_karaoke_data_reset_progress_data
+			(skd, my_song, my_song->active_token);
+
 		if (my_song->active_token)
 			singit_karaoke_data_update_progess_bar(skd, text, FALSE);
-		gtk_signal_emit(GTK_OBJECT(skd), skd_signals[EXPOSE], &area, SKD_EXPOSE_ALL, skd->last_time, &result);
+
+		gtk_signal_emit(GTK_OBJECT(skd), skd_signals[EXPOSE],
+			&area, SKD_EXPOSE_ALL, skd->last_time, &result);
+
 		singit_song_detach(&my_song);
 	}
 
-	changer = 0;
+	skd->thaw_refresh = 0;
 }
 
 
@@ -864,7 +953,6 @@ void singit_karaoke_data_set_song (SingitKaraokeData *skd, SingitSong *new_song)
 #ifdef SKD_DEBUG
 	g_print("skd_set_song\n");
 #endif
-
 	attached_song = singit_song_attach(new_song);
 
 	if (attached_song != skd->song) {
@@ -875,7 +963,8 @@ void singit_karaoke_data_set_song (SingitKaraokeData *skd, SingitSong *new_song)
 		skd->pbp_start = skd->pbp_offset = 0;
 		skd->pbp_start_last = skd->pbp_offset_last = 0;
 		skd->last_time = -1;
-		skd->ball_y_pos_last = skd->ball_y_pos = skd->ball_line_height - skd->ball_diameter;
+		skd->ball_y_pos_last = skd->ball_y_pos =
+			skd->ball_line_height - skd->ball_diameter;
 		skd->ball_start = skd->ball_offset_max = 0;
 
 		singit_karaoke_data_refresh(skd, SONG_CHG);
@@ -984,7 +1073,12 @@ void singit_karaoke_data_set_jumping_ball (SingitKaraokeData *skd, const gboolea
 }
 
 void singit_karaoke_data_freeze(SingitKaraokeData *skd)
-{ skd->freezers++; }
+{
+	g_return_if_fail(skd != NULL);
+	g_return_if_fail(IS_SINGIT_KARAOKE_DATA(skd));
+
+	skd->freezers++;
+}
 
 void singit_karaoke_data_thaw(SingitKaraokeData *skd)
 {
@@ -992,23 +1086,6 @@ void singit_karaoke_data_thaw(SingitKaraokeData *skd)
 	if (skd->freezers == 0) { singit_karaoke_data_refresh(skd, 0); }
 }
 
-void singit_karaoke_data_set_optimal_font (SingitKaraokeData *skd)
-{
-	g_return_if_fail(skd != NULL);
-	g_return_if_fail(IS_SINGIT_KARAOKE_DATA(skd));
-
-#ifdef SKD_DEBUG
-	g_print("skd_set_optimal_font\n");
-#endif
-
-	if ((skd->song == NULL) || (singit_song_lyrics_found(skd->song) == FALSE))
-		{ return; }
-
-	singit_karaoke_data_freeze(skd);
-//	set_optimal_font(skd);
-	singit_karaoke_data_thaw(skd);
-}
-
 void singit_karaoke_data_set_centered_lines (SingitKaraokeData *skd, gboolean value)
 {
 	g_return_if_fail(skd != NULL);
@@ -1036,6 +1113,72 @@ gboolean singit_karaoke_data_get_centered_lines (SingitKaraokeData *skd)
 	return skd->centerLines;
 }
 
+void singit_karaoke_data_set_optimize_font(SingitKaraokeData *skd, gboolean optimize)
+{
+	g_return_if_fail(skd != NULL);
+	g_return_if_fail(IS_SINGIT_KARAOKE_DATA(skd));
+
+#ifdef SKD_DEBUG
+	g_print("skd_get_get_optimize_font\n");
+#endif
+
+	if (optimize != skd->optimize_font) {
+		skd->optimize_font = optimize;
+		if (skd->optimize_font == TRUE)
+			singit_karaoke_data_refresh(skd, OPTM_CHG);
+	}
+}
+
+gboolean singit_karaoke_data_get_optimize_font(SingitKaraokeData *skd)
+{
+	g_return_val_if_fail((skd != NULL), FALSE);
+	g_return_val_if_fail(IS_SINGIT_KARAOKE_DATA(skd), FALSE);
+
+#ifdef SKD_DEBUG
+	g_print("skd_get_get_optimize_font\n");
+#endif
+
+	return skd->optimize_font;
+}
+
+void singit_karaoke_data_optimize_font(SingitKaraokeData *skd)
+{
+	gpointer font;
+	gint x = 0, y = 0;
+
+	g_return_if_fail(skd != NULL);
+	g_return_if_fail(IS_SINGIT_KARAOKE_DATA(skd));
+
+#ifdef SKD_DEBUG
+	g_print("skd_set_optimize_font\n");
+#endif
+
+	if ((skd->song == NULL) || (singit_song_text_found(skd->song) == FALSE))
+		{ return; }
+
+	gtk_signal_emit(GTK_OBJECT(skd), skd_signals[OPTIMIZE],
+		x, y, skd->song->lyrics[skd->max_line_nr], &font);
+}
+
+void singit_karaoke_data_set_drawing_area(SingitKaraokeData *skd, gint w, gint h)
+{
+	g_return_if_fail(skd != NULL);
+	g_return_if_fail(IS_SINGIT_KARAOKE_DATA(skd));
+
+#ifdef SKD_DEBUG
+	g_print("skd_set_optimize_font\n");
+#endif
+
+	if ((skd->drawing_area_width != w) ||
+		(skd->drawing_area_height != h))
+	{
+		skd->drawing_area_width = w;
+		skd->drawing_area_height = h;
+		if (skd->optimize_font == TRUE)
+			singit_karaoke_data_refresh(skd, OPTM_CHG);
+	}
+}
+
 
 
 /*****************************
@@ -1044,32 +1187,68 @@ gboolean singit_karaoke_data_get_centered_lines (SingitKaraokeData *skd)
  *
  *****************************/
 
-static guint get_max_line_width (SingitKaraokeData *skd)
+static guint get_max_line_pixel (SingitKaraokeData *skd, gint *line)
 {
-	gint i = 0;
+	gint i = 0, line_nr = -1;
 	guint strlength;
 	guint line_width = 0;
 	SingitSong *my_song = singit_song_attach(skd->song);
 
-	if (my_song) {
-		if (my_song->lyrics) {
-			while (my_song->lyrics[i]) {
-				strlength = strlen(my_song->lyrics[i]);
-				if (strlength > 0) {
-					gtk_signal_emit(GTK_OBJECT(skd), skd_signals[RENDER], skd->font, my_song->lyrics[i], &strlength);
-		  			if (strlength > line_width) { line_width = strlength; }
-				}
-				i++;
+	if (my_song != NULL) {
+		if (singit_song_text_found(my_song) == FALSE)
+			{ goto bail_out_song; }
+	}
+	else { goto bail_out; }
+
+	while (my_song->lyrics[i]) {
+		strlength = strlen(my_song->lyrics[i]);
+		if (strlength > 0) {
+			gtk_signal_emit(GTK_OBJECT(skd), skd_signals[RENDER],
+				skd->font, my_song->lyrics[i], &strlength);
+  			if (strlength > line_width) {
+				line_width = strlength;
+				line_nr = i;
 			}
 		}
-		singit_song_detach(&my_song);
+		i++;
 	}
+
+	if (line != NULL)
+		*line = line_nr;
+
+bail_out_song:
+	singit_song_detach(&my_song);
+bail_out:
 	return line_width;
 }
 
-void calc_karaoke_widget_sizes(SingitKaraokeData *skd, gint change)
+static void singit_karaoke_data_optimize_font_int(SingitKaraokeData *skd)
 {
-	if (change & FONT_CHG) {
+	gpointer font;
+	gint x = 0, y = 0;
+	SingitKaraokeDataClass *klass =
+		(SingitKaraokeDataClass*) GTK_OBJECT(skd)->klass;
+
+	if ((skd->song == NULL) ||
+		(singit_song_text_found(skd->song) == FALSE) ||
+		(skd->drawing_area_width <= 0) ||
+		(skd->drawing_area_height <= 0) ||
+		(klass->optimize == NULL))
+	{
+		return;
+	}
+
+	gtk_signal_emit(GTK_OBJECT(skd), skd_signals[OPTIMIZE],
+		x, y, skd->song->lyrics[skd->max_line_nr], &font);
+}
+
+static void calc_karaoke_widget_sizes(SingitKaraokeData *skd)
+{
+	// First optimize the font - most calculated data will depend on it
+	if (skd->thaw_refresh & OPTM_CHG)
+		singit_karaoke_data_optimize_font_int(skd);
+
+	if (skd->thaw_refresh & FONT_CHG) {
 
 		skd->ball_line_height = skd->font_heigth;
 
@@ -1083,7 +1262,8 @@ void calc_karaoke_widget_sizes(SingitKaraokeData *skd, gint change)
 		skd->line_seperator_high = skd->font_heigth / 6 + 1;
 		skd->active_line_seperator_high = skd->font_heigth / 3 + 1;
 
-		gtk_signal_emit(GTK_OBJECT(skd), skd_signals[NEW_BALL], skd->ball_diameter);
+		gtk_signal_emit(GTK_OBJECT(skd),
+			skd_signals[NEW_BALL], skd->ball_diameter);
 	}
 
 	skd->visual_min_height =
@@ -1094,18 +1274,23 @@ void calc_karaoke_widget_sizes(SingitKaraokeData *skd, gint change)
 	else
 		skd->visual_min_height -= skd->line_seperator_high;
 
-	if (change & (FONT_CHG | SONG_CHG))
-		{ skd->max_line_width = get_max_line_width(skd); }
+	if (skd->thaw_refresh & (FONT_CHG | SONG_CHG)) {
+		skd->max_line_pixel =
+			get_max_line_pixel(skd, &skd->max_line_nr);
+	}
 
-	skd->visual_min_width = skd->max_line_width + 2 * skd->text_left_offset;
+	skd->visual_min_width = skd->max_line_pixel + 2 * skd->text_left_offset;
 
-	skd->top_lines_height = skd->top_lines * (skd->text_line_height + skd->line_seperator_high)
-		+ skd->active_line_seperator_high;
+	skd->top_lines_height = skd->top_lines *
+		(skd->text_line_height + skd->line_seperator_high)
+			+ skd->active_line_seperator_high;
 
-	gtk_signal_emit(GTK_OBJECT(skd), skd_signals[NEW_VISUAL], skd->visual_min_width, skd->visual_min_height);
+	gtk_signal_emit(GTK_OBJECT(skd), skd_signals[NEW_VISUAL],
+			skd->visual_min_width, skd->visual_min_height);
 }
 
-gint singit_karaoke_data_get_line_offset(SingitKaraokeData *skd, gboolean ball)
+gint singit_karaoke_data_get_line_offset
+	(SingitKaraokeData *skd, gboolean ball)
 {
 	g_return_val_if_fail((skd != NULL), FALSE);
 	g_return_val_if_fail(IS_SINGIT_KARAOKE_DATA(skd), FALSE);
@@ -1113,7 +1298,8 @@ gint singit_karaoke_data_get_line_offset(SingitKaraokeData *skd, gboolean ball)
 	return (ball == FALSE) ? skd->line_offset : skd->line_offset - left_right_line_border;
 }
 
-gint singit_karaoke_data_calc_line_offset(SingitKaraokeData *skd, gboolean ball, gchar *text)
+gint singit_karaoke_data_calc_line_offset
+	(SingitKaraokeData *skd, gboolean ball, gchar *text)
 {
 	gint size = 0, result;
 
@@ -1126,10 +1312,12 @@ gint singit_karaoke_data_calc_line_offset(SingitKaraokeData *skd, gboolean ball,
 		result = (ball == FALSE) ? left_right_line_border : 0;
 	}
 	else {
-		if (strlen(text) > 0)
-			{ gtk_signal_emit(GTK_OBJECT(skd), skd_signals[RENDER], skd->font, text, &size); }
+		if (strlen(text) > 0) {
+			gtk_signal_emit(GTK_OBJECT(skd),
+				skd_signals[RENDER], skd->font, text, &size);
+		}
 
-		result = (skd->max_line_width - size) / 2;
+		result = (skd->max_line_pixel - size) / 2;
 		if (result < left_right_line_border)
 			{ result = left_right_line_border; }
 		if (ball != FALSE)
