@@ -30,9 +30,9 @@
 
 #include <gtk/gtk.h>
 
-#include "singit_macros.h"
+#include "singit/macros.h"
 
-#include "singit_wgt_colorbutton.h"
+#include "singit/wgt_colorbutton.h"
 
 #define GIMP_CHECK_SIZE    8
 #define GIMP_CHECK_SIZE_SM 4
