@@ -27,8 +27,8 @@
 
 #include "singit_debug.h"
 
-#include "singit_karaoke_data.h"
-#include "singit_wgt_karaoke.h"
+#include "singit/karaoke_data.h"
+#include "singit/wgt_karaoke.h"
 #include "singit_tools.h"
 
 #define left_right_line_border ((SINGIT_KARAOKE_DATA(skw->skd)->ball_diameter / 2) + 1)
@@ -50,11 +50,6 @@ enum {
 	LAST_VALUE
 };
 
-/*
-enum {
-	ARG_0
-};
-*/
 void singit_karaoke_widget_build_lyric_pixmaps(SingitKaraokeWidget *skw);
 void singit_karaoke_widget_update_ball(SingitKaraokeWidget *skw, gint calced_offset);
 gint singit_karaoke_widget_update_progess_bar(SingitKaraokeWidget *skw, gchar *text);
@@ -73,8 +68,6 @@ static void singit_karaoke_widget_size_allocate (GtkWidget *widget, GtkAllocatio
 static void singit_karaoke_widget_realize (GtkWidget *widget);
 static void singit_karaoke_widget_unrealize(GtkWidget *widget);
 
-// static void singit_karaoke_widget_set_arg(GtkObject *object, GtkArg *arg, guint arg_id);
-// static void singit_karaoke_widget_get_arg(GtkObject *object, GtkArg *arg, guint arg_id);
 static void singit_karaoke_widget_destroy(GtkObject *object);
 static void singit_karaoke_widget_finalize(GtkObject *object);
 
@@ -108,8 +101,6 @@ static void singit_karaoke_widget_class_init (SingitKaraokeWidgetClass *klass)
 	GtkWidgetClass *widget_class = (GtkWidgetClass*) klass;
 	parent_class = gtk_type_class(GTK_TYPE_WIDGET);
 
-//	object_class->set_arg = singit_karaoke_widget_set_arg;
-//	object_class->get_arg = singit_karaoke_widget_get_arg;
 	object_class->destroy = singit_karaoke_widget_destroy;
 	object_class->finalize = singit_karaoke_widget_finalize;
 
@@ -158,7 +149,6 @@ static void singit_karaoke_widget_init(SingitKaraokeWidget *skw)
 		skw->private_color[i].blue = color_presets[i][2];
 	}
 
-	skw->maxLineWidth = FALSE;
 	skw->last_time = -1;
 
 	skw->timeIndicators = TRUE;
@@ -173,15 +163,15 @@ static void singit_karaoke_widget_init(SingitKaraokeWidget *skw)
 	skw->update_background = TRUE;
 
 	skw->skd = (gpointer) singit_karaoke_data_new();
-	gtk_signal_connect(GTK_OBJECT(skw->skd), "render", 
+	gtk_signal_connect(GTK_OBJECT(skw->skd), "render",
 		GTK_SIGNAL_FUNC(singit_karaoke_data_render), NULL);
-//	gtk_signal_connect(GTK_OBJECT(skw->skd), "optimize", 
+//	gtk_signal_connect(GTK_OBJECT(skw->skd), "optimize",
 //		GTK_SIGNAL_FUNC(singit_karaoke_data_optimize), NULL);
-	gtk_signal_connect(GTK_OBJECT(skw->skd), "expose", 
+	gtk_signal_connect(GTK_OBJECT(skw->skd), "expose",
 		GTK_SIGNAL_FUNC(singit_karaoke_data_expose), skw);
-	gtk_signal_connect(GTK_OBJECT(skw->skd), "new_ball", 
+	gtk_signal_connect(GTK_OBJECT(skw->skd), "new_ball",
 		GTK_SIGNAL_FUNC(singit_karaoke_data_new_ball), skw);
-	gtk_signal_connect(GTK_OBJECT(skw->skd), "new_visual", 
+	gtk_signal_connect(GTK_OBJECT(skw->skd), "new_visual",
 		GTK_SIGNAL_FUNC(singit_karaoke_data_new_visual), skw);
 }
 
@@ -192,45 +182,42 @@ static gint singit_karaoke_data_render(SingitKaraokeData *skd, gpointer font, gc
 
 static void draw_timeline(SingitKaraokeWidget *skw, gint time, GdkRectangle *area);
 
-static gboolean singit_karaoke_data_expose(SingitKaraokeData *skd, GdkRectangle *area, gint event, gint time, gpointer user_data)
+static gboolean singit_karaoke_data_expose(SingitKaraokeData *skd,
+	GdkRectangle *area, gint event, gint time, gpointer user_data)
 {
 	gint offset = 0;
 	SingitKaraokeWidget *skw;
 	GdkRectangle combined_area;
 
-	if (!GTK_WIDGET_DRAWABLE(GTK_WIDGET(user_data))) { return FALSE; }
-	if (!GTK_WIDGET_REALIZED(GTK_WIDGET(user_data))) { return FALSE; }
+	if (!GTK_WIDGET_REALIZED(GTK_WIDGET(user_data)))
+		{ return FALSE; }
 
-	if (event == 0) { return TRUE; }
+	if (event == 0)
+		{ return TRUE; }
 
 	skw = SINGIT_KARAOKE_WIDGET(user_data);
 
-//	if ((area->width != 0) && (area->height != 0)) {
-//		g_print("Area: %i\n", time);
-		if (event & SKD_EXPOSE_ALL) {
-			singit_karaoke_widget_build_lyric_pixmaps(skw);
-		}
-		if (event & SKD_EXPOSE_PROGRESS) {
-			offset =  singit_karaoke_widget_update_progess_bar
-				(skw, tText(skd->song, skd->current));
-			offset -= ((skd->ball_diameter / 2) + 1);
-		}
-		if ((offset >= 0) && (event & SKD_EXPOSE_BALL)) {
-			singit_karaoke_widget_update_ball(skw, offset);
-		}
+	if (event & SKD_EXPOSE_ALL) {
+		singit_karaoke_widget_build_lyric_pixmaps(skw);
+	}
+	if (event & SKD_EXPOSE_PROGRESS) {
+		offset =  singit_karaoke_widget_update_progess_bar
+			(skw, tText(skd->song, skd->current));
+		offset -= ((skd->ball_diameter / 2) + 1);
+	}
+	if ((offset >= 0) && (event & SKD_EXPOSE_BALL)) {
+		singit_karaoke_widget_update_ball(skw, offset);
+	}
 
-		if ((skw->timeIndicators == FALSE) || (event & SKD_EXPOSE_TIMELINE) != event) {
-//			g_print("Expose-Area: %i\n", time);
-			gtk_widget_queue_draw_area(GTK_WIDGET(user_data),
-				area->x + skw->sizes[LEFT_RIGHT_WIDGET_BORDER],
-				area->y + skw->sizes[TOP_BOTTOM_WIDGET_BORDER],
-				area->width, area->height);
-		}
-//	}
+	if ((skw->timeIndicators == FALSE) || (event & SKD_EXPOSE_TIMELINE) != event) {
+		gtk_widget_queue_draw_area(GTK_WIDGET(user_data),
+			area->x + skw->sizes[LEFT_RIGHT_WIDGET_BORDER],
+			area->y + skw->sizes[TOP_BOTTOM_WIDGET_BORDER],
+			area->width, area->height);
+	}
 
 	if ((skw->timeIndicators == TRUE) && (event & SKD_EXPOSE_TIMELINE)) {
 		if ((event & SKD_EXPOSE_TIMELINE) == event) {
-//			g_print("Timeline: %i\n", time);
 			combined_area = *area;
 			draw_timeline(skw, time, &combined_area);
 			gtk_widget_queue_draw_area(GTK_WIDGET(user_data),
@@ -250,9 +237,9 @@ static void draw_ball(SingitKaraokeWidget *skw, GdkPixmap *pixmap, gint pos_x,
 	gint ball_frame;
 	gboolean filled_ball = (SINGIT_KARAOKE_DATA(skw->skd)->ball_diameter > 5);
 
-	if (!GTK_WIDGET_REALIZED(GTK_WIDGET(skw))) 
+	if (!GTK_WIDGET_REALIZED(GTK_WIDGET(skw)))
 		{ return; }
-	
+
 	if (filled_ball == TRUE) {
 		draw_gc = gdk_gc_ref(skw->private_gc[skwc_normal_text]);
 	}
@@ -262,7 +249,7 @@ static void draw_ball(SingitKaraokeWidget *skw, GdkPixmap *pixmap, gint pos_x,
 		else
 			draw_gc = gdk_gc_ref(skw->private_gc[skwc_normal_text]);
 	}
-	
+
 	gdk_draw_arc (pixmap, draw_gc, TRUE, pos_x, pos_y,
 		SINGIT_KARAOKE_DATA(skw->skd)->ball_diameter,
 		SINGIT_KARAOKE_DATA(skw->skd)->ball_diameter, 0, 360 * 64);
@@ -281,7 +268,7 @@ static void draw_ball(SingitKaraokeWidget *skw, GdkPixmap *pixmap, gint pos_x,
 			SINGIT_KARAOKE_DATA(skw->skd)->ball_diameter - ball_frame * 2,
 			0, 360 * 64);
 	}
-	
+
 	gdk_gc_unref(draw_gc);
 }
 
@@ -362,13 +349,19 @@ static void singit_karaoke_data_new_ball
 	draw_gc = gdk_gc_ref(skw->private_gc[skwc_normal_bar]);
 
 	skw->ball_pixmap = gdk_pixmap_new(GTK_WIDGET(skw)->window,
-		SINGIT_KARAOKE_DATA(skw->skd)->ball_diameter, SINGIT_KARAOKE_DATA(skw->skd)->ball_diameter, -1);
+		SINGIT_KARAOKE_DATA(skw->skd)->ball_diameter,
+		SINGIT_KARAOKE_DATA(skw->skd)->ball_diameter, -1);
 	gdk_draw_rectangle(skw->ball_pixmap, draw_gc, TRUE, 0, 0,
-		SINGIT_KARAOKE_DATA(skw->skd)->ball_diameter, SINGIT_KARAOKE_DATA(skw->skd)->ball_diameter);
+		SINGIT_KARAOKE_DATA(skw->skd)->ball_diameter,
+		SINGIT_KARAOKE_DATA(skw->skd)->ball_diameter);
 
 	draw_ball(skw, skw->ball_pixmap, 0, 0, TRUE, FALSE);
 
 	gdk_gc_unref(draw_gc);
+
+	gtk_widget_set_usize((GtkWidget*) skw,
+		SINGIT_KARAOKE_DATA(skw->skd)->visual_min_width,
+		SINGIT_KARAOKE_DATA(skw->skd)->visual_min_height);
 }
 
 static void skw_draw_line_rects(SingitKaraokeWidget *skw, GdkPixmap *pixmap, gboolean restore_background)
@@ -405,7 +398,7 @@ static void skw_draw_line_rects(SingitKaraokeWidget *skw, GdkPixmap *pixmap, gbo
 	g_print("skw_draw_line_rects\n");
 #endif
 
-	if (!GTK_WIDGET_REALIZED(GTK_WIDGET(skw))) 
+	if (!GTK_WIDGET_REALIZED(GTK_WIDGET(skw)))
 		{ return; }
 
 	draw_bar_gc = gdk_gc_ref(skw->private_gc[skwc_normal_bar]);
@@ -427,7 +420,7 @@ static void skw_draw_line_rects(SingitKaraokeWidget *skw, GdkPixmap *pixmap, gbo
 	for (i = 0; i < (gint) (SINGIT_KARAOKE_DATA(skw->skd)->lines - SINGIT_KARAOKE_DATA(skw->skd)->top_lines); i++) {
 		DRAW_BAR(text_line_height);
 		RESTORE_BG(line_seperator_high);
-		if (i == 0) { 
+		if (i == 0) {
 			RESTORE_BG(active_line_seperator_high);
 		}
 	}
@@ -438,7 +431,8 @@ static void skw_draw_line_rects(SingitKaraokeWidget *skw, GdkPixmap *pixmap, gbo
 #undef RESTORE_BG
 }
 
-static void singit_karaoke_data_new_visual(SingitKaraokeData *skd, gint wx, gint wy, gpointer user_data)
+static void singit_karaoke_data_new_visual
+	(SingitKaraokeData *skd, gint wx, gint wy, gpointer user_data)
 {
 	SingitKaraokeWidget *skw;
 
@@ -446,7 +440,7 @@ static void singit_karaoke_data_new_visual(SingitKaraokeData *skd, gint wx, gint
 	g_return_if_fail(IS_SINGIT_KARAOKE_DATA(skd));
 	g_return_if_fail(IS_SINGIT_KARAOKE_WIDGET(user_data));
 
-	if (!GTK_WIDGET_REALIZED(user_data)) 
+	if (!GTK_WIDGET_REALIZED(user_data))
 		{ return; }
 
 	skw = SINGIT_KARAOKE_WIDGET(user_data);
@@ -464,7 +458,7 @@ static void singit_karaoke_data_new_visual(SingitKaraokeData *skd, gint wx, gint
 	}
 
 	skw->double_buffer_pixmap = gdk_pixmap_new(GTK_WIDGET(skw)->window, wx, wy, -1);
-	gdk_draw_rectangle(skw->double_buffer_pixmap, 
+	gdk_draw_rectangle(skw->double_buffer_pixmap,
 		skw->private_gc[skwc_background], TRUE,
 		0, 0, wx, wy);
 
@@ -526,33 +520,6 @@ static void singit_karaoke_widget_finalize (GtkObject *object)
 		GTK_OBJECT_CLASS(parent_class)->finalize (object);
 }
 
-static void singit_karaoke_widget_set_arg(GtkObject *object, GtkArg *arg, guint arg_id)
-{
-	SingitKaraokeWidget *skw;
-
-	skw = SINGIT_KARAOKE_WIDGET(object);
-
-	switch (arg_id)
-	{
-	default:
-		break;
-	}
-}
-
-static void singit_karaoke_widget_get_arg(GtkObject *object, GtkArg *arg, guint arg_id)
-{
-	SingitKaraokeWidget *skw;
-
-	skw = SINGIT_KARAOKE_WIDGET(object);
-
-	switch (arg_id)
-	{
-	default:
-		arg->type = GTK_TYPE_INVALID;
-		break;
-	}
-}
-
 static void singit_karaoke_widget_realize (GtkWidget *widget)
 {
 	SingitKaraokeWidget *skw;
@@ -1030,7 +997,6 @@ static gint substract_region(GdkRectangle full, GdkRectangle part, GdkRectangle
 
 static gboolean singit_karaoke_expose_event (GtkWidget *widget, GdkEventExpose *event)
 {
-//	GdkGC *draw_gc = NULL;
 	SingitKaraokeWidget *skw;
 	GdkRectangle intersect_rectangle, widget_rectangle;
 	GdkRectangle result_top, result_left, result_right, result_bottom;
@@ -1040,41 +1006,23 @@ static gboolean singit_karaoke_expose_event (GtkWidget *widget, GdkEventExpose *
 	g_return_val_if_fail(IS_SINGIT_KARAOKE_WIDGET(widget), FALSE);
 	g_return_val_if_fail(event != NULL, FALSE);
 
+	skw = SINGIT_KARAOKE_WIDGET (widget);
+
 //	Check if we are ready to draw
-	if (
-		(!GTK_WIDGET_DRAWABLE(widget)) ||
-		(!GTK_WIDGET_REALIZED(widget)) ||
-		(widget->window == NULL) ||
-		(!gdk_window_is_visible(widget->window)) ||
-		(!gdk_window_is_viewable(widget->window))
-		)
+	if (!GTK_WIDGET_DRAWABLE(widget) || (skw->double_buffer_pixmap == NULL))
 	{
 		return FALSE;
 	}
 
-//	if (event->count > 0) { return FALSE; }
-
-	skw = SINGIT_KARAOKE_WIDGET (widget);
-
-	if (skw->freezers > 0) { return FALSE; }
+	if (skw->freezers > 0)
+		{ return FALSE; }
 
 	widget_rectangle.x = skw->sizes[LEFT_RIGHT_WIDGET_BORDER];
 	widget_rectangle.y = skw->sizes[TOP_BOTTOM_WIDGET_BORDER];
 	widget_rectangle.width = SINGIT_KARAOKE_DATA(skw->skd)->visual_min_width;
 	widget_rectangle.height = SINGIT_KARAOKE_DATA(skw->skd)->visual_min_height;
 
-	if (!(SINGIT_KARAOKE_DATA(skw->skd)->song && singit_song_lyrics_found(SINGIT_KARAOKE_DATA(skw->skd)->song) && skw->double_buffer_pixmap &&
-		gdk_rectangle_intersect(&event->area, &widget_rectangle, &intersect_rectangle)))
-	{
-		gdk_window_clear_area(widget->window, event->area.x, event->area.y,
-			event->area.width, event->area.height);
-		return FALSE;
-	}
-
-//	draw_gc = gdk_gc_new (widget->window);
-//	gdk_gc_copy(draw_gc, GTK_WIDGET(skw)->style->black_gc);
-//	gdk_gc_set_fill (draw_gc, GDK_SOLID);
-//	gdk_gc_set_foreground (draw_gc, widget->style->text);
+	gdk_rectangle_intersect(&event->area, &widget_rectangle, &intersect_rectangle);
 
 	// Redraw all widget borders if needed
 	if ((draw_sides = substract_region(event->area, intersect_rectangle,
@@ -1110,66 +1058,6 @@ static gboolean singit_karaoke_expose_event (GtkWidget *widget, GdkEventExpose *
 	return FALSE;
 }
 
-/*
- *On variable sized fonts it's really hard to get the right
- * measurement of (multiple) spaces because it's dependant
- * of the prevous and next characters
- *
- * So we have to do some tricks
- */
-static gint singit_karaoke_widget_get_offset_pos(gchar *text, GdkFont *font, gint pos)
-{
-	gint str_len;
-	gint str_pixel;
-	gchar *offset_pos;
-	gchar old_char;
-
-	gint start_pixel, end_pixel, start_pos, end_pos;
-
-	if (pos == 0) { return 0; }
-
-	str_len = strlen(text);
-	str_pixel = gdk_string_measure(font, text);
-	if (pos == str_len) { return str_pixel; }
-
-	// If we have some spaces at the position in the string...
-	if ((text[pos-1] == ' ') || (text[pos] == ' '))
-	{
-		// Find the next non-space character and measure the rest
-		end_pos = pos;
-		while ((end_pos < str_len) && (text[end_pos] == ' ')) { end_pos++; }
-		end_pixel = (end_pos < str_len) ? gdk_string_measure(font, &text[end_pos]) : 0;
-
-		// Find the prev non-space character and measure from the start
-		start_pos = pos - 1;
-		while ((start_pos > 0) && (text[start_pos] == ' ')) { start_pos--; }
-		if (start_pos > 0) {
-			offset_pos = text + start_pos + 1;
-			old_char = offset_pos[0];
-			offset_pos[0] = '\0';
-			start_pixel = gdk_string_measure(font, text);
-			offset_pos[0] = old_char;
-		}
-		else { start_pixel = 0; }
-
-		// Calculate the percentual position
-		if ((end_pos - start_pos) != str_len) {
-			str_pixel = start_pixel + (str_pixel - start_pixel - end_pixel) *
-				(pos - start_pos) / (end_pos - start_pos);
-		}
-	}
-	else {
-		// Do the simple measurement
-		offset_pos = text + pos;
-		old_char = offset_pos[0];
-		offset_pos[0] = '\0';
-		str_pixel = gdk_string_measure(font, text);
-		offset_pos[0] = old_char;
-	}
-
-	return str_pixel;
-}
-
 /*
  * This creates a new a double_buffer_pixmap dependent on
  * the current song position
@@ -1236,7 +1124,7 @@ gint singit_karaoke_widget_update_progess_bar(SingitKaraokeWidget *skw, gchar *t
 	if (!(GTK_WIDGET(skw)->window && skw->double_buffer_pixmap)) { return 0; }
 
 	height = SINGIT_KARAOKE_DATA(skw->skd)->top_lines_height;
-	if (SINGIT_KARAOKE_DATA(skw->skd)->use_ball) 
+	if (SINGIT_KARAOKE_DATA(skw->skd)->use_ball)
 		{ height += (SINGIT_KARAOKE_DATA(skw->skd)->ball_line_height + SINGIT_KARAOKE_DATA(skw->skd)->line_seperator_high); }
 
 	string_left_offset = singit_karaoke_data_get_line_offset(SINGIT_KARAOKE_DATA(skw->skd), FALSE);
@@ -1393,15 +1281,18 @@ static void singit_karaoke_widget_refresh (SingitKaraokeWidget *skw)
 
 
 	singit_karaoke_widget_build_lyric_pixmaps(skw);
-	if (SINGIT_KARAOKE_DATA(skw->skd)->song && SINGIT_KARAOKE_DATA(skw->skd)->song->active_token)
+	if (SINGIT_KARAOKE_DATA(skw->skd)->song &&
+		SINGIT_KARAOKE_DATA(skw->skd)->song->active_token)
+	{
 		singit_karaoke_widget_update_progess_bar
-			(skw, tText(SINGIT_KARAOKE_DATA(skw->skd)->song, SINGIT_KARAOKE_DATA(skw->skd)->song->active_token));
+			(skw, tText(SINGIT_KARAOKE_DATA(skw->skd)->song,
+			SINGIT_KARAOKE_DATA(skw->skd)->song->active_token));
+	}
 
-	if (GTK_WIDGET_DRAWABLE(GTK_WIDGET(skw)))
+	if (GTK_WIDGET_REALIZED(GTK_WIDGET(skw)))
 		gtk_widget_set_usize((GtkWidget*) skw,
-			SINGIT_KARAOKE_DATA(skw->skd)->visual_min_width, SINGIT_KARAOKE_DATA(skw->skd)->visual_min_height);
-/*	if (GTK_WIDGET_DRAWABLE(GTK_WIDGET (skw)))
-		{ gtk_widget_queue_resize(GTK_WIDGET(skw)); }*/
+			SINGIT_KARAOKE_DATA(skw->skd)->visual_min_width,
+			SINGIT_KARAOKE_DATA(skw->skd)->visual_min_height);
 }
 
 
@@ -1500,14 +1391,14 @@ void singit_karaoke_widget_set_color
 			gdk_colormap_alloc_color(gtk_widget_get_colormap(GTK_WIDGET(skw)),
 				&new_color, FALSE, TRUE);
 
-			if (item == skwc_background) 
+			if (item == skwc_background)
 				{ gdk_window_set_background(GTK_WIDGET(skw)->window, &new_color); }
 
 			gdk_gc_set_foreground(skw->private_gc[item], &new_color);
 		}
 
 		skw->private_color[item] = new_color;
-		
+
 		if (item == skwc_background)
 			{ skw->update_background = TRUE; }
 	}
@@ -1540,14 +1431,14 @@ void singit_karaoke_widget_set_color_gdk
 		gdk_colormap_alloc_color(gtk_widget_get_colormap(GTK_WIDGET(skw)),
 			new_color, FALSE, TRUE);
 
-		if (item == skwc_background) 
+		if (item == skwc_background)
 			{ gdk_window_set_background(GTK_WIDGET(skw)->window, new_color); }
 
 		gdk_gc_set_foreground(skw->private_gc[item], new_color);
 	}
 
 	skw->private_color[item] = (*new_color);
-	
+
 	if (item == skwc_background)
 		{ skw->update_background = TRUE; }
 }
@@ -1570,7 +1461,7 @@ void singit_karaoke_widget_set_font (SingitKaraokeWidget *skw, const gchar *font
 		skd = SINGIT_KARAOKE_DATA(skw->skd);
 
 		if (skd->font) { gdk_font_unref((GdkFont*) (skd->font)); }
-		singit_karaoke_data_set_font(skd, (gpointer) new_font, 
+		singit_karaoke_data_set_font(skd, (gpointer) new_font,
 			new_font->ascent + new_font->descent);
 
 		if (skw->private_font_name != NULL)
@@ -1641,7 +1532,7 @@ void singit_karaoke_widget_set_optimal_font (SingitKaraokeWidget *skw)
 	g_print("skw_set_optimal_font\n");
 #endif
 
-	if ((SINGIT_KARAOKE_DATA(skw->skd)->song == NULL) || 
+	if ((SINGIT_KARAOKE_DATA(skw->skd)->song == NULL) ||
 		(singit_song_lyrics_found(SINGIT_KARAOKE_DATA(skw->skd)->song) == FALSE))
 		{ return; }
 
